(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     62996,       1568]
NotebookOptionsPosition[     57242,       1471]
NotebookOutlinePosition[     57598,       1487]
CellTagsIndexPosition[     57555,       1484]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Session 4 : Exercises", "Title",
 CellChangeTimes->{{3.773468977392448*^9, 
  3.7734690009706707`*^9}},ExpressionUUID->"d0a18a2b-fbb1-4c83-92bb-\
5fbc0dbe2fde"],

Cell[TextData[{
 "For any graph, an optimal flow can be computed as the solution to the \
convex program\n",
 Cell[BoxData[{
  FormBox[
   RowBox[{"min", "  ", 
    RowBox[{
     SubscriptBox["\[Sum]", "e"], 
     RowBox[{
      SubscriptBox["x", "e"], 
      RowBox[{
       SubscriptBox["c", "e"], "(", 
       SubscriptBox["x", "e"], ")"}]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"     ", 
    RowBox[{
     RowBox[{
      RowBox[{"s", ".", "t", ".", "  ", "x"}], "  ", "is", "   ", "s"}], "-", 
     
     RowBox[{"t", "   ", "flow"}]}]}], TraditionalForm]}],
  FormatType->"TraditionalForm",ExpressionUUID->
  "c7dc8b14-eccc-4d56-96a2-3127a2bfe755"],
 "\nA Wardrop can be computed by solving \n",
 Cell[BoxData[{
  FormBox[
   RowBox[{"min", "  ", 
    RowBox[{
     SubscriptBox["\[Sum]", "e"], 
     RowBox[{"\[Integral]", 
      RowBox[{
       SubscriptBox["c", "e"], "(", 
       SubscriptBox["x", "e"], ")"}]}]}]}], 
   TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"     ", 
    RowBox[{
     RowBox[{
      RowBox[{"s", ".", "t", ".", "  ", "x"}], "  ", "is", "   ", "s"}], "-", 
     
     RowBox[{"t", "   ", "flow"}]}]}], TraditionalForm]}],
  FormatType->"TraditionalForm",ExpressionUUID->
  "01153e8e-0d2c-444d-9f7f-31adbeb99ec5"],
 "\nWe want to set up these convex programs for any given graph with affine \
cost functions, to solve them later."
}], "Text",
 CellChangeTimes->{{3.7734690316923847`*^9, 3.773469076825315*^9}, {
  3.7734712510851097`*^9, 3.773471289752164*^9}, {3.773471413322291*^9, 
  3.773471430680572*^9}, {3.773471473224145*^9, 
  3.7734715568557577`*^9}},ExpressionUUID->"df5b0a0c-8df5-4ab6-99bd-\
3ddef197ae55"],

Cell[CellGroupData[{

Cell["Exercise 1", "Section",
 CellChangeTimes->{{3.773471595320911*^9, 
  3.773471602742584*^9}},ExpressionUUID->"e60213ab-e900-4b9d-b7d5-\
dd82c6d652d8"],

Cell["\<\
Create the following graph g using Graph[ ]. The numbers on the edges are \
edge weights.
Then compute the shortest 1-v-path for all vertices v (use All in the \
shortest path function) and use HighlightGraph[ g , DirectedGraph[ PathGraph[ \
path ]] ] to highlight the shortest path in the graph\
\>", "Text",
 CellChangeTimes->{{3.7734716216718493`*^9, 3.773471649589077*^9}, {
  3.773471711509699*^9, 3.7734717174832*^9}, {3.773471765050034*^9, 
  3.773471829353753*^9}, {3.7734719022647457`*^9, 3.7734719222452993`*^9}, {
  3.77347250633613*^9, 3.773472516688046*^9}, {3.773472644992865*^9, 
  3.7734726451052227`*^9}},ExpressionUUID->"ecc5b2f2-3ecd-427c-9499-\
f9467cbda2c9"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 6, 4, 5, 
      7}, {{{1, 2}, {1, 3}, {2, 3}, {2, 4}, {3, 5}, {1, 6}, {2, 6}, {4, 3}, {
       5, 4}, {6, 7}, {7, 4}}, Null}, {
      EdgeLabels -> {"EdgeWeight"}, VertexLabels -> {Automatic}, 
       EdgeWeight -> {2, 1, 4, 3, 2, 0, 4, 1, 3, 1, 3}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        Medium], {
         ArrowBox[{{0.5960160277281462, 1.862156152067551}, {
          0.8690983639077405, 1.1848884731247575`}}, 0.026628425965941713`], 
         InsetBox["2", {0.7325571958179433, 1.5235223125961541}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.5960160277281462, 1.862156152067551}, {
          1.6694078657601121`, 1.4272274195904915`}}, 0.026628425965941713`], 
         InsetBox["1", {1.1327119467441291, 1.6446917858290213}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.5960160277281462, 1.862156152067551}, {0., 
          0.9779844465166062}}, 0.026628425965941713`], 
         InsetBox["0", {0.2980080138640731, 1.4200702992920786}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.8690983639077405, 1.1848884731247575`}, {
          1.6694078657601121`, 1.4272274195904915`}}, 0.026628425965941713`], 
         InsetBox["4", {1.2692531148339263, 1.3060579463576245}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.8690983639077405, 1.1848884731247575`}, {
          1.5282154061044397`, 0.4952293143734847}}, 0.026628425965941713`], 
         InsetBox["3", {1.1986568850060901, 0.8400588937491211}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.8690983639077405, 1.1848884731247575`}, {0., 
          0.9779844465166062}}, 0.026628425965941713`], 
         InsetBox["4", {0.43454918195387027, 1.0814364598206818}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.6694078657601121`, 1.4272274195904915`}, {
          2.5111897789994537`, 0.8478448865270738}}, 0.026628425965941713`], 
         InsetBox["2", {2.0902988223797827, 1.1375361530587826}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.5282154061044397`, 0.4952293143734847}, {
          1.6694078657601121`, 1.4272274195904915`}}, 0.026628425965941713`], 
         InsetBox["1", {1.598811635932276, 0.9612283669819881}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.5111897789994537`, 0.8478448865270738}, {
          1.5282154061044397`, 0.4952293143734847}}, 0.026628425965941713`], 
         InsetBox["3", {2.0197025925519467, 0.6715371004502793}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 0.9779844465166062}, {0.45740167194578374`, 0.}}, 
          0.026628425965941713`], 
         InsetBox["1", {0.22870083597289187, 0.4889922232583031}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.45740167194578374`, 0.}, {1.5282154061044397`, 
          0.4952293143734847}}, 0.026628425965941713`], 
         InsetBox["3", {0.9928085390251118, 0.24761465718674236}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         DiskBox[{0.5960160277281462, 1.862156152067551}, 
          0.026628425965941713], 
         InsetBox["1", 
          Offset[{2, 2}, {0.6226444536940879, 1.8887845780334926}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.8690983639077405, 1.1848884731247575}, 
          0.026628425965941713], 
         InsetBox["2", 
          Offset[{2, 2}, {0.8957267898736823, 1.2115168990906993}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.6694078657601121, 1.4272274195904915}, 
          0.026628425965941713], 
         InsetBox["3", 
          Offset[{2, 2}, {1.6960362917260539, 1.4538558455564332}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.5282154061044397, 0.4952293143734847}, 
          0.026628425965941713], 
         InsetBox["6", 
          Offset[{2, 2}, {1.5548438320703815, 0.5218577403394264}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.5111897789994537, 0.8478448865270738}, 
          0.026628425965941713], 
         InsetBox["4", 
          Offset[{2, 2}, {2.5378182049653955, 0.8744733124930155}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0., 0.9779844465166062}, 0.026628425965941713], 
         InsetBox["5", 
          Offset[{2, 2}, {0.026628425965941713, 1.0046128724825478}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.45740167194578374, 0.}, 0.026628425965941713], 
         InsetBox["7", 
          Offset[{2, 2}, {0.48403009791172547, 0.026628425965941713}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Input",ExpressionUUID->"c49f4346-c988-4e43-8def-\
f12833743e9b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g", "=", " ", 
   RowBox[{"Graph", "[", " ", 
    RowBox[{"(*", " ", 
     RowBox[{"...", "."}], " ", "*)"}], " ", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pathfunction", " ", "=", " ", 
   RowBox[{"FindShortestPath", "[", 
    RowBox[{"g", ",", " ", "1", ",", " ", "All"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"...", "."}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.773472674075941*^9, 
  3.773472737501899*^9}},ExpressionUUID->"24371248-d405-41eb-8f49-\
ded8d85ea4c0"],

Cell[CellGroupData[{

Cell["Solution", "Subsection",
 CellChangeTimes->{{3.773472652015807*^9, 
  3.773472655349676*^9}},ExpressionUUID->"d905f599-adbf-4a98-b5c5-\
beedf4c01ee7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"g", " ", "=", " ", 
  RowBox[{"Graph", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "\[Rule]", "2"}], ",", 
      RowBox[{"1", "\[Rule]", "3"}], ",", 
      RowBox[{"2", "\[Rule]", "3"}], ",", 
      RowBox[{"2", "\[Rule]", "6"}], ",", 
      RowBox[{"3", "\[Rule]", "4"}], ",", 
      RowBox[{"1", "\[Rule]", "5"}], ",", 
      RowBox[{"2", "\[Rule]", "5"}], ",", 
      RowBox[{"6", "\[Rule]", "3"}], ",", 
      RowBox[{"4", "\[Rule]", "6"}], ",", 
      RowBox[{"5", "\[Rule]", "7"}], ",", 
      RowBox[{"7", "\[Rule]", "6"}]}], "}"}], ",", " ", 
    RowBox[{"VertexLabels", "\[Rule]", "Automatic"}], ",", " ", 
    RowBox[{"EdgeWeight", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
      "2", ",", "1", ",", "4", ",", "3", ",", "2", ",", "0", ",", "4", ",", 
       "1", ",", "3", ",", "1", ",", "3"}], "}"}]}], ",", 
    RowBox[{"EdgeLabels", "\[Rule]", "\"\<EdgeWeight\>\""}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pathfunc", "=", 
   RowBox[{"FindShortestPath", "[", 
    RowBox[{"g", ",", "1", ",", "All"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"HighlightGraph", "[", 
    RowBox[{"g", ",", 
     RowBox[{"DirectedGraph", "[", 
      RowBox[{"PathGraph", "[", 
       RowBox[{"pathfunc", "[", "target", "]"}], "]"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"target", ",", "1", ",", "7", ",", "1"}], "}"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7734717225028*^9, 3.7734717282384167`*^9}, {
  3.7734718011612253`*^9, 3.773471801386046*^9}, {3.773471831772335*^9, 
  3.773471893762497*^9}, {3.773471932610484*^9, 3.773472023518561*^9}, {
  3.77347208369921*^9, 3.773472142005328*^9}, {3.7734722556671267`*^9, 
  3.7734722623695383`*^9}, {3.773472418580566*^9, 3.7734724903363743`*^9}, {
  3.773472527322661*^9, 3.773472627893364*^9}},
 CellLabel->
  "In[298]:=",ExpressionUUID->"8422b6ac-f7e2-4603-89c3-368276ba90cd"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 6, 4, 5, 
      7}, {{{1, 2}, {1, 3}, {2, 3}, {2, 4}, {3, 5}, {1, 6}, {2, 6}, {4, 3}, {
       5, 4}, {6, 7}, {7, 4}}, Null}, {
      EdgeLabels -> {"EdgeWeight"}, VertexLabels -> {Automatic}, 
       EdgeWeight -> {2, 1, 4, 3, 2, 0, 4, 1, 3, 1, 3}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        Medium], {
         ArrowBox[{{0.5960160277281462, 1.862156152067551}, {
          0.8690983639077405, 1.1848884731247575`}}, 0.026628425965941713`], 
         InsetBox["2", {0.7325571958179433, 1.5235223125961541}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.5960160277281462, 1.862156152067551}, {
          1.6694078657601121`, 1.4272274195904915`}}, 0.026628425965941713`], 
         InsetBox["1", {1.1327119467441291, 1.6446917858290213}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.5960160277281462, 1.862156152067551}, {0., 
          0.9779844465166062}}, 0.026628425965941713`], 
         InsetBox["0", {0.2980080138640731, 1.4200702992920786}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.8690983639077405, 1.1848884731247575`}, {
          1.6694078657601121`, 1.4272274195904915`}}, 0.026628425965941713`], 
         InsetBox["4", {1.2692531148339263, 1.3060579463576245}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.8690983639077405, 1.1848884731247575`}, {
          1.5282154061044397`, 0.4952293143734847}}, 0.026628425965941713`], 
         InsetBox["3", {1.1986568850060901, 0.8400588937491211}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.8690983639077405, 1.1848884731247575`}, {0., 
          0.9779844465166062}}, 0.026628425965941713`], 
         InsetBox["4", {0.43454918195387027, 1.0814364598206818}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.6694078657601121`, 1.4272274195904915`}, {
          2.5111897789994537`, 0.8478448865270738}}, 0.026628425965941713`], 
         InsetBox["2", {2.0902988223797827, 1.1375361530587826}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.5282154061044397`, 0.4952293143734847}, {
          1.6694078657601121`, 1.4272274195904915`}}, 0.026628425965941713`], 
         InsetBox["1", {1.598811635932276, 0.9612283669819881}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{2.5111897789994537`, 0.8478448865270738}, {
          1.5282154061044397`, 0.4952293143734847}}, 0.026628425965941713`], 
         InsetBox["3", {2.0197025925519467, 0.6715371004502793}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 0.9779844465166062}, {0.45740167194578374`, 0.}}, 
          0.026628425965941713`], 
         InsetBox["1", {0.22870083597289187, 0.4889922232583031}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.45740167194578374`, 0.}, {1.5282154061044397`, 
          0.4952293143734847}}, 0.026628425965941713`], 
         InsetBox["3", {0.9928085390251118, 0.24761465718674236}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         DiskBox[{0.5960160277281462, 1.862156152067551}, 
          0.026628425965941713], 
         InsetBox["1", 
          Offset[{2, 2}, {0.6226444536940879, 1.8887845780334926}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.8690983639077405, 1.1848884731247575}, 
          0.026628425965941713], 
         InsetBox["2", 
          Offset[{2, 2}, {0.8957267898736823, 1.2115168990906993}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.6694078657601121, 1.4272274195904915}, 
          0.026628425965941713], 
         InsetBox["3", 
          Offset[{2, 2}, {1.6960362917260539, 1.4538558455564332}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.5282154061044397, 0.4952293143734847}, 
          0.026628425965941713], 
         InsetBox["6", 
          Offset[{2, 2}, {1.5548438320703815, 0.5218577403394264}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{2.5111897789994537, 0.8478448865270738}, 
          0.026628425965941713], 
         InsetBox["4", 
          Offset[{2, 2}, {2.5378182049653955, 0.8744733124930155}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0., 0.9779844465166062}, 0.026628425965941713], 
         InsetBox["5", 
          Offset[{2, 2}, {0.026628425965941713, 1.0046128724825478}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.45740167194578374, 0.}, 0.026628425965941713], 
         InsetBox["7", 
          Offset[{2, 2}, {0.48403009791172547, 0.026628425965941713}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.773471881632353*^9, 3.773471885112502*^9}, {
   3.773471946124239*^9, 3.773471973249817*^9}, 3.773472024121791*^9, {
   3.773472089033828*^9, 3.7734721432721148`*^9}, {3.7734722582818403`*^9, 
   3.7734722625687838`*^9}, {3.773472479792609*^9, 3.773472491037871*^9}, {
   3.7734725432708473`*^9, 3.773472577281303*^9}, {3.773472615874751*^9, 
   3.773472628497424*^9}},
 CellLabel->
  "Out[298]=",ExpressionUUID->"5dffb88b-3a38-4126-93bc-ff70430cc9fa"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`target$$ = 7, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`target$$], 1, 7, 1}}, Typeset`size$$ = {
    360., {138., 142.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`target$101074$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`target$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`target$$, $CellContext`target$101074$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> HighlightGraph[$CellContext`g, 
        DirectedGraph[
         PathGraph[
          $CellContext`pathfunc[$CellContext`target$$]]]], 
      "Specifications" :> {{$CellContext`target$$, 1, 7, 1}}, "Options" :> {},
       "DefaultOptions" :> {}],
     ImageSizeCache->{405., {183., 189.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.773471881632353*^9, 3.773471885112502*^9}, {
   3.773471946124239*^9, 3.773471973249817*^9}, 3.773472024121791*^9, {
   3.773472089033828*^9, 3.7734721432721148`*^9}, {3.7734722582818403`*^9, 
   3.7734722625687838`*^9}, {3.773472479792609*^9, 3.773472491037871*^9}, {
   3.7734725432708473`*^9, 3.773472577281303*^9}, {3.773472615874751*^9, 
   3.773472628530971*^9}},
 CellLabel->
  "Out[300]=",ExpressionUUID->"0abdc73a-d0fe-4154-bfb4-3c81e07b9719"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercise 2", "Section",
 CellChangeTimes->{{3.773472750249998*^9, 
  3.773472769238263*^9}},ExpressionUUID->"bea4ab9e-c4cc-41d0-a996-\
42d51dd3988b"],

Cell["\<\
Assume you are given a graph, lists of coefficients of the affine cost \
functions of the edges, and specified source and sink vertices, e.g., the \
Braess Graph:\
\>", "Text",
 CellChangeTimes->{{3.7734728076732187`*^9, 3.773472845356028*^9}, {
  3.773472880816162*^9, 3.773472893191284*^9}, {3.773473137183651*^9, 
  3.773473137727283*^9}},ExpressionUUID->"1951a4b5-7382-44a0-9a22-\
80a1674fbb35"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Graph", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"graph", " ", "=", " ", 
     RowBox[{"Graph", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"s", "\[Rule]", "v"}], ",", 
        RowBox[{"s", "\[Rule]", "w"}], ",", 
        RowBox[{"v", "\[Rule]", "w"}], ",", 
        RowBox[{"v", "\[Rule]", "t"}], ",", 
        RowBox[{"w", "\[Rule]", "t"}]}], "}"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Slopes", " ", "of", " ", "affine", " ", "linear", " ", "cost", " ", 
     "functions"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "1"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Offsets", " ", "of", " ", "affine", " ", "linear", " ", "cost", " ", 
     "functions"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0", ",", "1", ",", "0"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"source", " ", "=", " ", "s"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sink", " ", "=", " ", "t"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.773472897736478*^9, 3.773472904902852*^9}},
 CellLabel->
  "In[389]:=",ExpressionUUID->"f24f582e-a656-4f01-bb7a-3e778e34dc40"],

Cell[CellGroupData[{

Cell["a)", "Subsection",
 CellChangeTimes->{{3.773472964102387*^9, 
  3.773472967855503*^9}},ExpressionUUID->"1c8ba35e-2dad-4ee7-b780-\
d0c1cd9a3ddf"],

Cell[TextData[{
 "For later use, we need variables \[OpenCurlyDoubleQuote]vertices\
\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]edges\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]n\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]m\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]sourceIndex\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]sinkIndex\
\[CloseCurlyDoubleQuote], that store the list of vertices, edges of g, the \
number of vertices, the number of edges n and m, as well as the index of the \
source and the sink index. (Use the function FirstPosition[ ] to obtain the \
position of an element in a list, see also the documentation).\nFurther, we \
are going to need the Incidence-Matrix of the graph, store it in a variable \
",
 Cell[BoxData[
  FormBox["\[CapitalGamma]", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "ad3ae117-ea47-41f7-b56d-1dfebe3aa3ef"],
 ". To create a Gamma-Letter, enter [ESC] Gamma  [ESC]. "
}], "Text",
 CellChangeTimes->{{3.773472970044718*^9, 3.7734731142320557`*^9}, {
  3.773473161326529*^9, 3.773473246960184*^9}, {3.7734745927481747`*^9, 
  3.773474605795039*^9}},ExpressionUUID->"8e3cdfcb-c133-4276-8a48-\
6165a74c1505"],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
 CellChangeTimes->{{3.7734731161098967`*^9, 
  3.773473119843031*^9}},ExpressionUUID->"6310153a-7a80-460f-80fe-\
16637bc597ae"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"vertices", "=", 
   RowBox[{"VertexList", "[", "graph", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"edges", " ", "=", " ", 
   RowBox[{"EdgeList", "[", "graph", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sourceIndex", "=", 
   RowBox[{
    RowBox[{"FirstPosition", "[", 
     RowBox[{"vertices", ",", "source"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sinkIndex", "=", 
   RowBox[{
    RowBox[{"FirstPosition", "[", 
     RowBox[{"vertices", ",", "sink"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", 
   RowBox[{"VertexCount", "[", "graph", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"m", "=", 
    RowBox[{"EdgeCount", "[", "graph", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]", "=", 
   RowBox[{"IncidenceMatrix", "[", "graph", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.773473124738708*^9, 3.7734731526956873`*^9}, {
  3.773473253241839*^9, 3.7734732703038692`*^9}},
 CellLabel->
  "In[403]:=",ExpressionUUID->"6aacf704-35a7-400c-b08b-ba2e1b9ff817"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["b)", "Subsection",
 CellChangeTimes->{{3.773473073939939*^9, 3.773473076658534*^9}, {
  3.773473278347494*^9, 
  3.773473281516021*^9}},ExpressionUUID->"e4f8ec8b-038f-42df-afed-\
373b8a52239c"],

Cell[TextData[{
 "Create functions that take an edge index ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "29aecb3c-7559-4466-99da-46696d3d55c2"],
 " and a flow ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "1e5d899c-1431-43c2-9c63-77a317b78f86"],
 " and compute the (affine) costs of edge ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "d89f0e7d-256a-4078-a826-b704c9efb074"],
 ", where the cost functions are given by the coefficients a and b above, \
i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["c", "e"], "(", "x", ")"}], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["a", "e"], "x"}], "+", 
     RowBox[{
      SubscriptBox["b", "e"], "."}]}]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "b6b9baf6-6bdb-49b8-94e2-1313ebd2af63"],
 "\nCreate the integrated cost functions, i.e., ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox[
      OverscriptBox["c", "~"], "e"], "(", "x", ")"}], "=", 
    RowBox[{
     SuperscriptBox[
      SubscriptBox["\[Integral]", "0"], "x"], 
     RowBox[{
      RowBox[{
       SubscriptBox["c", "e"], "(", "t", ")"}], "dt"}]}]}], TraditionalForm]],
  
  FormatType->"TraditionalForm",ExpressionUUID->
  "94d386bc-02cf-4d48-aaae-3496e73b55cc"],
 ". (You may use the function Integrate[ ])\nFinally, create a graph that has \
the cost functions as EdgeLabels. To do so, you may first create a list that \
contains rules of the form edge -> cost(edge, x) and assign it to the option \
EdgeLabels. The output for the Braess graph given above should look something \
like\n",
 Cell[BoxData[
  GraphicsBox[
   NamespaceBox["NetworkGraphics",
    DynamicModuleBox[{Typeset`graph = HoldComplete[
      Graph[{$CellContext`s, $CellContext`v, $CellContext`w, $CellContext`t}, \
{{{1, 2}, {1, 3}, {2, 3}, {2, 4}, {3, 4}}, Null}, {
       EdgeLabels -> {
         DirectedEdge[$CellContext`v, $CellContext`w] -> 0, 
          DirectedEdge[$CellContext`s, $CellContext`v] -> $CellContext`x, 
          DirectedEdge[$CellContext`w, $CellContext`t] -> $CellContext`x, 
          DirectedEdge[$CellContext`s, $CellContext`w] -> 1, 
          DirectedEdge[$CellContext`v, $CellContext`t] -> 1}, 
        GraphLayout -> {"Dimension" -> 2}, VertexLabels -> {Automatic}}]]}, 
     TagBox[GraphicsGroupBox[{
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
         Medium], {ArrowBox[{{0., 3.}, {1., 2.}}, 0.030239520958083826`], 
          InsetBox["x", {0.5, 2.5}, ImageScaled[{0.5, 0.5}],
           BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQjQo4HGCskPM3jr6ezw7nb/KQrNhliuCL5xwUyznI
Bue3WV5cyOCM4P/dANLACufXXVKvvaSO4HPMyzvL380C588UluUyeMIM55sY
gwCCfwWkvZYJzi+UOQ5EjHC+kCAIIPgbWaM3sEYzwPkLvnjO/+L53x7Gv3cX
BP7C+bIg4wr/wPkxG0AG/IbzZ80EgZ9wPjh4zH/A+Z8PK6U+ePkNzmcHWb/h
K4IP9u8XOP9rT+yef5Wf4Xxw8NR+gvPByqd8hPMjEv1KNA58gPMh4IM9AIO9
YI0=
           "]], 0.030239520958083826`], 
          InsetBox["1", {0., 2.}, ImageScaled[{0.5, 0.5}],
           BaseStyle->"Graphics"]}, {
          ArrowBox[{{1., 2.}, {0., 1.}}, 0.030239520958083826`], 
          InsetBox["0", {0.5, 1.5}, ImageScaled[{0.5, 0.5}],
           BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7KEMBxh/+byN3dft/9vD+EkTjT6UZP+zZ4Ty
9W406d5o+guX5yle5MzY9gfO/5UI0vAbwV/iD0II9TZ3Z8mL/YTzDdWtRBJO
fIfz08DgG5y/GKz9C5z/2KIPiD7D3aOsBAKf4PKJ3NsSuLd9gPPtX062ezn5
HZy/ZzcIvIbzLUHGPX4B54N0J3A/g/ONweAxnA8OnvwHcP45/u4pjctvw90j
nnNQLOfgNbi8ZMUuU3udS3D+ivQ3j76ePw3nT7EDOfAwnP/g5bU/Gzx2wvn/
tM508rGugPNhMQcApt6NHA==
           "]], 0.030239520958083826`], 
          InsetBox["1", {1., 0.9999999999999998}, ImageScaled[{0.5, 0.5}],
           BaseStyle->"Graphics"]}, {
          ArrowBox[{{0., 1.}, {1., 0.}}, 0.030239520958083826`], 
          InsetBox["x", {0.5, 0.5}, ImageScaled[{0.5, 0.5}],
           BaseStyle->"Graphics"]}}, 
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
         0.7]}], {DiskBox[{0., 3.}, 0.030239520958083826], 
          InsetBox["s", 
           Offset[{2, 2}, {0.030239520958083826, 3.0302395209580837}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 2.}, 0.030239520958083826], 
          InsetBox["v", 
           Offset[{2, 2}, {1.030239520958084, 2.0302395209580837}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{0., 1.}, 0.030239520958083826], 
          InsetBox["w", 
           Offset[{2, 2}, {0.030239520958083826, 1.030239520958084}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.030239520958083826], 
          InsetBox["t", 
           Offset[{2, 2}, {1.030239520958084, 0.030239520958083826}], 
           ImageScaled[{0, 0}],
           BaseStyle->"Graphics"]}}}],
      MouseAppearanceTag["NetworkGraphics"]],
     AllowKernelInitialization->False]],
   DefaultBaseStyle->{
    "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
   FormatType->TraditionalForm,
   FrameTicks->None]],
  CellChangeTimes->{3.773473769106288*^9},ExpressionUUID->
  "3e289231-1621-4885-aab7-b1a43333ea1a"]
}], "Text",
 CellChangeTimes->{{3.77347340946943*^9, 3.773473541677243*^9}, {
  3.773473573447691*^9, 
  3.773473777560182*^9}},ExpressionUUID->"c4672a8d-96d7-453a-86d2-\
db50bc6cfd1b"],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
 CellChangeTimes->{{3.773473785525001*^9, 
  3.773473787777582*^9}},ExpressionUUID->"ee7e7cb8-58e2-48b1-b5f3-\
d80453c786ec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Create", " ", "cost", " ", "functions"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"e_", ",", "x_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "[", 
        RowBox[{"[", "e", "]"}], "]"}], "*", "x"}], "+", 
      RowBox[{"b", "[", 
       RowBox[{"[", "e", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Create", " ", "itegrated", " ", "cost", " ", "functios"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"cInt", "[", 
      RowBox[{"e_", ",", "x_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"e", ",", "\[Xi]"}], "]"}], ",", "\[Xi]"}], "]"}], "/.", 
      RowBox[{"\[Xi]", "\[Rule]", "x"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Print", " ", "Graph", " ", "with", " ", "cost", " ", "functions"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Input Graph with cost functions:\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"edgelabels", "=", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"edges", "[", 
         RowBox[{"[", "e", "]"}], "]"}], "\[Rule]", 
        RowBox[{"c", "[", 
         RowBox[{"e", ",", "x"}], "]"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"e", ",", "1", ",", "m"}], "}"}]}], " ", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Graph", "[", 
    RowBox[{"graph", ",", 
     RowBox[{"VertexLabels", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"EdgeLabels", "\[Rule]", "edgelabels"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellLabel->
  "In[429]:=",ExpressionUUID->"33128358-37e2-4d23-983b-2c7e110d6411"],

Cell[BoxData["\<\"Input Graph with cost functions:\"\>"], "Print",
 CellChangeTimes->{3.7734737690671597`*^9, 3.773475859579999*^9},
 CellLabel->
  "During evaluation of \
In[429]:=",ExpressionUUID->"57ab5bf6-393a-43d7-8639-6112598348d5"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{$CellContext`s, $CellContext`v, $CellContext`w, $CellContext`t}, \
{{{1, 2}, {1, 3}, {2, 3}, {2, 4}, {3, 4}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[$CellContext`v, $CellContext`w] -> 0, 
         DirectedEdge[$CellContext`s, $CellContext`v] -> $CellContext`x, 
         DirectedEdge[$CellContext`w, $CellContext`t] -> $CellContext`x, 
         DirectedEdge[$CellContext`s, $CellContext`w] -> 1, 
         DirectedEdge[$CellContext`v, $CellContext`t] -> 1}, 
       GraphLayout -> {"Dimension" -> 2}, VertexLabels -> {Automatic}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        Medium], {ArrowBox[{{0., 3.}, {1., 2.}}, 0.030239520958083826`], 
         InsetBox["x", {0.5, 2.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQjQo4HGCskPM3jr6ezw7nb/KQrNhliuCL5xwUyznI
Bue3WV5cyOCM4P/dANLACufXXVKvvaSO4HPMyzvL380C588UluUyeMIM55sY
gwCCfwWkvZYJzi+UOQ5EjHC+kCAIIPgbWaM3sEYzwPkLvnjO/+L53x7Gv3cX
BP7C+bIg4wr/wPkxG0AG/IbzZ80EgZ9wPjh4zH/A+Z8PK6U+ePkNzmcHWb/h
K4IP9u8XOP9rT+yef5Wf4Xxw8NR+gvPByqd8hPMjEv1KNA58gPMh4IM9AIO9
YI0=
          "]], 0.030239520958083826`], 
         InsetBox["1", {0., 2.}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., 2.}, {0., 1.}}, 0.030239520958083826`], 
         InsetBox["0", {0.5, 1.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7KEMBxh/+byN3dft/9vD+EkTjT6UZP+zZ4Ty
9W406d5o+guX5yle5MzY9gfO/5UI0vAbwV/iD0II9TZ3Z8mL/YTzDdWtRBJO
fIfz08DgG5y/GKz9C5z/2KIPiD7D3aOsBAKf4PKJ3NsSuLd9gPPtX062ezn5
HZy/ZzcIvIbzLUHGPX4B54N0J3A/g/ONweAxnA8OnvwHcP45/u4pjctvw90j
nnNQLOfgNbi8ZMUuU3udS3D+ivQ3j76ePw3nT7EDOfAwnP/g5bU/Gzx2wvn/
tM508rGugPNhMQcApt6NHA==
          "]], 0.030239520958083826`], 
         InsetBox["1", {1., 0.9999999999999998}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 1.}, {1., 0.}}, 0.030239520958083826`], 
         InsetBox["x", {0.5, 0.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {DiskBox[{0., 3.}, 0.030239520958083826], 
         InsetBox["s", 
          Offset[{2, 2}, {0.030239520958083826, 3.0302395209580837}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{1., 2.}, 0.030239520958083826], 
         InsetBox["v", 
          Offset[{2, 2}, {1.030239520958084, 2.0302395209580837}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{0., 1.}, 0.030239520958083826], 
         InsetBox["w", 
          Offset[{2, 2}, {0.030239520958083826, 1.030239520958084}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.030239520958083826], 
         InsetBox["t", 
          Offset[{2, 2}, {1.030239520958084, 0.030239520958083826}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{3.773473769106288*^9, 3.773475859626932*^9},
 CellLabel->
  "Out[433]=",ExpressionUUID->"33d7ff83-41ad-4961-82ca-31a1368609a2"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["c)", "Subsection",
 CellChangeTimes->{{3.773473838860752*^9, 
  3.773473843849854*^9}},ExpressionUUID->"21e9ab9f-99b8-4039-97ce-\
88d0025a8e92"],

Cell["\<\
We now want to set up the convex program to compute the Wardrop Equilibrium. \
We first create a list of flow variables:\
\>", "Text",
 CellChangeTimes->{{3.7734739304718447`*^9, 
  3.7734739925544443`*^9}},ExpressionUUID->"28447c7f-19bd-4e08-a6db-\
505096b36ebb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Create", " ", "list", " ", "of", " ", "flow"}], "-", 
    RowBox[{
    "variables", " ", "for", " ", "the", " ", "convex", " ", "program"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"flowvars", " ", "=", " ", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"f", "[", "e", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"e", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";"}]}]], "Input",\
ExpressionUUID->"48533fbd-9e92-4e89-99ba-02be4925d11c"],

Cell["\<\
Create three variables objective, flowconditions, and nonnegconditions that \
contain the objective function, and lists of flow conservation and \
non-negativity conditions.
For the objective, use the function for integrated cost from b), and use \
Total[ list ] to create the sum of an appropriate list.
The flow conservation states that the excess (sum of incoming minus outgoing \
flow) is zero (or +/- r at the sink/source). The vector of all vertex excess \
values can be computed by multiplying the incidence matrix \[CapitalGamma] \
with the flow vector (in this case the vector of flow variables). Use the \
excess vector obtained this way to set up a list of flow conservation \
constraints (use Table[ ... ])
The non-negativity constraints can be constructed as a list containing \
flowvars[e] >= 0 for every edge e.

Finally, execute the following code that should produce the following output \
for the Braess graph above.\
\>", "Text",
 CellChangeTimes->{{3.7734740188656*^9, 3.773474300009912*^9}, {
  3.773474348273226*^9, 3.773474355696015*^9}, {3.7734743960823717`*^9, 
  3.773474470344857*^9}, {3.773474550389621*^9, 
  3.773474560796035*^9}},ExpressionUUID->"af6f29ef-a4f7-46a4-9b93-\
b01e8ad37e07"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Print", " ", "the", " ", "conxex", " ", "program"}], " ", "*)"}], 
  "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", "\"\<Convex program:\>\"", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< min \>\"", ",", "objective"}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "n"}], ",", 
      RowBox[{"i", "++"}], ",", "\n", 
      RowBox[{
       RowBox[{"praefix", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", "\[Equal]", "1"}], ",", "\"\< s.t. \>\"", ",", " ", 
          "\"\<      \>\""}], "]"}]}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"praefix", ",", " ", 
         RowBox[{"flowconditions", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ";"}]}], "\n", "]"}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "m"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<      \>\"", ",", " ", 
         RowBox[{"nonnegconditions", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7734744715425377`*^9, 3.773474506409384*^9}},
 CellLabel->
  "In[423]:=",ExpressionUUID->"9472d1d5-9384-4f72-9527-1bb59d808808"],

Cell[CellGroupData[{

Cell[BoxData["\<\"Convex program:\"\>"], "Print",
 CellChangeTimes->{
  3.773474540956234*^9, {3.773475796001876*^9, 3.773475814397869*^9}},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"0653f3e4-0d2c-47bb-a2d4-70e398b7c497"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" min \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"cInt", "[", 
     RowBox[{"1", ",", 
      RowBox[{"f", "[", "1", "]"}]}], "]"}], "+", 
    RowBox[{"cInt", "[", 
     RowBox[{"2", ",", 
      RowBox[{"f", "[", "2", "]"}]}], "]"}], "+", 
    RowBox[{"cInt", "[", 
     RowBox[{"3", ",", 
      RowBox[{"f", "[", "3", "]"}]}], "]"}], "+", 
    RowBox[{"cInt", "[", 
     RowBox[{"4", ",", 
      RowBox[{"f", "[", "4", "]"}]}], "]"}], "+", 
    RowBox[{"cInt", "[", 
     RowBox[{"5", ",", 
      RowBox[{"f", "[", "5", "]"}]}], "]"}]}]}],
  SequenceForm[" min ", $CellContext`cInt[1, 
     $CellContext`f[1]] + $CellContext`cInt[2, 
     $CellContext`f[2]] + $CellContext`cInt[3, 
     $CellContext`f[3]] + $CellContext`cInt[4, 
     $CellContext`f[4]] + $CellContext`cInt[5, 
     $CellContext`f[5]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773474540956234*^9, {3.773475796001876*^9, 3.773475814408173*^9}},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"bda048b2-9e3d-405f-a5c4-a3ab7d40904a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" s.t. \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"f", "[", "1", "]"}]}], "-", 
     RowBox[{"f", "[", "2", "]"}]}], "\[Equal]", 
    RowBox[{"-", "r"}]}]}],
  SequenceForm[
  " s.t. ", -$CellContext`f[1] - $CellContext`f[2] == -$CellContext`r],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773474540956234*^9, {3.773475796001876*^9, 3.773475814417706*^9}},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"58543817-9aaa-49fe-bb57-be24f315fa3f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "1", "]"}], "-", 
     RowBox[{"f", "[", "3", "]"}], "-", 
     RowBox[{"f", "[", "4", "]"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "      ", $CellContext`f[1] - $CellContext`f[3] - $CellContext`f[4] == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773474540956234*^9, {3.773475796001876*^9, 3.7734758144248247`*^9}},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"1a53e0e1-8b00-4c35-9a4f-2ed194d1bba3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "2", "]"}], "+", 
     RowBox[{"f", "[", "3", "]"}], "-", 
     RowBox[{"f", "[", "5", "]"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "      ", $CellContext`f[2] + $CellContext`f[3] - $CellContext`f[5] == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773474540956234*^9, {3.773475796001876*^9, 3.7734758144318447`*^9}},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"5f77c0ae-bdff-4ab1-871a-fd79f618a533"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "4", "]"}], "+", 
     RowBox[{"f", "[", "5", "]"}]}], "\[Equal]", "r"}]}],
  SequenceForm[
  "      ", $CellContext`f[4] + $CellContext`f[5] == $CellContext`r],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773474540956234*^9, {3.773475796001876*^9, 3.773475814438787*^9}},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"f2c2e4ac-4db0-4c68-83b4-dc65599c1b63"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "\[GreaterEqual]", "0"}]}],
  SequenceForm["      ", $CellContext`f[1] >= 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773474540956234*^9, {3.773475796001876*^9, 3.773475814445713*^9}},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"911dfb0f-64fa-4401-a01d-f6970116725b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "\[GreaterEqual]", "0"}]}],
  SequenceForm["      ", $CellContext`f[2] >= 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773474540956234*^9, {3.773475796001876*^9, 3.7734758144526043`*^9}},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"afa4acae-0150-478e-b109-97d59f83455a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "\[GreaterEqual]", "0"}]}],
  SequenceForm["      ", $CellContext`f[3] >= 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773474540956234*^9, {3.773475796001876*^9, 3.7734758144596977`*^9}},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"72e5b1d7-afba-41f0-9136-fa18c30e0ede"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"f", "[", "4", "]"}], "\[GreaterEqual]", "0"}]}],
  SequenceForm["      ", $CellContext`f[4] >= 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773474540956234*^9, {3.773475796001876*^9, 3.7734758144667177`*^9}},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"cc88a1dd-8fb3-4fd8-afc6-98c92eb5c48e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"f", "[", "5", "]"}], "\[GreaterEqual]", "0"}]}],
  SequenceForm["      ", $CellContext`f[5] >= 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773474540956234*^9, {3.773475796001876*^9, 3.773475814473648*^9}},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"272494b0-6730-4abc-8af9-d11df078af09"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution", "Subsubsection",
 CellChangeTimes->{{3.773474511625749*^9, 
  3.773474514991243*^9}},ExpressionUUID->"d3bf77a1-d74e-41d1-92c4-\
4a73db76a3bd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Create", " ", "list", " ", "of", " ", "flow"}], "-", 
    RowBox[{
    "variables", " ", "for", " ", "the", " ", "convex", " ", "program"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"flowvars", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"f", "[", "e", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"e", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Create", " ", "the", " ", "objective", " ", "function"}], " ", 
     "\[Equal]", " ", 
     RowBox[{
     "Sum", " ", "over", " ", "all", " ", "iterated", " ", "cost", " ", 
      "functios"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"objective", "=", 
     RowBox[{"Total", "[", 
      RowBox[{"Table", "[", " ", 
       RowBox[{
        RowBox[{"cInt", "[", 
         RowBox[{"e", ",", 
          RowBox[{"flowvars", "[", 
           RowBox[{"[", "e", "]"}], "]"}]}], "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"e", ",", "1", ",", "m"}], "}"}]}], " ", "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Create", " ", "flow", " ", "conditions"}], ",", " ", 
     RowBox[{"i", ".", "e"}], ",", " ", 
     RowBox[{"excess", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"-", "r"}], " ", "/", " ", 
          RowBox[{"+", "r"}]}], " ", "/", " ", "0"}], " ", "for", " ", "v"}], 
       " ", "=", " ", 
       RowBox[{
        RowBox[{"s", " ", "/", " ", "t"}], " ", "/", " ", "otherwise"}]}]}]}],
     " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"\[Rule]", " ", 
     RowBox[{
     "Compute", " ", "the", " ", "excess", " ", "vector", " ", "containing", 
      " ", "the", " ", "excess", " ", "of", " ", "all", " ", "vertices", " ", 
      "depending", " ", "on", " ", "the", " ", "flow", " ", "definded", " ", 
      "by", " ", "flowvars"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"excess", "=", 
     RowBox[{"\[CapitalGamma]", ".", "flowvars"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"\[Rule]", " ", 
     RowBox[{
     "Create", " ", "a", " ", "list", " ", "of", " ", "flow", " ", 
      "conservation", " ", "rules"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"flowconditions", "=", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"excess", "[", 
         RowBox[{"[", "v", "]"}], "]"}], "\[Equal]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"v", "\[Equal]", "sourceIndex"}], ",", 
          RowBox[{"-", "r"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"v", "\[Equal]", "sinkIndex"}], ",", "r", ",", "0"}], 
           "]"}]}], "]"}]}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Create", " ", "non"}], "-", 
      RowBox[{"negativity", " ", "constraints", " ", 
       RowBox[{"f", "[", "e", "]"}]}]}], "\[GreaterEqual]", "0"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nonnegconditions", "=", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"flowvars", "[", 
         RowBox[{"[", "e", "]"}], "]"}], "\[GreaterEqual]", "0"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"e", ",", "1", ",", "m"}], "}"}]}], " ", "]"}]}], ";"}], "\n",
    "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Print", " ", "the", " ", "conxex", " ", "program"}], " ", "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Convex program:\>\"", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< min \>\"", ",", "objective"}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "n"}], ",", 
      RowBox[{"i", "++"}], ",", "\n", 
      RowBox[{
       RowBox[{"praefix", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", "\[Equal]", "1"}], ",", "\"\< s.t. \>\"", ",", " ", 
          "\"\<      \>\""}], "]"}]}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{"praefix", ",", " ", 
         RowBox[{"flowconditions", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ";"}]}], "\n", "]"}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "m"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<      \>\"", ",", " ", 
         RowBox[{"nonnegconditions", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.77347453059972*^9, 3.773474533146081*^9}},
 CellLabel->
  "In[414]:=",ExpressionUUID->"947d09ac-e3c7-4b9e-89ff-5c4fec079174"],

Cell[CellGroupData[{

Cell[BoxData["\<\"Convex program:\"\>"], "Print",
 CellChangeTimes->{
  3.77347453445835*^9, {3.773475784040945*^9, 3.7734758107250423`*^9}},
 CellLabel->
  "During evaluation of \
In[414]:=",ExpressionUUID->"eff3a44c-3c55-4817-8b08-f674eb73de9b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" min \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"cInt", "[", 
     RowBox[{"1", ",", 
      RowBox[{"f", "[", "1", "]"}]}], "]"}], "+", 
    RowBox[{"cInt", "[", 
     RowBox[{"2", ",", 
      RowBox[{"f", "[", "2", "]"}]}], "]"}], "+", 
    RowBox[{"cInt", "[", 
     RowBox[{"3", ",", 
      RowBox[{"f", "[", "3", "]"}]}], "]"}], "+", 
    RowBox[{"cInt", "[", 
     RowBox[{"4", ",", 
      RowBox[{"f", "[", "4", "]"}]}], "]"}], "+", 
    RowBox[{"cInt", "[", 
     RowBox[{"5", ",", 
      RowBox[{"f", "[", "5", "]"}]}], "]"}]}]}],
  SequenceForm[" min ", $CellContext`cInt[1, 
     $CellContext`f[1]] + $CellContext`cInt[2, 
     $CellContext`f[2]] + $CellContext`cInt[3, 
     $CellContext`f[3]] + $CellContext`cInt[4, 
     $CellContext`f[4]] + $CellContext`cInt[5, 
     $CellContext`f[5]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.77347453445835*^9, {3.773475784040945*^9, 3.773475810745425*^9}},
 CellLabel->
  "During evaluation of \
In[414]:=",ExpressionUUID->"1c619efc-a131-448e-952e-910ee3390722"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" s.t. \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"f", "[", "1", "]"}]}], "-", 
     RowBox[{"f", "[", "2", "]"}]}], "\[Equal]", 
    RowBox[{"-", "r"}]}]}],
  SequenceForm[
  " s.t. ", -$CellContext`f[1] - $CellContext`f[2] == -$CellContext`r],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.77347453445835*^9, {3.773475784040945*^9, 3.77347581075453*^9}},
 CellLabel->
  "During evaluation of \
In[414]:=",ExpressionUUID->"619d1b1f-c533-408a-93f9-104393a9eb3e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "1", "]"}], "-", 
     RowBox[{"f", "[", "3", "]"}], "-", 
     RowBox[{"f", "[", "4", "]"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "      ", $CellContext`f[1] - $CellContext`f[3] - $CellContext`f[4] == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.77347453445835*^9, {3.773475784040945*^9, 3.773475810760138*^9}},
 CellLabel->
  "During evaluation of \
In[414]:=",ExpressionUUID->"ab290010-285c-4bfc-a5e1-0179b5022c18"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "2", "]"}], "+", 
     RowBox[{"f", "[", "3", "]"}], "-", 
     RowBox[{"f", "[", "5", "]"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "      ", $CellContext`f[2] + $CellContext`f[3] - $CellContext`f[5] == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.77347453445835*^9, {3.773475784040945*^9, 3.773475810765417*^9}},
 CellLabel->
  "During evaluation of \
In[414]:=",ExpressionUUID->"d4bce235-041d-455d-8ef9-74fe0568bc7c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "4", "]"}], "+", 
     RowBox[{"f", "[", "5", "]"}]}], "\[Equal]", "r"}]}],
  SequenceForm[
  "      ", $CellContext`f[4] + $CellContext`f[5] == $CellContext`r],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.77347453445835*^9, {3.773475784040945*^9, 3.773475810770626*^9}},
 CellLabel->
  "During evaluation of \
In[414]:=",ExpressionUUID->"13c68e78-5341-4135-af4d-359ec24c2dce"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"f", "[", "1", "]"}], "\[GreaterEqual]", "0"}]}],
  SequenceForm["      ", $CellContext`f[1] >= 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.77347453445835*^9, {3.773475784040945*^9, 3.773475810775839*^9}},
 CellLabel->
  "During evaluation of \
In[414]:=",ExpressionUUID->"4e860df8-7d82-4c28-9fcb-163b7facccdb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"f", "[", "2", "]"}], "\[GreaterEqual]", "0"}]}],
  SequenceForm["      ", $CellContext`f[2] >= 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.77347453445835*^9, {3.773475784040945*^9, 3.773475810780904*^9}},
 CellLabel->
  "During evaluation of \
In[414]:=",ExpressionUUID->"85065b59-c8f5-4f2c-8b5e-f620d1e85379"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"f", "[", "3", "]"}], "\[GreaterEqual]", "0"}]}],
  SequenceForm["      ", $CellContext`f[3] >= 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.77347453445835*^9, {3.773475784040945*^9, 3.773475810786038*^9}},
 CellLabel->
  "During evaluation of \
In[414]:=",ExpressionUUID->"e586790c-8503-46f6-8048-af06734a54ff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"f", "[", "4", "]"}], "\[GreaterEqual]", "0"}]}],
  SequenceForm["      ", $CellContext`f[4] >= 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.77347453445835*^9, {3.773475784040945*^9, 3.7734758107911377`*^9}},
 CellLabel->
  "During evaluation of \
In[414]:=",ExpressionUUID->"701edd28-a3e2-4836-b086-18981a6aecbb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"f", "[", "5", "]"}], "\[GreaterEqual]", "0"}]}],
  SequenceForm["      ", $CellContext`f[5] >= 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.77347453445835*^9, {3.773475784040945*^9, 3.773475810796281*^9}},
 CellLabel->
  "During evaluation of \
In[414]:=",ExpressionUUID->"e72aeac6-271a-41c3-b4d1-f6a951f35cca"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
WindowSize->{808, 857},
WindowMargins->{{Automatic, 360}, {-52, Automatic}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 166, 3, 98, "Title",ExpressionUUID->"d0a18a2b-fbb1-4c83-92bb-5fbc0dbe2fde"],
Cell[749, 27, 1706, 50, 171, "Text",ExpressionUUID->"df5b0a0c-8df5-4ab6-99bd-3ddef197ae55"],
Cell[CellGroupData[{
Cell[2480, 81, 155, 3, 67, "Section",ExpressionUUID->"e60213ab-e900-4b9d-b7d5-dd82c6d652d8"],
Cell[2638, 86, 689, 12, 81, "Text",ExpressionUUID->"ecc5b2f2-3ecd-427c-9499-f9467cbda2c9"],
Cell[3330, 100, 5521, 107, 293, "Input",ExpressionUUID->"c49f4346-c988-4e43-8def-f12833743e9b"],
Cell[8854, 209, 585, 17, 73, "Input",ExpressionUUID->"24371248-d405-41eb-8f49-ded8d85ea4c0"],
Cell[CellGroupData[{
Cell[9464, 230, 156, 3, 54, "Subsection",ExpressionUUID->"d905f599-adbf-4a98-b5c5-beedf4c01ee7"],
Cell[CellGroupData[{
Cell[9645, 237, 1971, 47, 136, "Input",ExpressionUUID->"8422b6ac-f7e2-4603-89c3-368276ba90cd"],
Cell[11619, 286, 5940, 114, 297, "Output",ExpressionUUID->"5dffb88b-3a38-4126-93bc-ff70430cc9fa"],
Cell[17562, 402, 2135, 42, 391, "Output",ExpressionUUID->"0abdc73a-d0fe-4154-bfb4-3c81e07b9719"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[19758, 451, 155, 3, 53, "Section",ExpressionUUID->"bea4ab9e-c4cc-41d0-a996-42d51dd3988b"],
Cell[19916, 456, 409, 8, 58, "Text",ExpressionUUID->"1951a4b5-7382-44a0-9a22-80a1674fbb35"],
Cell[20328, 466, 1473, 39, 199, "Input",ExpressionUUID->"f24f582e-a656-4f01-bb7a-3e778e34dc40"],
Cell[CellGroupData[{
Cell[21826, 509, 150, 3, 54, "Subsection",ExpressionUUID->"1c8ba35e-2dad-4ee7-b780-d0c1cd9a3ddf"],
Cell[21979, 514, 1208, 22, 150, "Text",ExpressionUUID->"8e3cdfcb-c133-4276-8a48-6165a74c1505"],
Cell[CellGroupData[{
Cell[23212, 540, 161, 3, 45, "Subsubsection",ExpressionUUID->"6310153a-7a80-460f-80fe-16637bc597ae"],
Cell[23376, 545, 1255, 34, 178, "Input",ExpressionUUID->"6aacf704-35a7-400c-b08b-ba2e1b9ff817"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[24680, 585, 199, 4, 38, "Subsection",ExpressionUUID->"e4f8ec8b-038f-42df-afed-373b8a52239c"],
Cell[24882, 591, 5492, 123, 586, "Text",ExpressionUUID->"c4672a8d-96d7-453a-86d2-db50bc6cfd1b"],
Cell[CellGroupData[{
Cell[30399, 718, 159, 3, 45, "Subsubsection",ExpressionUUID->"ee7e7cb8-58e2-48b1-b5f3-d80453c786ec"],
Cell[CellGroupData[{
Cell[30583, 725, 1934, 55, 220, "Input",ExpressionUUID->"33128358-37e2-4d23-983b-2c7e110d6411"],
Cell[32520, 782, 238, 4, 24, "Print",ExpressionUUID->"57ab5bf6-393a-43d7-8639-6112598348d5"],
Cell[32761, 788, 3546, 68, 449, "Output",ExpressionUUID->"33d7ff83-41ad-4961-82ca-31a1368609a2"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[36368, 863, 150, 3, 38, "Subsection",ExpressionUUID->"21e9ab9f-99b8-4039-97ce-88d0025a8e92"],
Cell[36521, 868, 274, 6, 58, "Text",ExpressionUUID->"28447c7f-19bd-4e08-a6db-505096b36ebb"],
Cell[36798, 876, 543, 15, 52, "Input",ExpressionUUID->"48533fbd-9e92-4e89-99ba-02be4925d11c"],
Cell[37344, 893, 1228, 22, 265, "Text",ExpressionUUID->"af6f29ef-a4f7-46a4-9b93-b01e8ad37e07"],
Cell[CellGroupData[{
Cell[38597, 919, 1529, 42, 220, "Input",ExpressionUUID->"9472d1d5-9384-4f72-9527-1bb59d808808"],
Cell[CellGroupData[{
Cell[40151, 965, 246, 5, 24, "Print",ExpressionUUID->"0653f3e4-0d2c-47bb-a2d4-70e398b7c497"],
Cell[40400, 972, 1088, 30, 24, "Print",ExpressionUUID->"bda048b2-9e3d-405f-a5c4-a3ab7d40904a"],
Cell[41491, 1004, 564, 16, 24, "Print",ExpressionUUID->"58543817-9aaa-49fe-bb57-be24f315fa3f"],
Cell[42058, 1022, 570, 15, 24, "Print",ExpressionUUID->"1a53e0e1-8b00-4c35-9a4f-2ed194d1bba3"],
Cell[42631, 1039, 570, 15, 24, "Print",ExpressionUUID->"5f77c0ae-bdff-4ab1-871a-fd79f618a533"],
Cell[43204, 1056, 520, 14, 24, "Print",ExpressionUUID->"f2c2e4ac-4db0-4c68-83b4-dc65599c1b63"],
Cell[43727, 1072, 434, 11, 24, "Print",ExpressionUUID->"911dfb0f-64fa-4401-a01d-f6970116725b"],
Cell[44164, 1085, 436, 11, 24, "Print",ExpressionUUID->"afa4acae-0150-478e-b109-97d59f83455a"],
Cell[44603, 1098, 436, 11, 24, "Print",ExpressionUUID->"72e5b1d7-afba-41f0-9136-fa18c30e0ede"],
Cell[45042, 1111, 436, 11, 24, "Print",ExpressionUUID->"cc88a1dd-8fb3-4fd8-afc6-98c92eb5c48e"],
Cell[45481, 1124, 434, 11, 24, "Print",ExpressionUUID->"272494b0-6730-4abc-8af9-d11df078af09"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[45964, 1141, 159, 3, 45, "Subsubsection",ExpressionUUID->"d3bf77a1-d74e-41d1-92c4-4a73db76a3bd"],
Cell[CellGroupData[{
Cell[46148, 1148, 5247, 141, 556, "Input",ExpressionUUID->"947d09ac-e3c7-4b9e-89ff-5c4fec079174"],
Cell[CellGroupData[{
Cell[51420, 1293, 247, 5, 24, "Print",ExpressionUUID->"eff3a44c-3c55-4817-8b08-f674eb73de9b"],
Cell[51670, 1300, 1087, 30, 24, "Print",ExpressionUUID->"1c619efc-a131-448e-952e-910ee3390722"],
Cell[52760, 1332, 562, 16, 24, "Print",ExpressionUUID->"619d1b1f-c533-408a-93f9-104393a9eb3e"],
Cell[53325, 1350, 567, 15, 24, "Print",ExpressionUUID->"ab290010-285c-4bfc-a5e1-0179b5022c18"],
Cell[53895, 1367, 567, 15, 24, "Print",ExpressionUUID->"d4bce235-041d-455d-8ef9-74fe0568bc7c"],
Cell[54465, 1384, 519, 14, 24, "Print",ExpressionUUID->"13c68e78-5341-4135-af4d-359ec24c2dce"],
Cell[54987, 1400, 433, 11, 24, "Print",ExpressionUUID->"4e860df8-7d82-4c28-9fcb-163b7facccdb"],
Cell[55423, 1413, 433, 11, 24, "Print",ExpressionUUID->"85065b59-c8f5-4f2c-8b5e-f620d1e85379"],
Cell[55859, 1426, 433, 11, 24, "Print",ExpressionUUID->"e586790c-8503-46f6-8048-af06734a54ff"],
Cell[56295, 1439, 435, 11, 24, "Print",ExpressionUUID->"701edd28-a3e2-4836-b086-18981a6aecbb"],
Cell[56733, 1452, 433, 11, 24, "Print",ExpressionUUID->"e72aeac6-271a-41c3-b4d1-f6a951f35cca"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

