(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     43282,       1209]
NotebookOptionsPosition[     35790,       1083]
NotebookOutlinePosition[     36145,       1099]
CellTagsIndexPosition[     36102,       1096]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Session 2 - Solving Equations and Inequalities ", "Title",
 CellChangeTimes->{{3.7733778750473146`*^9, 
  3.773377886471238*^9}},ExpressionUUID->"24707d61-6bb5-49c1-ac9b-\
b52b1328ef31"],

Cell[CellGroupData[{

Cell["Rules and Replacement", "Section",
 CellChangeTimes->{{3.773377893990649*^9, 
  3.773377899962494*^9}},ExpressionUUID->"5fb229e9-4fd0-4a65-9545-\
1a406dd5b076"],

Cell["\<\
A rule is a directive to transform expressions into other expression. Rules \
are denoted by lhs -> rhs meaning that lhs is transformed into rhs. Rules are \
applied by the functions Replace or ReplaceAll\
\>", "Text",
 CellChangeTimes->{{3.7733781155685873`*^9, 
  3.773378247322362*^9}},ExpressionUUID->"dd669644-310c-49b9-9531-\
10a03fa42f86"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "A", " ", "rule", " ", "specifying", " ", "to", " ", "replace", " ", "x", 
    " ", "by", " ", "42"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"x", "\[Rule]", "42"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "The", " ", "function", " ", "ReplaceAll", " ", "applies", " ", "a", " ", 
     "rule", " ", "to", " ", "some", " ", "expression"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ReplaceAll", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "^", "2"}], "+", "x", "+", "2"}], ",", 
     RowBox[{"x", "\[Rule]", "2"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "The", " ", "shortform", " ", "for", " ", "ReplaceAll", " ", "is", " ", 
      "expression"}], " ", "/.", " ", "rule"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "^", "2"}], " ", "+", " ", "x", " ", "+", " ", "2"}], " ", "/.", 
    RowBox[{"x", "\[Rule]", "2"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Use", " ", "lists", " ", "of", " ", "rules", " ", "to", " ", "replace", 
     " ", "many", " ", "variables"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "^", "2"}], "+", 
     RowBox[{"2", "y"}], "-", "5"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "\[Rule]", "1"}], ",", 
      RowBox[{"y", "\[Rule]", 
       RowBox[{"Log", "[", "42", "]"}]}]}], "}"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Change", " ", "a", " ", "name", " ", "of", " ", "a", " ", "variable", 
     " ", "by", " ", "using", " ", "a", " ", "rule"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], "+", "x"}], "/.", 
    RowBox[{"x", "\[Rule]", "\[Xi]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.773378253960444*^9, 3.7733785084328012`*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"cd82bea5-1074-435d-aa49-c0ebd69ee013"],

Cell[BoxData[
 RowBox[{"x", "\[Rule]", "42"}]], "Output",
 CellChangeTimes->{3.773378343847938*^9, 3.773378414313953*^9, 
  3.773378476641362*^9, 3.773378509799559*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"1b06e7d3-bb76-4aa9-a4fb-049f74557c48"],

Cell[BoxData["8"], "Output",
 CellChangeTimes->{3.773378343847938*^9, 3.773378414313953*^9, 
  3.773378476641362*^9, 3.773378509811273*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"13717a09-07ef-47eb-8b64-0b69101586f0"],

Cell[BoxData["8"], "Output",
 CellChangeTimes->{3.773378343847938*^9, 3.773378414313953*^9, 
  3.773378476641362*^9, 3.773378509815218*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"0b45855d-73eb-4dae-9620-20fa9bbb69cd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "4"}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"Log", "[", "42", "]"}]}]}]], "Output",
 CellChangeTimes->{3.773378343847938*^9, 3.773378414313953*^9, 
  3.773378476641362*^9, 3.773378509818741*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"00a346d1-dc0f-4368-b78e-92141779f6ed"],

Cell[BoxData[
 RowBox[{"\[Xi]", "+", 
  RowBox[{"Sin", "[", "\[Xi]", "]"}]}]], "Output",
 CellChangeTimes->{3.773378343847938*^9, 3.773378414313953*^9, 
  3.773378476641362*^9, 3.773378509822246*^9},
 CellLabel->"Out[16]=",ExpressionUUID->"a099f9ef-cc93-47c0-8745-c73bb98a5250"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving Equations", "Section",
 CellChangeTimes->{{3.773378526689699*^9, 3.7733785380926647`*^9}, 
   3.7733792900703287`*^9},ExpressionUUID->"41c3f542-7c63-401e-bd0e-\
6218073d9fa1"],

Cell[CellGroupData[{

Cell["Basic Equation Solving", "Subsection",
 CellChangeTimes->{{3.773379396824471*^9, 
  3.773379407551343*^9}},ExpressionUUID->"53d6b442-c765-4b47-8ca7-\
b1eee8d76e5e"],

Cell["\<\
The Solve[ ] function can be used to solve equations and systems of \
equations, with or without side constraints. The basic usage of Solve is \
Solve[ eqn, variable ]. Equations are denoted with ==\
\>", "Text",
 CellChangeTimes->{{3.77337855942799*^9, 3.773378656040303*^9}, {
  3.7733786877883797`*^9, 
  3.773378696282207*^9}},ExpressionUUID->"f7293dea-87f4-4327-8930-\
fcfc526a6cf9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Solve", " ", "a", " ", "simple"}], ",", " ", 
    RowBox[{"linear", " ", "equation", " ", "for", " ", "x"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "+", "5"}], "\[Equal]", "3"}], ",", "x"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "If", " ", "there", " ", "is", " ", "only", " ", "one", " ", 
      "variable"}], ",", " ", 
     RowBox[{
     "the", " ", "second", " ", "parameter", " ", "can", " ", "be", " ", 
      "omitted"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"x", "+", "5"}], "\[Equal]", "3"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.773378659824749*^9, 3.773378704337352*^9}, {
  3.773378804554983*^9, 3.773378833046123*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"da707750-af3e-4caa-a2b6-2d3b1ce82581"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    RowBox[{"-", "2"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.7733787048718567`*^9, 3.773378833668436*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"4b3238a8-34c3-4019-94f6-7bcd1dd247ea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    RowBox[{"-", "2"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.7733787048718567`*^9, 3.773378833677589*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"6e403d82-a4e3-4ad3-b2a6-7dfedfc7bea1"]
}, Open  ]],

Cell["\<\
The Solve[ ] function returns a list of list of the following form:
result = { solution1, solution2, ... }
where every solution is a again a list of rules for every variable \
\>", "Text",
 CellChangeTimes->{{3.773378841033958*^9, 
  3.773378935995187*^9}},ExpressionUUID->"d104cddb-a8c5-4196-bdc5-\
d8c5426519c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Solving", " ", "an", " ", "equation", " ", "with", " ", "multiple", " ", 
    "solutions"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"x", "^", "3"}], "-", 
      RowBox[{"2", 
       RowBox[{"x", "^", "2"}]}], "-", "x"}], "\[Equal]", 
     RowBox[{"-", "2"}]}], ",", "x"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7733786735156937`*^9, 3.773378674040441*^9}, {
  3.773378940855166*^9, 3.773379009076172*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"d7fc0d69-e37f-43b6-a57d-e9e3427b4c89"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"-", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.773379009996817*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"f0be1466-573f-4fae-af09-eff13cd86f20"]
}, Open  ]],

Cell["\<\
To solve systems of equations (or inequalities), use a list of equations in \
the first argument.\
\>", "Text",
 CellChangeTimes->{{3.7733791694512053`*^9, 3.773379213558041*^9}, 
   3.7733948710258617`*^9},ExpressionUUID->"986ec7d5-4e30-4500-bdf0-\
875449d85a89"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Solve", " ", "a", " ", "system", " ", "of", " ", "two", " ", "linear", 
    " ", "equations", " ", "for", " ", "two", " ", "varibles"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "+", "y"}], "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{"x", "-", "y"}], "\[Equal]", "3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Solve", " ", "an", " ", "equation", " ", "with", " ", "a", " ", "side", 
     " ", "constraint"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"x", "^", "3"}], "-", 
         RowBox[{"2", 
          RowBox[{"x", "^", "2"}]}], "-", "x"}], "\[Equal]", 
        RowBox[{"-", "2"}]}], ",", 
       RowBox[{"x", "\[GreaterEqual]", "0"}]}], "}"}], ",", "x"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.773379215508884*^9, 3.773379275074004*^9}, {
  3.773379319212789*^9, 3.77337936251016*^9}},
 CellLabel->"In[29]:=",ExpressionUUID->"0b1c5799-0d6b-4e7c-adc8-26d36f355c45"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", "2"}], ",", 
    RowBox[{"y", "\[Rule]", 
     RowBox[{"-", "1"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.773379363211603*^9},
 CellLabel->"Out[29]=",ExpressionUUID->"7098e7cd-7093-47f9-92a3-bd2034749967"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.773379363216267*^9},
 CellLabel->"Out[30]=",ExpressionUUID->"cb7a239a-a154-4a86-997d-c1889ae15af3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Using the results of Solve", "Subsection",
 CellChangeTimes->{{3.77337941178023*^9, 
  3.773379421729018*^9}},ExpressionUUID->"28f10610-8b84-466a-8687-\
83f5e8562d63"],

Cell["\<\
The result of solve are lists of lists of rules that can be used to plug in \
the result values in new equations.\
\>", "Text",
 CellChangeTimes->{{3.773379458557797*^9, 
  3.77337949621491*^9}},ExpressionUUID->"b39e6d02-d7f1-4ed4-873b-\
569ead34fdda"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "To", " ", "extract", " ", "the", " ", "solution", " ", "values"}], ",", 
    " ", 
    RowBox[{"apply", " ", "the", " ", "returned", " ", "rules"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"solution", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"x", "^", "3"}], "-", 
         RowBox[{"2", 
          RowBox[{"x", "^", "2"}]}], "-", "x"}], "\[Equal]", 
        RowBox[{"-", "2"}]}], ",", "x"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"x", "/.", "solution"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "If", " ", "just", " ", "one", " ", "sultion", " ", "is", " ", 
      "needed"}], ",", " ", "use", ",", " ", 
     RowBox[{"e", ".", "g", "."}], ",", " ", "First"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solution", "=", 
     RowBox[{"First", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"x", "^", "3"}], "-", 
          RowBox[{"2", 
           RowBox[{"x", "^", "2"}]}], "-", "x"}], "\[Equal]", 
         RowBox[{"-", "2"}]}], ",", "x"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"x", "/.", "solution"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "The", " ", "results", " ", "can", " ", "be", " ", "plugged", " ", "in", 
     " ", "directly", " ", "into", " ", "other", " ", "equations"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solution", " ", "=", " ", 
     RowBox[{"First", "[", 
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "+", "y"}], "\[Equal]", "1"}], ",", 
          RowBox[{
           RowBox[{"x", "-", "y"}], "\[Equal]", "3"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"42", "*", 
     RowBox[{"(", 
      RowBox[{"x", "+", "y"}], ")"}]}], "/.", "solution"}]}]}]], "Input",
 CellChangeTimes->{{3.773379529625348*^9, 3.773379559251658*^9}, {
  3.773379637635702*^9, 3.773379677220468*^9}, {3.773379708803043*^9, 
  3.7733797937495823`*^9}},
 CellLabel->"In[43]:=",ExpressionUUID->"9f68369f-1c08-4551-9d62-0180026a3ef6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1"}], ",", "1", ",", "2"}], "}"}]], "Output",
 CellChangeTimes->{
  3.773379559914938*^9, 3.773379666804241*^9, {3.773379775529942*^9, 
   3.773379794572921*^9}},
 CellLabel->"Out[44]=",ExpressionUUID->"1bb89562-3e1e-4b1a-b82f-dc9cdf876313"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{
  3.773379559914938*^9, 3.773379666804241*^9, {3.773379775529942*^9, 
   3.773379794585062*^9}},
 CellLabel->"Out[46]=",ExpressionUUID->"c953a82f-bd28-4197-a2c4-49993259662d"],

Cell[BoxData["42"], "Output",
 CellChangeTimes->{
  3.773379559914938*^9, 3.773379666804241*^9, {3.773379775529942*^9, 
   3.77337979458916*^9}},
 CellLabel->"Out[48]=",ExpressionUUID->"c225448b-2920-4820-88fe-f892e8824a60"]
}, Open  ]],

Cell["\<\
If a system has no solution, an empty list is returned. If a system has \
infinitely many solution, all of them are returned (if not all variables are \
determined by, a warning is stated)\
\>", "Text",
 CellChangeTimes->{{3.77337985017232*^9, 3.773379880853261*^9}, {
  3.773379911056465*^9, 3.773379950631736*^9}, {3.773394910364609*^9, 
  3.7733949127720213`*^9}},ExpressionUUID->"798e0c02-2e51-4bf4-b002-\
28785056c248"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"A", " ", "system", " ", "with", " ", "no", " ", "solution"}], " ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "+", "3"}], ")"}], "^", "2"}], "\[Equal]", "2"}], ",", 
       
       RowBox[{"x", "\[GreaterEqual]", "0"}]}], "}"}], ",", "x"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "A", " ", "system", " ", "with", " ", "infitely", " ", "many", " ", 
     "solutions"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], "\[Equal]", "0"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "A", " ", "system", " ", "with", " ", "redundant", " ", "equalities"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "+", "y"}], "\[Equal]", "1"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"2", "x"}], "+", 
         RowBox[{"2", "y"}]}], "\[Equal]", "2"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.773379953943048*^9, 3.77337996265803*^9}, {
  3.773380326721737*^9, 3.7733803273426113`*^9}, {3.773380396700532*^9, 
  3.7733804509807577`*^9}, {3.773394957248973*^9, 
  3.77339496273446*^9}},ExpressionUUID->"1b0f66ea-afff-426e-bd60-\
9690648e4908"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.7733804523215714`*^9},
 CellLabel->"Out[55]=",ExpressionUUID->"1936c090-668c-4236-a8a7-1a443d4a3e81"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{"2", " ", "\[Pi]", " ", 
        RowBox[{"C", "[", "1", "]"}]}], ",", 
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], "\[Element]", 
        TemplateBox[{},
         "Integers"]}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{"\[Pi]", "+", 
        RowBox[{"2", " ", "\[Pi]", " ", 
         RowBox[{"C", "[", "1", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"C", "[", "1", "]"}], "\[Element]", 
        TemplateBox[{},
         "Integers"]}]}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.773380452326186*^9},
 CellLabel->"Out[56]=",ExpressionUUID->"1f809b4f-426b-4256-91bb-7f662a8bb4b2"],

Cell[BoxData[
 TemplateBox[{
  "Solve","svars",
   "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
   57,3,22788172953567579777,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7733804523303556`*^9},
 CellLabel->
  "During evaluation of \
In[55]:=",ExpressionUUID->"3a975fe4-e41c-4da3-8089-b72a8331eb0e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"y", "\[Rule]", 
    RowBox[{"1", "-", "x"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.7733804523468313`*^9},
 CellLabel->"Out[57]=",ExpressionUUID->"5c1b1733-3f4b-4e7a-b5b7-8d60862932e7"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Advanced solve options ", "Subsection",
 CellChangeTimes->{{3.773380511443153*^9, 
  3.77338053119351*^9}},ExpressionUUID->"760df842-4a67-470e-9080-\
bcfb85c10b63"],

Cell["\<\
The third argument of Solve can be used to specify a domain (which can be \
Reals, Integers or Complexes)\
\>", "Text",
 CellChangeTimes->{{3.7733806562932673`*^9, 3.7733806892801647`*^9}, {
  3.773380802861228*^9, 
  3.773380812120131*^9}},ExpressionUUID->"bb40ca21-d14d-4dad-8358-\
5ef4a7742e31"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "^", "3"}], "-", 
     RowBox[{"x", "^", "2"}], "+", "x"}], "\[Equal]", "1"}], ",", "x"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"x", "^", "3"}], "-", 
     RowBox[{"x", "^", "2"}], "+", "x"}], "\[Equal]", "1"}], ",", "x", ",", 
   "Reals"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"x", "^", "2"}], "\[Equal]", "a"}], ",", "x", ",", "Reals"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.7733807414292297`*^9, 3.773380845657337*^9}},
 CellLabel->"In[62]:=",ExpressionUUID->"06a64cde-277f-49d9-b04a-16de75a803fe"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"-", "\[ImaginaryI]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", "\[ImaginaryI]"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.773380814711746*^9, 3.773380846164839*^9}},
 CellLabel->"Out[62]=",ExpressionUUID->"c77235fe-6f7a-4526-b3fa-704e8afb8c64"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", "1"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.773380814711746*^9, 3.773380846176908*^9}},
 CellLabel->"Out[63]=",ExpressionUUID->"821f3770-c896-447e-bb89-1e73763b19a6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["a"]}], ",", 
       RowBox[{"a", ">", "0"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       SqrtBox["a"], ",", 
       RowBox[{"a", ">", "0"}]}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.773380814711746*^9, 3.7733808461813307`*^9}},
 CellLabel->"Out[64]=",ExpressionUUID->"4d882aa8-8bb8-42f1-9584-5edbffac727f"]
}, Open  ]],

Cell["\<\
If an equation has many solutions, but only one instance is needed, the \
function FindInstance may be helpful\
\>", "Text",
 CellChangeTimes->{{3.773380999452713*^9, 
  3.7733810291466503`*^9}},ExpressionUUID->"ab65b9dd-33ae-4bc4-af0d-\
4695d0f77c76"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"A", " ", "system", " ", "with", " ", "many", " ", "solutions"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "^", "2"}], "-", 
        RowBox[{"3", 
         RowBox[{"y", "^", "2"}]}]}], "\[Equal]", "1"}], "&&", 
      RowBox[{"10", "<", "x", "<", "100"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Returns", " ", "some", " ", "integer", " ", "solution", " ", "of", " ", 
     "the", " ", "system", " ", "above"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"FindInstance", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "^", "2"}], "-", 
        RowBox[{"3", 
         RowBox[{"y", "^", "2"}]}]}], "\[Equal]", "1"}], "&&", 
      RowBox[{"10", "<", "x", "<", "100"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], ",", "Integers"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7733810308049917`*^9, 3.773381114019177*^9}, {
  3.773394966997388*^9, 3.7733949691916933`*^9}},
 CellLabel->
  "In[362]:=",ExpressionUUID->"ba451754-f8f6-4db5-bb2f-bc47c1ef9792"],

Cell[BoxData[
 TemplateBox[{
  "Solve","svars",
   "\"Equations may not give solutions for all \\\"solve\\\" variables.\"",2,
   362,19,22788172953567579777,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.773381094750545*^9, 3.773394970061953*^9},
 CellLabel->
  "During evaluation of \
In[362]:=",ExpressionUUID->"23558c4a-7820-467d-bcd0-faab4e2c1f01"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    RowBox[{"ConditionalExpression", "[", 
     RowBox[{
      SqrtBox[
       RowBox[{"1", "+", 
        RowBox[{"3", " ", 
         SuperscriptBox[
          RowBox[{"Re", "[", "y", "]"}], "2"]}]}]], ",", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Im", "[", "y", "]"}], "\[Equal]", "0"}], "&&", 
         RowBox[{
          SqrtBox["33"], "<", 
          RowBox[{"Re", "[", "y", "]"}], "<", 
          SqrtBox["3333"]}]}], ")"}], "||", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Im", "[", "y", "]"}], "\[Equal]", "0"}], "&&", 
         RowBox[{
          RowBox[{"-", 
           SqrtBox["3333"]}], "<", 
          RowBox[{"Re", "[", "y", "]"}], "<", 
          RowBox[{"-", 
           SqrtBox["33"]}]}]}], ")"}]}]}], "]"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.773381094753942*^9, 3.7733949700823298`*^9},
 CellLabel->
  "Out[362]=",ExpressionUUID->"e21630b1-2b96-4edc-9fcc-0b94612908cc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"x", "\[Rule]", "26"}], ",", 
    RowBox[{"y", "\[Rule]", "15"}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.773381094753942*^9, 3.773394970089617*^9},
 CellLabel->
  "Out[363]=",ExpressionUUID->"4caf936f-2986-4854-8797-47adf60a541c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solving systems of linear equations", "Subsection",
 CellChangeTimes->{{3.773383418387116*^9, 
  3.7733834354790173`*^9}},ExpressionUUID->"193ec52c-d2a1-4be8-aa01-\
1c47788c47c1"],

Cell["\<\
The function LinearSolve[ A, b ] provides an easy way to solve systems of \
linear equations of the form A x = b.\
\>", "Text",
 CellChangeTimes->{{3.773383441974433*^9, 
  3.773383471074624*^9}},ExpressionUUID->"bead83b2-0dd5-49f3-921b-\
15f1855476b0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Setup", " ", "a", " ", "linear", " ", "system", " ", "of", " ", "the", 
     " ", "form", " ", "A", " ", "x"}], " ", "=", " ", "b"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A", "=", GridBox[{
       {"1", "0", "1"},
       {"2", "1", "2"},
       {"3", "1", 
        RowBox[{"-", "1"}]}
      }]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"b", "=", 
     RowBox[{"{", 
      RowBox[{"43", ",", "85", ",", 
       RowBox[{"-", "40"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Solve", " ", "the", " ", "Linear", " ", "System"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"x", "=", 
    RowBox[{"LinearSolve", "[", 
     RowBox[{"A", ",", "b"}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Verify", " ", "that", " ", "x", " ", "is", " ", "indeed", " ", "a", " ", 
     "solution"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"A", ".", "x"}], "\[Equal]", "b"}]}]}]], "Input",
 CellChangeTimes->{{3.7733834797081957`*^9, 3.773383598234928*^9}},
 CellLabel->
  "In[114]:=",ExpressionUUID->"c8241434-ad8a-4f7f-93b5-becce3284c79"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"-", "1"}], ",", "42"}], "}"}]], "Output",
 CellChangeTimes->{{3.773383516414845*^9, 3.773383545952249*^9}, 
   3.77338359867916*^9},
 CellLabel->
  "Out[116]=",ExpressionUUID->"192628ef-ad49-460a-ba4a-2c1492eb731c"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.773383516414845*^9, 3.773383545952249*^9}, 
   3.773383598687338*^9},
 CellLabel->
  "Out[117]=",ExpressionUUID->"e879edbb-3de6-42ea-8e9c-2d99e7bd0692"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reducing Systems of (In-)equalities", "Section",
 CellChangeTimes->{{3.773381158662574*^9, 
  3.773381185624423*^9}},ExpressionUUID->"cc672e02-8c58-47cc-b2dd-\
f6a864d6008c"],

Cell["\<\
The function Reduce[ ] reduces systems by solving equalities and inequalities \
as far as possible and simplifying terms.\
\>", "Text",
 CellChangeTimes->{{3.7733811893172398`*^9, 3.773381189877089*^9}, {
  3.773381300445353*^9, 
  3.773381328579733*^9}},ExpressionUUID->"590eadb6-ba08-4cbd-b422-\
42b3cd223a63"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Reduce", " ", "a", " ", "system"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "\[Equal]", "1"}], ",", 
       RowBox[{"x", "\[GreaterEqual]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}], ",", "Reals"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"x", "^", "2"}], "+", "1"}], "\[GreaterEqual]", "0"}], "}"}], 
     ",", "x", ",", "Reals"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "^", "2"}], "\[GreaterEqual]", "a"}], "}"}], ",", "x"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.773381348429303*^9, 3.773381393954688*^9}, {
  3.773381428338284*^9, 3.7733815031708612`*^9}},
 CellLabel->"In[78]:=",ExpressionUUID->"e1e1b18a-7236-4da7-8a06-ad95525942f7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"0", "\[LessEqual]", "x", "\[LessEqual]", "1"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"y", "\[Equal]", 
     RowBox[{"-", 
      SqrtBox[
       RowBox[{"1", "-", 
        SuperscriptBox["x", "2"]}]]}]}], "||", 
    RowBox[{"y", "\[Equal]", 
     SqrtBox[
      RowBox[{"1", "-", 
       SuperscriptBox["x", "2"]}]]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.773381382881871*^9, 3.773381394444469*^9}, 
   3.773381430602695*^9, {3.773381472110756*^9, 3.773381504011949*^9}},
 CellLabel->"Out[78]=",ExpressionUUID->"f8b5fea5-2770-47bb-9f09-3834202fae15"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.773381382881871*^9, 3.773381394444469*^9}, 
   3.773381430602695*^9, {3.773381472110756*^9, 3.7733815040220118`*^9}},
 CellLabel->"Out[79]=",ExpressionUUID->"e31a3447-98fb-4355-b860-f567b75e5fd3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "\[Element]", 
   TemplateBox[{},
    "Reals"]}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"a", "\[LessEqual]", "0"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", ">", "0"}], "&&", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x", "\[LessEqual]", 
         RowBox[{"-", 
          SqrtBox["a"]}]}], "||", 
        RowBox[{"x", "\[GreaterEqual]", 
         SqrtBox["a"]}]}], ")"}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.773381382881871*^9, 3.773381394444469*^9}, 
   3.773381430602695*^9, {3.773381472110756*^9, 3.7733815040261173`*^9}},
 CellLabel->"Out[80]=",ExpressionUUID->"5ac4255e-c81b-453b-9f20-9610841dbfb2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simplify and Conditional Expressions", "Section",
 CellChangeTimes->{{3.773381541863783*^9, 
  3.773381553952194*^9}},ExpressionUUID->"f9369d3e-bed8-4ed5-a14a-\
99b999983aac"],

Cell["\<\
Some expressions (e.g. solutions obtained from Solve) may be not in the \
simplest form. To simplify, use the functions Simplify or FullSimplify (see \
documentation for differences).\
\>", "Text",
 CellChangeTimes->{{3.7733817032436523`*^9, 
  3.773381778012587*^9}},ExpressionUUID->"fca649fd-bb3e-4430-80e1-\
4d5b6cfd992b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  FractionBox[
   RowBox[{
    RowBox[{"-", "252"}], "-", 
    RowBox[{"462", " ", "x"}], "-", 
    RowBox[{"126", " ", 
     RowBox[{"x", "^", "2"}]}], "+", 
    RowBox[{"126", " ", 
     RowBox[{"x", "^", "3"}]}], "+", 
    RowBox[{"42", " ", 
     RowBox[{"x", "^", "4"}]}]}], 
   RowBox[{"21", "+", 
    RowBox[{"42", " ", "x"}], "+", 
    RowBox[{"21", " ", 
     SuperscriptBox["x", "2"]}]}]], "]"}]], "Input",
 CellChangeTimes->{{3.773381795212309*^9, 3.7733818418440228`*^9}, {
   3.773381901948258*^9, 3.773381905432291*^9}, 3.7733819410969*^9},
 CellLabel->"In[86]:=",ExpressionUUID->"70ef2339-850b-45c8-b6c4-948a915fca0d"],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "6"}], "+", "x", "+", 
    SuperscriptBox["x", "2"]}], ")"}]}]], "Output",
 CellChangeTimes->{3.773381828690606*^9, 3.773381942248032*^9},
 CellLabel->"Out[86]=",ExpressionUUID->"f3a57d76-1392-48f6-b972-aa4a0a911f38"]
}, Open  ]],

Cell["\<\
Some Expressions can be simplified using assumptions. Use the Assumption \
option and assign a (list of) assumptions to it\
\>", "Text",
 CellChangeTimes->{{3.773382732007079*^9, 
  3.77338279454812*^9}},ExpressionUUID->"d9ff2858-e058-4c8a-8c4f-\
64a75d002fae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "An", " ", "expression", " ", "that", " ", "can", " ", "not", " ", "be", 
    " ", "simplified", " ", "without", " ", "further", " ", "assumptions"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Simplify", "[", " ", 
    RowBox[{"1", " ", "+", " ", 
     RowBox[{"Abs", "[", 
      RowBox[{"x", "-", "1"}], "]"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Using", " ", "assumptions", " ", "the", " ", "expression", " ", "can", 
     " ", "be", " ", "simplified"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", " ", 
    RowBox[{
     RowBox[{"1", " ", "+", " ", 
      RowBox[{"Abs", "[", 
       RowBox[{"x", "-", "1"}], "]"}]}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", "\[GreaterEqual]", "1"}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "^", "2"}], "\[Equal]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{"Assumptions", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"x", "\[Element]", "Reals"}], "}"}]}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7733827963022346`*^9, 3.773382901762548*^9}, {
  3.773382933045608*^9, 3.77338297338103*^9}},
 CellLabel->"In[99]:=",ExpressionUUID->"3e2fcd8b-8c66-44f8-a888-b0dbd2f692fc"],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"Abs", "[", 
   RowBox[{
    RowBox[{"-", "1"}], "+", "x"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.773382827654502*^9, {3.773382864473537*^9, 3.7733829023158484`*^9}, {
   3.773382960078076*^9, 3.773382974147612*^9}},
 CellLabel->"Out[99]=",ExpressionUUID->"ca21327c-748a-4b4e-a248-6677f34eaf45"],

Cell[BoxData["x"], "Output",
 CellChangeTimes->{
  3.773382827654502*^9, {3.773382864473537*^9, 3.7733829023158484`*^9}, {
   3.773382960078076*^9, 3.773382974161612*^9}},
 CellLabel->
  "Out[100]=",ExpressionUUID->"2a383dcf-703e-4c21-b4ba-b4d7a946dc11"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{
  3.773382827654502*^9, {3.773382864473537*^9, 3.7733829023158484`*^9}, {
   3.773382960078076*^9, 3.773382974173162*^9}},
 CellLabel->
  "Out[101]=",ExpressionUUID->"12047661-e6db-4c05-b30e-7b7bce53dda1"]
}, Open  ]],

Cell["\<\
Results of Solve may be Conditional Expressions if the solution depends on a \
parameter. Conditional Expressions can be removed by using Simplify with \
Assumptions.\
\>", "Text",
 CellChangeTimes->{{3.773381650451483*^9, 3.77338168332911*^9}, {
  3.7733830311404*^9, 
  3.773383051602655*^9}},ExpressionUUID->"0a54320c-593e-4163-809a-\
68122613bf17"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"solution", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "^", "2"}], "\[Equal]", "a"}], ",", "x", ",", "Reals"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Simplify", "[", 
  RowBox[{"solution", ",", 
   RowBox[{"Assumptions", "\[Rule]", 
    RowBox[{"a", ">", "0"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.773381844952577*^9, 3.773381876528039*^9}, {
  3.773381912699587*^9, 3.773381931833671*^9}, {3.773383055848011*^9, 
  3.773383123686137*^9}},
 CellLabel->
  "In[107]:=",ExpressionUUID->"23919bea-dd1b-458f-ad77-46e876a4b2c3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{"-", 
        SqrtBox["a"]}], ",", 
       RowBox[{"a", ">", "0"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       SqrtBox["a"], ",", 
       RowBox[{"a", ">", "0"}]}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.773381868179895*^9, 3.773381876775906*^9}, 
   3.773381935440855*^9, {3.773383068478448*^9, 3.773383123876783*^9}},
 CellLabel->
  "Out[107]=",ExpressionUUID->"24519c46-52ce-4d48-957b-9db14739ffc7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"-", 
      SqrtBox["a"]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     SqrtBox["a"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.773381868179895*^9, 3.773381876775906*^9}, 
   3.773381935440855*^9, {3.773383068478448*^9, 3.7733831238884*^9}},
 CellLabel->
  "Out[108]=",ExpressionUUID->"98ad3abd-52b3-4bad-b12c-02eb2cf65d31"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 857},
WindowMargins->{{113, Automatic}, {Automatic, 47}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 192, 3, 160, "Title",ExpressionUUID->"24707d61-6bb5-49c1-ac9b-b52b1328ef31"],
Cell[CellGroupData[{
Cell[797, 29, 166, 3, 67, "Section",ExpressionUUID->"5fb229e9-4fd0-4a65-9545-1a406dd5b076"],
Cell[966, 34, 356, 7, 58, "Text",ExpressionUUID->"dd669644-310c-49b9-9531-10a03fa42f86"],
Cell[CellGroupData[{
Cell[1347, 45, 2025, 51, 220, "Input",ExpressionUUID->"cd82bea5-1074-435d-aa49-c0ebd69ee013"],
Cell[3375, 98, 247, 4, 34, "Output",ExpressionUUID->"1b06e7d3-bb76-4aa9-a4fb-049f74557c48"],
Cell[3625, 104, 218, 3, 34, "Output",ExpressionUUID->"13717a09-07ef-47eb-8b64-0b69101586f0"],
Cell[3846, 109, 218, 3, 34, "Output",ExpressionUUID->"0b45855d-73eb-4dae-9620-20fa9bbb69cd"],
Cell[4067, 114, 313, 7, 34, "Output",ExpressionUUID->"00a346d1-dc0f-4368-b78e-92141779f6ed"],
Cell[4383, 123, 278, 5, 34, "Output",ExpressionUUID->"a099f9ef-cc93-47c0-8745-c73bb98a5250"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[4710, 134, 189, 3, 67, "Section",ExpressionUUID->"41c3f542-7c63-401e-bd0e-6218073d9fa1"],
Cell[CellGroupData[{
Cell[4924, 141, 170, 3, 54, "Subsection",ExpressionUUID->"53d6b442-c765-4b47-8ca7-b1eee8d76e5e"],
Cell[5097, 146, 398, 8, 58, "Text",ExpressionUUID->"f7293dea-87f4-4327-8930-fcfc526a6cf9"],
Cell[CellGroupData[{
Cell[5520, 158, 979, 26, 94, "Input",ExpressionUUID->"da707750-af3e-4caa-a2b6-2d3b1ce82581"],
Cell[6502, 186, 268, 6, 34, "Output",ExpressionUUID->"4b3238a8-34c3-4019-94f6-7bcd1dd247ea"],
Cell[6773, 194, 268, 6, 34, "Output",ExpressionUUID->"6e403d82-a4e3-4ad3-b2a6-7dfedfc7bea1"]
}, Open  ]],
Cell[7056, 203, 324, 7, 81, "Text",ExpressionUUID->"d104cddb-a8c5-4196-bdc5-d8c5426519c9"],
Cell[CellGroupData[{
Cell[7405, 214, 625, 16, 52, "Input",ExpressionUUID->"d7fc0d69-e37f-43b6-a57d-e9e3427b4c89"],
Cell[8033, 232, 390, 11, 34, "Output",ExpressionUUID->"f0be1466-573f-4fae-af09-eff13cd86f20"]
}, Open  ]],
Cell[8438, 246, 274, 6, 35, "Text",ExpressionUUID->"986ec7d5-4e30-4500-bdf0-875449d85a89"],
Cell[CellGroupData[{
Cell[8737, 256, 1299, 36, 94, "Input",ExpressionUUID->"0b1c5799-0d6b-4e7c-adc8-26d36f355c45"],
Cell[10039, 294, 301, 8, 34, "Output",ExpressionUUID->"7098e7cd-7093-47f9-92a3-bd2034749967"],
Cell[10343, 304, 304, 8, 34, "Output",ExpressionUUID->"cb7a239a-a154-4a86-997d-c1889ae15af3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10696, 318, 173, 3, 54, "Subsection",ExpressionUUID->"28f10610-8b84-466a-8687-83f5e8562d63"],
Cell[10872, 323, 262, 6, 35, "Text",ExpressionUUID->"b39e6d02-d7f1-4ed4-873b-569ead34fdda"],
Cell[CellGroupData[{
Cell[11159, 333, 2410, 68, 199, "Input",ExpressionUUID->"9f68369f-1c08-4551-9d62-0180026a3ef6"],
Cell[13572, 403, 298, 7, 34, "Output",ExpressionUUID->"1bb89562-3e1e-4b1a-b82f-dc9cdf876313"],
Cell[13873, 412, 241, 5, 34, "Output",ExpressionUUID->"c953a82f-bd28-4197-a2c4-49993259662d"],
Cell[14117, 419, 224, 4, 34, "Output",ExpressionUUID->"c225448b-2920-4820-88fe-f892e8824a60"]
}, Open  ]],
Cell[14356, 426, 434, 8, 58, "Text",ExpressionUUID->"798e0c02-2e51-4bf4-b002-28785056c248"],
Cell[CellGroupData[{
Cell[14815, 438, 1571, 45, 136, "Input",ExpressionUUID->"1b0f66ea-afff-426e-bd60-9690648e4908"],
Cell[16389, 485, 168, 3, 34, "Output",ExpressionUUID->"1936c090-668c-4236-a8a7-1a443d4a3e81"],
Cell[16560, 490, 872, 25, 56, "Output",ExpressionUUID->"1f809b4f-426b-4256-91bb-7f662a8bb4b2"],
Cell[17435, 517, 354, 9, 24, "Message",ExpressionUUID->"3a975fe4-e41c-4da3-8089-b72a8331eb0e"],
Cell[17792, 528, 251, 6, 34, "Output",ExpressionUUID->"5c1b1733-3f4b-4e7a-b5b7-8d60862932e7"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[18092, 540, 170, 3, 54, "Subsection",ExpressionUUID->"760df842-4a67-470e-9080-bcfb85c10b63"],
Cell[18265, 545, 308, 7, 35, "Text",ExpressionUUID->"bb40ca21-d14d-4dad-8358-5ef4a7742e31"],
Cell[CellGroupData[{
Cell[18598, 556, 724, 21, 73, "Input",ExpressionUUID->"06a64cde-277f-49d9-b04a-16de75a803fe"],
Cell[19325, 579, 438, 11, 34, "Output",ExpressionUUID->"c77235fe-6f7a-4526-b3fa-704e8afb8c64"],
Cell[19766, 592, 248, 5, 34, "Output",ExpressionUUID->"821f3770-c896-447e-bb89-1e73763b19a6"],
Cell[20017, 599, 600, 17, 38, "Output",ExpressionUUID->"4d882aa8-8bb8-42f1-9584-5edbffac727f"]
}, Open  ]],
Cell[20632, 619, 262, 6, 35, "Text",ExpressionUUID->"ab65b9dd-33ae-4bc4-af0d-4695d0f77c76"],
Cell[CellGroupData[{
Cell[20919, 629, 1286, 35, 94, "Input",ExpressionUUID->"ba451754-f8f6-4db5-bb2f-bc47c1ef9792"],
Cell[22208, 666, 377, 9, 24, "Message",ExpressionUUID->"23558c4a-7820-467d-bcd0-faab4e2c1f01"],
Cell[22588, 677, 1057, 32, 74, "Output",ExpressionUUID->"e21630b1-2b96-4edc-9fcc-0b94612908cc"],
Cell[23648, 711, 308, 8, 92, "Output",ExpressionUUID->"4caf936f-2986-4854-8797-47adf60a541c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24005, 725, 185, 3, 54, "Subsection",ExpressionUUID->"193ec52c-d2a1-4be8-aa01-1c47788c47c1"],
Cell[24193, 730, 263, 6, 35, "Text",ExpressionUUID->"bead83b2-0dd5-49f3-921b-15f1855476b0"],
Cell[CellGroupData[{
Cell[24481, 740, 1246, 35, 194, "Input",ExpressionUUID->"c8241434-ad8a-4f7f-93b5-becce3284c79"],
Cell[25730, 777, 277, 7, 34, "Output",ExpressionUUID->"192628ef-ad49-460a-ba4a-2c1492eb731c"],
Cell[26010, 786, 206, 4, 34, "Output",ExpressionUUID->"e879edbb-3de6-42ea-8e9c-2d99e7bd0692"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[26277, 797, 180, 3, 67, "Section",ExpressionUUID->"cc672e02-8c58-47cc-b2dd-f6a864d6008c"],
Cell[26460, 802, 322, 7, 58, "Text",ExpressionUUID->"590eadb6-ba08-4cbd-b422-42b3cd223a63"],
Cell[CellGroupData[{
Cell[26807, 813, 1125, 33, 94, "Input",ExpressionUUID->"e1e1b18a-7236-4da7-8a06-ad95525942f7"],
Cell[27935, 848, 601, 16, 49, "Output",ExpressionUUID->"f8b5fea5-2770-47bb-9f09-3834202fae15"],
Cell[28539, 866, 250, 3, 34, "Output",ExpressionUUID->"e31a3447-98fb-4355-b860-f567b75e5fd3"],
Cell[28792, 871, 697, 20, 38, "Output",ExpressionUUID->"5ac4255e-c81b-453b-9f20-9610841dbfb2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[29538, 897, 181, 3, 67, "Section",ExpressionUUID->"f9369d3e-bed8-4ed5-a14a-99b999983aac"],
Cell[29722, 902, 335, 7, 58, "Text",ExpressionUUID->"fca649fd-bb3e-4430-80e1-4d5b6cfd992b"],
Cell[CellGroupData[{
Cell[30082, 913, 674, 18, 48, "Input",ExpressionUUID->"70ef2339-850b-45c8-b6c4-948a915fca0d"],
Cell[30759, 933, 296, 7, 37, "Output",ExpressionUUID->"f3a57d76-1392-48f6-b972-aa4a0a911f38"]
}, Open  ]],
Cell[31070, 943, 271, 6, 58, "Text",ExpressionUUID->"d9ff2858-e058-4c8a-8c4f-64a75d002fae"],
Cell[CellGroupData[{
Cell[31366, 953, 1387, 35, 115, "Input",ExpressionUUID->"3e2fcd8b-8c66-44f8-a888-b0dbd2f692fc"],
Cell[32756, 990, 346, 8, 34, "Output",ExpressionUUID->"ca21327c-748a-4b4e-a248-6677f34eaf45"],
Cell[33105, 1000, 254, 5, 34, "Output",ExpressionUUID->"2a383dcf-703e-4c21-b4ba-b4d7a946dc11"],
Cell[33362, 1007, 258, 5, 34, "Output",ExpressionUUID->"12047661-e6db-4c05-b30e-7b7bce53dda1"]
}, Open  ]],
Cell[33635, 1015, 362, 8, 58, "Text",ExpressionUUID->"0a54320c-593e-4163-809a-68122613bf17"],
Cell[CellGroupData[{
Cell[34022, 1027, 594, 15, 52, "Input",ExpressionUUID->"23919bea-dd1b-458f-ad77-46e876a4b2c3"],
Cell[34619, 1044, 674, 19, 38, "Output",ExpressionUUID->"24519c46-52ce-4d48-957b-9db14739ffc7"],
Cell[35296, 1065, 454, 13, 38, "Output",ExpressionUUID->"98ad3abd-52b3-4bad-b12c-02eb2cf65d31"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

