(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     42870,       1044]
NotebookOptionsPosition[     38908,        972]
NotebookOutlinePosition[     39262,        988]
CellTagsIndexPosition[     39219,        985]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Session 4 : Graphs", "Title",
 CellChangeTimes->{{3.773395866850622*^9, 
  3.773395873100605*^9}},ExpressionUUID->"05b2e0a9-d600-47e1-bd32-\
a2e3935d0311"],

Cell[CellGroupData[{

Cell["Creating Graphs", "Section",
 CellChangeTimes->{{3.773395906862399*^9, 
  3.773395928994774*^9}},ExpressionUUID->"d0670f6f-1414-4742-9f97-\
f008e4d6b286"],

Cell["\<\
The function Graph[ ] creates a graph. Graphs are created from Lists of edges \
(and maybe vertices). Directed Edges can be created with the function \
DirectedEdge[v,w], Undirected edges with UndirectedEdge[v,w]. Edges can also \
be entered using the shortform v -> w and v <-> w . The vertices may be any \
expressions (numbers or unset variables in general.
Graph[ edgelist ] creates a graph from the edge list creating all vertices \
automatically.
Graph[ vertexlist, edgelist] creates a graph with specified edges and vertices\
\>", "Text",
 CellChangeTimes->{{3.7733959426052513`*^9, 3.773395943979334*^9}, {
  3.773396147903234*^9, 
  3.773396350864091*^9}},ExpressionUUID->"eb920e49-f19b-4e07-91fb-\
29294e8e20c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Create", " ", "edges"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DirectedEdge", "[", 
    RowBox[{"v", ",", "w"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"UndirectedEdge", "[", 
    RowBox[{"v", ",", "w"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Creates", " ", "a", " ", "directed", " ", "graph"}], " ", "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{"Graph", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"1", "\[Rule]", "2"}], ",", 
      RowBox[{"2", "\[Rule]", "3"}], ",", 
      RowBox[{"1", "\[Rule]", "3"}], ",", 
      RowBox[{"3", "\[Rule]", "4"}], ",", 
      RowBox[{"2", "\[Rule]", "5"}], ",", " ", 
      RowBox[{"5", "\[Rule]", "1"}]}], "}"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Creates", " ", "an", " ", "undirected", " ", "graph", " ", "with", " ", 
      "vertices", " ", "1"}], ",", "2", ",", "3", ",", "4", ",", "5"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[TwoWayRule]", "2"}], ",", 
       RowBox[{"2", "\[TwoWayRule]", "3"}], ",", 
       RowBox[{"3", "\[TwoWayRule]", "4"}], ",", 
       RowBox[{"4", "\[TwoWayRule]", "1"}]}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7733962304612103`*^9, 3.7733962355611753`*^9}, {
  3.773396357843788*^9, 3.7733964853030157`*^9}},
 CellLabel->
  "In[381]:=",ExpressionUUID->"e0598faa-1e74-4fe1-88d0-97b3238b8519"],

Cell[BoxData[
 RowBox[{"v", "\[DirectedEdge]", "w"}]], "Output",
 CellChangeTimes->{
  3.77339623622229*^9, {3.7733963985749903`*^9, 3.773396413035941*^9}, 
   3.7733964460262413`*^9, 3.773396491359662*^9},
 CellLabel->
  "Out[381]=",ExpressionUUID->"c4366c30-6e3b-4a92-afed-016bfdedf936"],

Cell[BoxData[
 RowBox[{"v", "\[UndirectedEdge]", "w"}]], "Output",
 CellChangeTimes->{
  3.77339623622229*^9, {3.7733963985749903`*^9, 3.773396413035941*^9}, 
   3.7733964460262413`*^9, 3.773396491367869*^9},
 CellLabel->
  "Out[382]=",ExpressionUUID->"8eeb1601-5a44-4ab8-83f3-23a6838b10ba"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 
      5}, {{{1, 2}, {2, 3}, {1, 3}, {3, 4}, {2, 5}, {5, 1}}, Null}]]}, 
    TagBox[
     GraphicsGroupBox[
      GraphicsComplexBox[{{0.8834883404060231, 0.7467409153248292}, {
       0.8849910496514127, 0.}, {1.8902599974438676`, 0.3736486136446303}, {
       3.029046622127032, 0.37277656921719704`}, {0., 0.37231488735143514`}}, {
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[Medium], 
         ArrowBox[{{1, 2}, {1, 3}, {2, 3}, {2, 5}, {3, 4}, {5, 1}}, 
          0.03044746092376492]}, 
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
         DiskBox[1, 0.03044746092376492], DiskBox[2, 0.03044746092376492], 
         DiskBox[3, 0.03044746092376492], DiskBox[4, 0.03044746092376492], 
         DiskBox[5, 0.03044746092376492]}}]],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.77339623622229*^9, {3.7733963985749903`*^9, 3.773396413035941*^9}, 
   3.7733964460262413`*^9, 3.773396491398005*^9},
 CellLabel->
  "Out[383]=",ExpressionUUID->"6e2e1f44-7f84-4023-8c63-ee3781dd4c42"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5}, {Null, {{1, 2}, {2, 3}, {3, 4}, {4, 1}}}]]}, 
    TagBox[
     GraphicsGroupBox[
      GraphicsComplexBox[{{1.1570827321497008`, -1.1281685887629571`}, {
       0.15768973023584465`, -1.154236031031331}, {
       0.12841548684339066`, -0.15485132588994366`}, {
       1.1283539266140916`, -0.12841548684339066`}, {
       0.12841548684339066`, -1.4110670047181124`}}, {
        {Hue[0.6, 0.7, 0.5], Opacity[0.7], 
         {Arrowheads[0.], ArrowBox[{1, 2}, 0.016512279377655925`]}, 
         {Arrowheads[0.], ArrowBox[{1, 4}, 0.016512279377655925`]}, 
         {Arrowheads[0.], ArrowBox[{2, 3}, 0.016512279377655925`]}, 
         {Arrowheads[0.], ArrowBox[{3, 4}, 0.016512279377655925`]}}, 
        {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
         DiskBox[1, 0.016512279377655925], DiskBox[2, 0.016512279377655925], 
         DiskBox[3, 0.016512279377655925], DiskBox[4, 0.016512279377655925], 
         DiskBox[5, 0.016512279377655925]}}]],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.77339623622229*^9, {3.7733963985749903`*^9, 3.773396413035941*^9}, 
   3.7733964460262413`*^9, 3.7733964914332447`*^9},
 CellLabel->
  "Out[384]=",ExpressionUUID->"dc5e2310-482f-4d48-a80a-4584dc8990d2"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Labels, Weights, Styles", "Section",
 CellChangeTimes->{{3.773397125720508*^9, 
  3.773397135736952*^9}},ExpressionUUID->"4455a87a-89b3-428c-b6af-\
4629da6a1309"],

Cell[CellGroupData[{

Cell["Vertex and Edge Labels/Edge Weights", "Subsection",
 CellChangeTimes->{{3.77339656159332*^9, 
  3.7733965736607733`*^9}},ExpressionUUID->"b3d42282-c779-43e7-a4bf-\
8c2350a352a1"],

Cell["\<\
Using the options VertexLabels and EdgeLabels assigns labels, the function \
EdgeWeights assigns weights to edges that can be used for various algorithms \
or for display. The Labels-Options expect a list of rules that assign to \
every vertex/edge a label or a global option. The EdgeWeight option expects a \
list of EdgeWeights.
If the variable g is a Graph object, then using Graph[ g ] creates a copy of \
that graph (maybe with additional options).\
\>", "Text",
 CellChangeTimes->{{3.773396614739571*^9, 3.7733967852085743`*^9}, {
  3.773396992707096*^9, 
  3.773397004484693*^9}},ExpressionUUID->"6efb6d5e-def5-44ee-ba6e-\
6f445ab03342"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Creates", " ", "a", " ", "graph", " ", "with", " ", "Names", " ", "as", 
    " ", 
    RowBox[{"Labels", ".", " ", "The"}], " ", "Edge", " ", "Labels", " ", 
    "are", " ", "displayed", " ", "as", " ", "Tooltip"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"g", "=", 
    RowBox[{"Graph", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"1", "\[Rule]", "2"}], ",", 
        RowBox[{"2", "\[Rule]", "3"}], ",", 
        RowBox[{"3", "\[Rule]", "1"}]}], "}"}], ",", 
      RowBox[{"VertexLabels", "\[Rule]", "Automatic"}], ",", " ", 
      RowBox[{"EdgeLabels", "\[Rule]", 
       RowBox[{"Placed", "[", 
        RowBox[{"\"\<Name\>\"", ",", " ", "Tooltip"}], "]"}]}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Creates", " ", "a", " ", "copy", " ", "of", " ", "the", " ", "above", 
     " ", "graph", " ", "assigning", " ", "weights", " ", "to", " ", "the", 
     " ", "edges", " ", "and", " ", "using", " ", "these", " ", "weights", 
     " ", "as", " ", "labels"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"weightedgraph", "=", 
    RowBox[{"Graph", "[", 
     RowBox[{"g", ",", 
      RowBox[{"EdgeWeight", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"1", ",", "42", ",", 
         RowBox[{"-", "3"}]}], "}"}]}], ",", 
      RowBox[{"EdgeLabels", "\[Rule]", "\"\<EdgeWeight\>\""}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "The", " ", "weights", " ", "are", " ", "for", " ", "example", " ", 
     "used", " ", "in", " ", "the", " ", "adjacency", " ", "matrix"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"WeightedAdjacencyMatrix", "[", "weightedgraph", "]"}], "//", 
    "MatrixForm"}]}]}]], "Input",
 CellChangeTimes->{{3.773396763104671*^9, 3.773397091482449*^9}},
 CellLabel->
  "In[403]:=",ExpressionUUID->"c23fd7b6-5124-44d8-9e6c-e837f8423407"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3}, {{{1, 2}, {2, 3}, {3, 1}}, Null}, {EdgeLabels -> {
         Placed["Name", Tooltip]}, VertexLabels -> {Automatic}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[Medium], 
        TagBox[
         TooltipBox[
          ArrowBox[{{-0.8660254037844384, -0.4999999999999994}, {
           0.8660254037844389, -0.5000000000000012}}, 0.020399597244776385`],
          RowBox[{"1", "\[DirectedEdge]", "2"}]],
         Annotation[#, 
          DirectedEdge[1, 2], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          ArrowBox[{{0.8660254037844389, -0.5000000000000012}, {
           1.8369701987210297`*^-16, 1.}}, 0.020399597244776385`],
          RowBox[{"2", "\[DirectedEdge]", "3"}]],
         Annotation[#, 
          DirectedEdge[2, 3], "Tooltip"]& ], 
        TagBox[
         TooltipBox[
          ArrowBox[{{1.8369701987210297`*^-16, 
           1.}, {-0.8660254037844384, -0.4999999999999994}}, 
           0.020399597244776385`],
          RowBox[{"3", "\[DirectedEdge]", "1"}]],
         Annotation[#, 
          DirectedEdge[3, 1], "Tooltip"]& ]}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
          0.020399597244776385], 
         InsetBox["1", 
          Offset[{2, 2}, {-0.845625806539662, -0.479600402755223}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.8660254037844389, -0.5000000000000012}, 
          0.020399597244776385], 
         InsetBox["2", 
          Offset[{2, 2}, {0.8864250010292153, -0.47960040275522486}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.8369701987210297*^-16, 1.}, 0.020399597244776385], 
         InsetBox["3", 
          Offset[{2, 2}, {0.02039959724477657, 1.0203995972447764}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.77339679677976*^9, 3.773396806695348*^9}, {
  3.773396938200136*^9, 3.773396980975885*^9}, {3.773397064987008*^9, 
  3.77339709216638*^9}},
 CellLabel->
  "Out[403]=",ExpressionUUID->"c66789a0-cf4a-420e-b7d6-862dd875cef7"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3}, {{{1, 2}, {2, 3}, {3, 1}}, Null}, {
      EdgeLabels -> {"EdgeWeight"}, EdgeWeight -> {1, 42, -3}, 
       GraphLayout -> {"Dimension" -> 2}, VertexLabels -> {Automatic}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        Medium], {
         ArrowBox[{{-0.8660254037844384, -0.4999999999999994}, {
          0.8660254037844389, -0.5000000000000012}}, 0.020399597244776385`], 
         InsetBox["1", {2.7755575615628914*^-16, -0.5000000000000003}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0.8660254037844389, -0.5000000000000012}, {
          1.8369701987210297`*^-16, 1.}}, 0.020399597244776385`], 
         InsetBox["42", {0.4330127018922196, 0.2499999999999994}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1.8369701987210297`*^-16, 
          1.}, {-0.8660254037844384, -0.4999999999999994}}, 
          0.020399597244776385`], InsetBox[
          RowBox[{"-", "3"}], {-0.4330127018922191, 0.25000000000000033}, 
          ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {
         DiskBox[{-0.8660254037844384, -0.4999999999999994}, 
          0.020399597244776385], 
         InsetBox["1", 
          Offset[{2, 2}, {-0.845625806539662, -0.479600402755223}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{0.8660254037844389, -0.5000000000000012}, 
          0.020399597244776385], 
         InsetBox["2", 
          Offset[{2, 2}, {0.8864250010292153, -0.47960040275522486}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         DiskBox[{1.8369701987210297*^-16, 1.}, 0.020399597244776385], 
         InsetBox["3", 
          Offset[{2, 2}, {0.02039959724477657, 1.0203995972447764}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.77339679677976*^9, 3.773396806695348*^9}, {
  3.773396938200136*^9, 3.773396980975885*^9}, {3.773397064987008*^9, 
  3.773397092208943*^9}},
 CellLabel->
  "Out[404]=",ExpressionUUID->"6fe8e200-50c2-4cfa-a57f-96e3c9237081"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1", "0"},
     {"0", "0", "42"},
     {
      RowBox[{"-", "3"}], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {3, 3}, 0, {
     1, {{0, 1, 2, 3}, {{2}, {3}, {1}}}, {1, 42, -3}}]]]]], "Output",
 CellChangeTimes->{{3.77339679677976*^9, 3.773396806695348*^9}, {
  3.773396938200136*^9, 3.773396980975885*^9}, {3.773397064987008*^9, 
  3.773397092237709*^9}},
 CellLabel->
  "Out[405]//MatrixForm=",ExpressionUUID->"0b0d676e-44d3-49c4-94e5-\
bbeab11aa209"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles", "Subsection",
 CellChangeTimes->{{3.773397149850297*^9, 
  3.773397155694718*^9}},ExpressionUUID->"830048c9-9051-41f7-b07c-\
6dda1be382bc"],

Cell["\<\
Graphs can be customized by using styles. Styles can be assigned to Vertices \
and Edges, either on creation or as options. To combine different styles, use \
the function Directive[ ]\
\>", "Text",
 CellChangeTimes->{{3.773397158716782*^9, 3.773397206647997*^9}, {
  3.7733972571069613`*^9, 
  3.773397271775646*^9}},ExpressionUUID->"69829f1a-bb48-4683-a9ad-\
febb2636b709"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Create", " ", "a", " ", "graph", " ", "with", " ", "a", " ", "red", " ", 
     "vertex"}], ",", " ", 
    RowBox[{"and", " ", "a", " ", "green", " ", "thick", " ", "edge"}]}], " ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", 
       RowBox[{"Style", "[", 
        RowBox[{"2", ",", "Red"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{"1", "\[Rule]", "2"}], ",", 
        RowBox[{"Directive", "[", 
         RowBox[{"Thick", ",", "Green"}], "]"}]}], "]"}], "}"}], ",", " ", 
     RowBox[{"VertexLabels", "\[Rule]", "Automatic"}]}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Create", " ", "a", " ", "graph"}], ",", " ", 
     RowBox[{"assign", " ", "edge", " ", "styles", " ", "as", " ", 
      RowBox[{"options", ".", " ", "The"}], " ", "EdgeStyle", " ", "option", 
      " ", "expects", " ", "a", " ", "list", " ", "of", " ", "rules", " ", 
      "assigning", " ", "styles", " ", "to", " ", "edges"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", "\[Rule]", "2"}], ",", 
       RowBox[{"2", "\[Rule]", "3"}], ",", 
       RowBox[{"3", "\[Rule]", "4"}], ",", 
       RowBox[{"4", "\[Rule]", "5"}], ",", 
       RowBox[{"5", "\[Rule]", "6"}]}], "}"}], ",", 
     RowBox[{"EdgeStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "\[Rule]", "2"}], ")"}], "\[Rule]", "Thick"}], " ", 
        ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "\[Rule]", "4"}], ")"}], "\[Rule]", "Thick"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"5", "\[Rule]", "6"}], ")"}], "\[Rule]", "Thick"}]}], 
       "}"}]}], ",", " ", 
     RowBox[{"EdgeLabels", "\[Rule]", "\"\<Name\>\""}]}], "]"}]}]}]], "Input",\

 CellChangeTimes->{{3.773397211973403*^9, 3.7733974501598997`*^9}},
 CellLabel->
  "In[417]:=",ExpressionUUID->"a4bb51d8-d9e9-4167-9e28-84fca19f5f72"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2}, {{{1, 2}}, Null}, {EdgeStyle -> {DirectedEdge[1, 2] -> {
           Directive[
            Thickness[Large], 
            RGBColor[0, 1, 0]]}}, VertexLabels -> {Automatic}, 
       VertexStyle -> {2 -> {
           RGBColor[1, 0, 0]}}}]]}, 
    TagBox[GraphicsGroupBox[{
       {RGBColor[0, 1, 0], Thickness[Large], Opacity[0.7], Arrowheads[Medium],
         ArrowBox[{{1., 0.}, {0., 1.2246467991473532`*^-16}}, 0.01273]}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {DiskBox[{1., 0.}, 0.01273], 
         InsetBox["1", Offset[{2, 2}, {1.01273, 0.01273}], ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {
         {RGBColor[1, 0, 0], DiskBox[{0., 1.2246467991473532*^-16}, 0.01273]},
          InsetBox["2", Offset[{2, 2}, {0.01273, 0.012730000000000123}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.7733972265018883`*^9, 3.7733972501135607`*^9}, {
   3.7733973781125593`*^9, 3.7733974140036077`*^9}, 3.7733974506749687`*^9},
 CellLabel->
  "Out[417]=",ExpressionUUID->"3ec1bd4d-9f53-4fdb-ae52-0c3f3bc335c7"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{1, 2, 3, 4, 5, 
      6}, {{{1, 2}, {2, 3}, {3, 4}, {4, 5}, {5, 6}}, Null}, {
      EdgeLabels -> {"Name"}, 
       EdgeStyle -> {
        DirectedEdge[3, 4] -> Thickness[Large], DirectedEdge[1, 2] -> 
         Thickness[Large], DirectedEdge[5, 6] -> Thickness[Large]}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[Medium], {
         {Thickness[Large], 
          ArrowBox[{{0., 9.797174393178826*^-16}, {1., 
           8.572527594031472*^-16}}, 0.043048128342245986`]}, InsetBox[
          RowBox[{"1", "\[DirectedEdge]", "2"}], {0.5, 9.184850993605148*^-16},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., 8.572527594031472*^-16}, {2., 
          7.347880794884119*^-16}}, 0.043048128342245986`], InsetBox[
          RowBox[{"2", "\[DirectedEdge]", "3"}], {1.5, 7.960204194457795*^-16},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Thickness[Large], 
          ArrowBox[{{2., 7.347880794884119*^-16}, {3., 
           4.898587196589412*^-16}}, 0.043048128342245986`]}, InsetBox[
          RowBox[{"3", "\[DirectedEdge]", "4"}], {2.5, 6.123233995736765*^-16},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{3., 4.898587196589412*^-16}, {4., 
          2.449293598294706*^-16}}, 0.043048128342245986`], InsetBox[
          RowBox[{"4", "\[DirectedEdge]", "5"}], {3.5, 3.673940397442059*^-16},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         {Thickness[Large], 
          ArrowBox[{{4., 2.449293598294706*^-16}, {5., 0.}}, 
           0.043048128342245986`]}, InsetBox[
          RowBox[{"5", "\[DirectedEdge]", "6"}], {4.5, 1.224646799147353*^-16},
           ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        DiskBox[{0., 9.797174393178826*^-16}, 0.043048128342245986], 
        DiskBox[{1., 8.572527594031472*^-16}, 0.043048128342245986], 
        DiskBox[{2., 7.347880794884119*^-16}, 0.043048128342245986], 
        DiskBox[{3., 4.898587196589412*^-16}, 0.043048128342245986], 
        DiskBox[{4., 2.449293598294706*^-16}, 0.043048128342245986], 
        DiskBox[{5., 0.}, 0.043048128342245986]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{{3.7733972265018883`*^9, 3.7733972501135607`*^9}, {
   3.7733973781125593`*^9, 3.7733974140036077`*^9}, 3.7733974507138367`*^9},
 CellLabel->
  "Out[418]=",ExpressionUUID->"6b0f4f15-01f9-4ed4-b651-dfb3efcd1457"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Basic Graph Properties", "Section",
 CellChangeTimes->{{3.773397484046678*^9, 
  3.773397495776655*^9}},ExpressionUUID->"39733ef3-7c47-450d-bcdc-\
246c9c6b3c14"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"g", "=", " ", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", "v"}], ",", 
       RowBox[{"s", "\[Rule]", "w"}], ",", 
       RowBox[{"v", "\[Rule]", "w"}], ",", 
       RowBox[{"v", "\[Rule]", "t"}], ",", 
       RowBox[{"w", "\[Rule]", "t"}]}], "}"}], ",", 
     RowBox[{"EdgeWeight", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1", ",", "1", ",", "2", ",", "3"}], "}"}]}], ",", 
     RowBox[{"EdgeLabels", "\[Rule]", "\"\<EdgeWeight\>\""}]}], "]"}]}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Vertex", " ", "and", " ", "Edge", " ", "Sets"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"VertexList", "[", "g", "]"}], "\[IndentingNewLine]", 
 RowBox[{"EdgeList", "[", "g", "]"}], "\[IndentingNewLine]", 
 RowBox[{"VertexCount", "[", "g", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EdgeCount", "[", "g", "]"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Graph", " ", "Matrices"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AdjacencyMatrix", "[", "g", "]"}], " ", "//", " ", 
  "MatrixForm"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]", " ", "=", 
   RowBox[{"IncidenceMatrix", "[", "g", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]", "//", "MatrixForm"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Compute", " ", "weighted", " ", "Laplacian", " ", "matrix", " ", "of", 
    " ", "the", " ", "graph"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]", ".", 
   RowBox[{"DiagonalMatrix", "[", 
    RowBox[{"{", 
     RowBox[{"2", ",", "1", ",", "1", ",", "2", ",", "3"}], "}"}], "]"}], ".", 
   RowBox[{"Transpose", "[", "\[CapitalGamma]", "]"}]}], "//", 
  "MatrixForm"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.773397501753385*^9, 3.773397503479327*^9}, {
  3.773397561670936*^9, 3.773397835339961*^9}},
 CellLabel->
  "In[439]:=",ExpressionUUID->"fae8e1fe-81f6-4e99-9a61-70e7a116b7e7"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{$CellContext`s, $CellContext`v, $CellContext`w, $CellContext`t}, \
{{{1, 2}, {1, 3}, {2, 3}, {2, 4}, {3, 4}}, Null}, {
      EdgeLabels -> {"EdgeWeight"}, EdgeWeight -> {2, 1, 1, 2, 3}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        Medium], {ArrowBox[{{0., 3.}, {1., 2.}}, 0.030239520958083826`], 
         InsetBox["2", {0.5, 2.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQjQo4HGCskPM3jr6ezw7nb/KQrNhliuCL5xwUyznI
Bue3WV5cyOCM4P/dANLACufXXVKvvaSO4HPMyzvL380C588UluUyeMIM55sY
gwCCfwWkvZYJzi+UOQ5EjHC+kCAIIPgbWaM3sEYzwPkLvnjO/+L53x7Gv3cX
BP7C+bIg4wr/wPkxG0AG/IbzZ80EgZ9wPjh4zH/A+Z8PK6U+ePkNzmcHWb/h
K4IP9u8XOP9rT+yef5Wf4Xxw8NR+gvPByqd8hPMjEv1KNA58gPMh4IM9AIO9
YI0=
          "]], 0.030239520958083826`], 
         InsetBox["1", {0., 2.}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., 2.}, {0., 1.}}, 0.030239520958083826`], 
         InsetBox["1", {0.5, 1.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7KEMBxh/+byN3dft/9vD+EkTjT6UZP+zZ4Ty
9W406d5o+guX5yle5MzY9gfO/5UI0vAbwV/iD0II9TZ3Z8mL/YTzDdWtRBJO
fIfz08DgG5y/GKz9C5z/2KIPiD7D3aOsBAKf4PKJ3NsSuLd9gPPtX062ezn5
HZy/ZzcIvIbzLUHGPX4B54N0J3A/g/ONweAxnA8OnvwHcP45/u4pjctvw90j
nnNQLOfgNbi8ZMUuU3udS3D+ivQ3j76ePw3nT7EDOfAwnP/g5bU/Gzx2wvn/
tM508rGugPNhMQcApt6NHA==
          "]], 0.030239520958083826`], 
         InsetBox["2", {1., 0.9999999999999998}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 1.}, {1., 0.}}, 0.030239520958083826`], 
         InsetBox["3", {0.5, 0.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[0.7]}], 
        DiskBox[{0., 3.}, 0.030239520958083826], 
        DiskBox[{1., 2.}, 0.030239520958083826], 
        DiskBox[{0., 1.}, 0.030239520958083826], 
        DiskBox[{1., 0.}, 0.030239520958083826]}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.7733976096712637`*^9, {3.773397728066766*^9, 3.773397739899047*^9}, {
   3.7733978099399014`*^9, 3.7733978361188803`*^9}},
 CellLabel->
  "Out[439]=",ExpressionUUID->"412ca22c-1365-4064-88ca-f1fd2240564e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"s", ",", "v", ",", "w", ",", "t"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7733976096712637`*^9, {3.773397728066766*^9, 3.773397739899047*^9}, {
   3.7733978099399014`*^9, 3.7733978361312637`*^9}},
 CellLabel->
  "Out[440]=",ExpressionUUID->"08dd9881-2367-457c-b19a-24a749742669"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"s", "\[DirectedEdge]", "v"}], ",", 
   RowBox[{"s", "\[DirectedEdge]", "w"}], ",", 
   RowBox[{"v", "\[DirectedEdge]", "w"}], ",", 
   RowBox[{"v", "\[DirectedEdge]", "t"}], ",", 
   RowBox[{"w", "\[DirectedEdge]", "t"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7733976096712637`*^9, {3.773397728066766*^9, 3.773397739899047*^9}, {
   3.7733978099399014`*^9, 3.7733978361357937`*^9}},
 CellLabel->
  "Out[441]=",ExpressionUUID->"f0b7d932-92cb-4198-a671-0f0b583e474a"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{
  3.7733976096712637`*^9, {3.773397728066766*^9, 3.773397739899047*^9}, {
   3.7733978099399014`*^9, 3.773397836139924*^9}},
 CellLabel->
  "Out[442]=",ExpressionUUID->"a2027e6c-2e52-40ff-94cb-8ea4402adb8f"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{
  3.7733976096712637`*^9, {3.773397728066766*^9, 3.773397739899047*^9}, {
   3.7733978099399014`*^9, 3.773397836143911*^9}},
 CellLabel->
  "Out[443]=",ExpressionUUID->"845f99e5-f755-465b-ae47-75aa4361f18d"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "1", "1", "0"},
     {"0", "0", "1", "1"},
     {"0", "0", "0", "1"},
     {"0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 4}, 0, {
     1, {{0, 2, 4, 5, 5}, {{2}, {3}, {3}, {4}, {4}}}, {1, 1, 1, 1, 
      1}}]]]]], "Output",
 CellChangeTimes->{
  3.7733976096712637`*^9, {3.773397728066766*^9, 3.773397739899047*^9}, {
   3.7733978099399014`*^9, 3.773397836148056*^9}},
 CellLabel->
  "Out[444]//MatrixForm=",ExpressionUUID->"2fbd5571-2402-4740-8e22-\
9e4adca06849"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0", "0", "0"},
     {"1", "0", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "0"},
     {"0", "1", "1", "0", 
      RowBox[{"-", "1"}]},
     {"0", "0", "0", "1", "1"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[
   SparseArray[
    Automatic, {4, 5}, 0, {
     1, {{0, 2, 5, 8, 10}, {{1}, {2}, {1}, {3}, {4}, {2}, {3}, {5}, {4}, {
       5}}}, {-1, -1, 1, -1, -1, 1, 1, -1, 1, 1}}]]]]], "Output",
 CellChangeTimes->{
  3.7733976096712637`*^9, {3.773397728066766*^9, 3.773397739899047*^9}, {
   3.7733978099399014`*^9, 3.773397836152426*^9}},
 CellLabel->
  "Out[446]//MatrixForm=",ExpressionUUID->"3d18e109-c527-4aec-b367-\
6ab213d4a350"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"3", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "1"}], "0"},
     {
      RowBox[{"-", "2"}], "5", 
      RowBox[{"-", "1"}], 
      RowBox[{"-", "2"}]},
     {
      RowBox[{"-", "1"}], 
      RowBox[{"-", "1"}], "5", 
      RowBox[{"-", "3"}]},
     {"0", 
      RowBox[{"-", "2"}], 
      RowBox[{"-", "3"}], "5"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7733976096712637`*^9, {3.773397728066766*^9, 3.773397739899047*^9}, {
   3.7733978099399014`*^9, 3.7733978361566153`*^9}},
 CellLabel->
  "Out[447]//MatrixForm=",ExpressionUUID->"7a31b7ea-06a3-4e73-b9ae-\
f8f5263ebd1e"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Graph Functions", "Section",
 CellChangeTimes->{{3.773397860182989*^9, 
  3.77339786554547*^9}},ExpressionUUID->"15df4ffb-4717-409e-895c-\
db70ee8b9ec8"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"g", "=", " ", 
   RowBox[{"Graph", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", "v"}], ",", 
       RowBox[{"s", "\[Rule]", "w"}], ",", 
       RowBox[{"v", "\[Rule]", "w"}], ",", 
       RowBox[{"v", "\[Rule]", "t"}], ",", 
       RowBox[{"w", "\[Rule]", "t"}]}], "}"}], ",", 
     RowBox[{"EdgeWeight", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "2", ",", "1", ",", "2", ",", "3"}], "}"}]}], ",", 
     RowBox[{"EdgeCapacity", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"2", ",", "2", ",", "1", ",", "2", ",", "3"}], "}"}]}], ",", 
     RowBox[{"EdgeLabels", "\[Rule]", "\"\<EdgeWeight\>\""}], ",", " ", 
     RowBox[{"VertexLabels", "\[Rule]", "Automatic"}]}], "]"}]}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Finds", " ", "the", " ", "shortest", " ", "path", " ", 
    RowBox[{"(", 
     RowBox[{
     "using", " ", "edge", " ", "weights", " ", "as", " ", "lengths"}], 
     " "}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FindShortestPath", "[", 
   RowBox[{"g", ",", "s", ",", "t"}], "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Finds", " ", "the", " ", "maximal", " ", "flow", " ", 
    RowBox[{"(", 
     RowBox[{
     "using", " ", "edge", " ", "capacities", " ", "as", " ", "capacities"}], 
     " "}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"FindMaximumFlow", "[", 
  RowBox[{"g", ",", "s", ",", "t"}], "]"}]}], "Input",
 CellChangeTimes->{{3.773397875684415*^9, 3.773397957554555*^9}, {
  3.773398013229972*^9, 3.773398049611071*^9}},
 CellLabel->
  "In[459]:=",ExpressionUUID->"34befd8b-163d-4811-999d-0d41777aac49"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{$CellContext`s, $CellContext`v, $CellContext`w, $CellContext`t}, \
{{{1, 2}, {1, 3}, {2, 3}, {2, 4}, {3, 4}}, Null}, {
      EdgeLabels -> {"EdgeWeight"}, VertexLabels -> {Automatic}, 
       EdgeWeight -> {2, 2, 1, 2, 3}, EdgeCapacity -> {2, 2, 1, 2, 3}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        Medium], {ArrowBox[{{0., 3.}, {1., 2.}}, 0.030239520958083826`], 
         InsetBox["2", {0.5, 2.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQjQo4HGCskPM3jr6ezw7nb/KQrNhliuCL5xwUyznI
Bue3WV5cyOCM4P/dANLACufXXVKvvaSO4HPMyzvL380C588UluUyeMIM55sY
gwCCfwWkvZYJzi+UOQ5EjHC+kCAIIPgbWaM3sEYzwPkLvnjO/+L53x7Gv3cX
BP7C+bIg4wr/wPkxG0AG/IbzZ80EgZ9wPjh4zH/A+Z8PK6U+ePkNzmcHWb/h
K4IP9u8XOP9rT+yef5Wf4Xxw8NR+gvPByqd8hPMjEv1KNA58gPMh4IM9AIO9
YI0=
          "]], 0.030239520958083826`], 
         InsetBox["2", {0., 2.}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., 2.}, {0., 1.}}, 0.030239520958083826`], 
         InsetBox["1", {0.5, 1.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7KEMBxh/+byN3dft/9vD+EkTjT6UZP+zZ4Ty
9W406d5o+guX5yle5MzY9gfO/5UI0vAbwV/iD0II9TZ3Z8mL/YTzDdWtRBJO
fIfz08DgG5y/GKz9C5z/2KIPiD7D3aOsBAKf4PKJ3NsSuLd9gPPtX062ezn5
HZy/ZzcIvIbzLUHGPX4B54N0J3A/g/ONweAxnA8OnvwHcP45/u4pjctvw90j
nnNQLOfgNbi8ZMUuU3udS3D+ivQ3j76ePw3nT7EDOfAwnP/g5bU/Gzx2wvn/
tM508rGugPNhMQcApt6NHA==
          "]], 0.030239520958083826`], 
         InsetBox["2", {1., 0.9999999999999998}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 1.}, {1., 0.}}, 0.030239520958083826`], 
         InsetBox["3", {0.5, 0.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {DiskBox[{0., 3.}, 0.030239520958083826], 
         InsetBox["s", 
          Offset[{2, 2}, {0.030239520958083826, 3.0302395209580837}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{1., 2.}, 0.030239520958083826], 
         InsetBox["v", 
          Offset[{2, 2}, {1.030239520958084, 2.0302395209580837}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{0., 1.}, 0.030239520958083826], 
         InsetBox["w", 
          Offset[{2, 2}, {0.030239520958083826, 1.030239520958084}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.030239520958083826], 
         InsetBox["t", 
          Offset[{2, 2}, {1.030239520958084, 0.030239520958083826}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.773397888851872*^9, {3.773397942815707*^9, 3.773397958155395*^9}, {
   3.7733980296487513`*^9, 3.77339805037421*^9}},
 CellLabel->
  "Out[459]=",ExpressionUUID->"02ba376c-a6cc-40f8-ba4e-74e3a30b9865"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"s", ",", "v", ",", "t"}], "}"}]], "Output",
 CellChangeTimes->{
  3.773397888851872*^9, {3.773397942815707*^9, 3.773397958155395*^9}, {
   3.7733980296487513`*^9, 3.773398050385132*^9}},
 CellLabel->
  "Out[460]=",ExpressionUUID->"742ea0dc-0202-49a4-b6b9-57a816aa49ac"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{
  3.773397888851872*^9, {3.773397942815707*^9, 3.773397958155395*^9}, {
   3.7733980296487513`*^9, 3.7733980503894243`*^9}},
 CellLabel->
  "Out[461]=",ExpressionUUID->"6d1652d1-f7ec-42bb-8283-c83a978a6fe2"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{858, 876},
WindowMargins->{{81, Automatic}, {Automatic, 28}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 161, 3, 98, "Title",ExpressionUUID->"05b2e0a9-d600-47e1-bd32-a2e3935d0311"],
Cell[CellGroupData[{
Cell[766, 29, 160, 3, 67, "Section",ExpressionUUID->"d0670f6f-1414-4742-9f97-f008e4d6b286"],
Cell[929, 34, 732, 13, 150, "Text",ExpressionUUID->"eb920e49-f19b-4e07-91fb-29294e8e20c9"],
Cell[CellGroupData[{
Cell[1686, 51, 1642, 40, 157, "Input",ExpressionUUID->"e0598faa-1e74-4fe1-88d0-97b3238b8519"],
Cell[3331, 93, 289, 6, 34, "Output",ExpressionUUID->"c4366c30-6e3b-4a92-afed-016bfdedf936"],
Cell[3623, 101, 291, 6, 34, "Output",ExpressionUUID->"8eeb1601-5a44-4ab8-83f3-23a6838b10ba"],
Cell[3917, 109, 1378, 28, 122, "Output",ExpressionUUID->"6e2e1f44-7f84-4023-8c63-ee3781dd4c42"],
Cell[5298, 139, 1578, 31, 449, "Output",ExpressionUUID->"dc5e2310-482f-4d48-a80a-4584dc8990d2"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[6925, 176, 168, 3, 53, "Section",ExpressionUUID->"4455a87a-89b3-428c-b6af-4629da6a1309"],
Cell[CellGroupData[{
Cell[7118, 183, 184, 3, 54, "Subsection",ExpressionUUID->"b3d42282-c779-43e7-a4bf-8c2350a352a1"],
Cell[7305, 188, 655, 12, 104, "Text",ExpressionUUID->"6efb6d5e-def5-44ee-ba6e-6f445ab03342"],
Cell[CellGroupData[{
Cell[7985, 204, 1971, 48, 157, "Input",ExpressionUUID->"c23fd7b6-5124-44d8-9e6c-e837f8423407"],
Cell[9959, 254, 2561, 59, 339, "Output",ExpressionUUID->"c66789a0-cf4a-420e-b7d6-862dd875cef7"],
Cell[12523, 315, 2591, 55, 339, "Output",ExpressionUUID->"6fe8e200-50c2-4cfa-a57f-96e3c9237081"],
Cell[15117, 372, 989, 28, 76, "Output",ExpressionUUID->"0b0d676e-44d3-49c4-94e5-bbeab11aa209"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[16155, 406, 154, 3, 54, "Subsection",ExpressionUUID->"830048c9-9051-41f7-b07c-6dda1be382bc"],
Cell[16312, 411, 385, 8, 58, "Text",ExpressionUUID->"69829f1a-bb48-4683-a9ad-febb2636b709"],
Cell[CellGroupData[{
Cell[16722, 423, 2201, 59, 136, "Input",ExpressionUUID->"a4bb51d8-d9e9-4167-9e28-84fca19f5f72"],
Cell[18926, 484, 1479, 30, 48, "Output",ExpressionUUID->"3ec1bd4d-9f53-4fdb-ae52-0c3f3bc335c7"],
Cell[20408, 516, 2908, 56, 38, "Output",ExpressionUUID->"6b0f4f15-01f9-4ed4-b651-dfb3efcd1457"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[23377, 579, 167, 3, 53, "Section",ExpressionUUID->"39733ef3-7c47-450d-bcdc-246c9c6b3c14"],
Cell[CellGroupData[{
Cell[23569, 586, 2108, 50, 325, "Input",ExpressionUUID->"fae8e1fe-81f6-4e99-9a61-70e7a116b7e7"],
Cell[25680, 638, 2652, 51, 449, "Output",ExpressionUUID->"412ca22c-1365-4064-88ca-f1fd2240564e"],
Cell[28335, 691, 323, 7, 34, "Output",ExpressionUUID->"08dd9881-2367-457c-b19a-24a749742669"],
Cell[28661, 700, 523, 12, 34, "Output",ExpressionUUID->"f0b7d932-92cb-4198-a671-0f0b583e474a"],
Cell[29187, 714, 256, 5, 34, "Output",ExpressionUUID->"a2027e6c-2e52-40ff-94cb-8ea4402adb8f"],
Cell[29446, 721, 256, 5, 34, "Output",ExpressionUUID->"845f99e5-f755-465b-ae47-75aa4361f18d"],
Cell[29705, 728, 1014, 29, 94, "Output",ExpressionUUID->"2fbd5571-2402-4740-8e22-9e4adca06849"],
Cell[30722, 759, 1191, 34, 94, "Output",ExpressionUUID->"3d18e109-c527-4aec-b367-6ab213d4a350"],
Cell[31916, 795, 1123, 35, 94, "Output",ExpressionUUID->"7a31b7ea-06a3-4e73-b9ae-f8f5263ebd1e"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[33088, 836, 159, 3, 53, "Section",ExpressionUUID->"15df4ffb-4717-409e-895c-db70ee8b9ec8"],
Cell[CellGroupData[{
Cell[33272, 843, 1685, 41, 136, "Input",ExpressionUUID->"34befd8b-163d-4811-999d-0d41777aac49"],
Cell[34960, 886, 3337, 65, 449, "Output",ExpressionUUID->"02ba376c-a6cc-40f8-ba4e-74e3a30b9865"],
Cell[38300, 953, 309, 7, 34, "Output",ExpressionUUID->"742ea0dc-0202-49a4-b6b9-57a816aa49ac"],
Cell[38612, 962, 256, 5, 34, "Output",ExpressionUUID->"6d1652d1-f7ec-42bb-8283-c83a978a6fe2"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

