(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     35928,       1015]
NotebookOptionsPosition[     32457,        948]
NotebookOutlinePosition[     32812,        964]
CellTagsIndexPosition[     32769,        961]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Session 5: Optimization", "Title",
 CellChangeTimes->{{3.773398173842546*^9, 
  3.773398180739665*^9}},ExpressionUUID->"e4ed4572-67c2-4916-b3a1-\
16afad4708b8"],

Cell["\<\
Mathematica provides the functions Maximize and Minimize that can solve all \
kinds of optimization problems. Further, there are functions like \
LinearProgramming to use specified solution methods.\
\>", "Text",
 CellChangeTimes->{{3.773398617261024*^9, 
  3.773398699864747*^9}},ExpressionUUID->"ef0c37f0-56f9-4ad4-9455-\
ecb39c5cf0f1"],

Cell[CellGroupData[{

Cell["Optimization using Maximize/Minimize", "Section",
 CellChangeTimes->{{3.77339871135421*^9, 3.773398724929152*^9}, {
  3.773398826495655*^9, 3.773398827159371*^9}, {3.773398949020996*^9, 
  3.773398949505487*^9}, {3.773399829725296*^9, 
  3.773399838523506*^9}},ExpressionUUID->"0313d4a7-ccc4-4ff2-b0d9-\
51861ded2445"],

Cell[CellGroupData[{

Cell["Optimizing functions", "Subsection",
 CellChangeTimes->{{3.773398960226721*^9, 
  3.773398964928503*^9}},ExpressionUUID->"a7c69e81-28ce-4448-883b-\
7fad9dda4f8a"],

Cell[TextData[{
 "The function Maximize (or Minimize) takes in general two arguments, an \
expression that should be optimized, and the optimization variable. It \
returns in general a list with two entries: the first one is the optimal \
value, the second one is a (list of) rule(s) specifying the optimal solution. \
\nMaximize/Minimize return in general ",
 StyleBox["some",
  FontSlant->"Italic"],
 " optimal solution, not ",
 StyleBox["all",
  FontSlant->"Italic"],
 " optimal solutions."
}], "Text",
 CellChangeTimes->{{3.773398791151029*^9, 
  3.773398936669606*^9}},ExpressionUUID->"d47d1d53-634d-4a3a-bc2e-\
f9fd014a6fe5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Maximize", " ", "a", " ", "parabola"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Maximize", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"x", "^", "2"}]}], "-", 
      RowBox[{"2", "x"}], "+", "1"}], ",", "x"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Maximize", " ", "a", " ", "constant", " ", 
     RowBox[{"function", " ", "--"}], " ", "Returns", " ", "an", " ", 
     "arbitrary", " ", "optimal", " ", "solution"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Maximize", "[", 
    RowBox[{"1", ",", "x"}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Maximize", " ", "a", " ", "parametrized", " ", "function"}], " ",
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Unset", "[", "a", "]"}], ";", 
    RowBox[{"Unset", "[", "b", "]"}], ";", 
    RowBox[{"Unset", "[", "c", "]"}], ";", 
    RowBox[{"Unset", "[", "d", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"solution", " ", "=", " ", 
    RowBox[{"Maximize", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", "c"}], "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "-", "a"}], ")"}], "^", "2"}]}], "-", 
       RowBox[{"d", "*", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "-", "d"}], ")"}], "^", "2"}]}]}], ",", "x"}], "]"}]}],
    "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Simplify", " ", "the", " ", "solution"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Simplify", "[", "solution", "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Maximize", " ", "a", " ", "function", " ", "depending", " ", "on", " ", 
     "two", " ", "varialbes"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Maximize", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", "x", "]"}], "*", 
      RowBox[{"Cos", "[", "y", "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.773398729308838*^9, 3.773398739871253*^9}, {
  3.773398772872856*^9, 3.77339878006772*^9}, {3.7733989721685953`*^9, 
  3.773399282735427*^9}, {3.7733993300590963`*^9, 3.7733994258722897`*^9}},
 CellLabel->
  "In[544]:=",ExpressionUUID->"2890a011-0704-49ea-ad13-aaeaa5aba636"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"-", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773398740481674*^9, 3.773398780603203*^9, {3.7733990332236137`*^9, 
   3.773399053087438*^9}, {3.773399106068203*^9, 3.7733991564342823`*^9}, {
   3.773399251408101*^9, 3.77339928302925*^9}, 3.77339933065641*^9, {
   3.773399367741398*^9, 3.773399426467008*^9}},
 CellLabel->
  "Out[544]=",ExpressionUUID->"372be69c-9921-4244-9f07-81bc4051cc15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["12", "5"]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773398740481674*^9, 3.773398780603203*^9, {3.7733990332236137`*^9, 
   3.773399053087438*^9}, {3.773399106068203*^9, 3.7733991564342823`*^9}, {
   3.773399251408101*^9, 3.77339928302925*^9}, 3.77339933065641*^9, {
   3.773399367741398*^9, 3.773399426475801*^9}},
 CellLabel->
  "Out[545]=",ExpressionUUID->"1d05ad24-eba4-4bc9-8450-6125ad48b602"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], " ", "c"}], "-", 
           SuperscriptBox["d", "3"]}], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", ">", "0"}], "&&", 
             RowBox[{"c", "\[Equal]", 
              RowBox[{"-", "d"}]}], "&&", 
             RowBox[{"a", "\[Equal]", 
              RowBox[{"-", 
               FractionBox[
                SuperscriptBox["d", "2"], "c"]}]}]}], ")"}], "||", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", "<", "0"}], "&&", 
             RowBox[{"c", "\[Equal]", 
              RowBox[{"-", "d"}]}], "&&", 
             RowBox[{"a", "\[Equal]", 
              RowBox[{"-", 
               FractionBox[
                SuperscriptBox["d", "2"], "c"]}]}]}], ")"}]}]},
         {
          FractionBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", "c", " ", "d"}], "+", 
            RowBox[{"2", " ", "a", " ", "c", " ", 
             SuperscriptBox["d", "2"]}], "-", 
            RowBox[{"c", " ", 
             SuperscriptBox["d", "3"]}]}], 
           RowBox[{"c", "+", "d"}]], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", ">", "0"}], "&&", 
             RowBox[{"c", ">", 
              RowBox[{"-", "d"}]}]}], ")"}], "||", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", "<", "0"}], "&&", 
             RowBox[{"c", ">", 
              RowBox[{"-", "d"}]}]}], ")"}]}]},
         {"\[Infinity]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", "\[Equal]", "0"}], "&&", 
             RowBox[{"c", "<", "0"}]}], ")"}], "||", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", ">", "0"}], "&&", 
             RowBox[{"c", "<", 
              RowBox[{"-", "d"}]}]}], ")"}], "||", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", "<", "0"}], "&&", 
             RowBox[{"c", "<", 
              RowBox[{"-", "d"}]}]}], ")"}], "||", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", ">", "0"}], "&&", 
             RowBox[{"c", "\[Equal]", 
              RowBox[{"-", "d"}]}], "&&", 
             RowBox[{"a", ">", 
              RowBox[{"-", 
               FractionBox[
                SuperscriptBox["d", "2"], "c"]}]}]}], ")"}], "||", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", ">", "0"}], "&&", 
             RowBox[{"c", "\[Equal]", 
              RowBox[{"-", "d"}]}], "&&", 
             RowBox[{"a", "<", 
              RowBox[{"-", 
               FractionBox[
                SuperscriptBox["d", "2"], "c"]}]}]}], ")"}], "||", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", "<", "0"}], "&&", 
             RowBox[{"c", "\[Equal]", 
              RowBox[{"-", "d"}]}], "&&", 
             RowBox[{"a", ">", 
              RowBox[{"-", 
               FractionBox[
                SuperscriptBox["d", "2"], "c"]}]}]}], ")"}], "||", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", "<", "0"}], "&&", 
             RowBox[{"c", "\[Equal]", 
              RowBox[{"-", "d"}]}], "&&", 
             RowBox[{"a", "<", 
              RowBox[{"-", 
               FractionBox[
                SuperscriptBox["d", "2"], "c"]}]}]}], ")"}]}]},
         {"0", 
          TagBox["True",
           "PiecewiseDefault",
           AutoDelete->True]}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {"a", 
            RowBox[{
             RowBox[{"d", "\[Equal]", "0"}], "&&", 
             RowBox[{"c", ">", "0"}]}]},
           {
            FractionBox[
             RowBox[{
              RowBox[{"a", " ", "c"}], "+", 
              SuperscriptBox["d", "2"]}], 
             RowBox[{"c", "+", "d"}]], 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d", ">", "0"}], "&&", 
               RowBox[{"c", ">", 
                RowBox[{"-", "d"}]}]}], ")"}], "||", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d", "<", "0"}], "&&", 
               RowBox[{"c", ">", 
                RowBox[{"-", "d"}]}]}], ")"}]}]},
           {"0", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d", "\[Equal]", "0"}], "&&", 
               RowBox[{"c", "\[Equal]", "0"}]}], ")"}], "||", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d", ">", "0"}], "&&", 
               RowBox[{"c", "\[Equal]", 
                RowBox[{"-", "d"}]}], "&&", 
               RowBox[{"a", "\[Equal]", 
                RowBox[{"-", 
                 FractionBox[
                  SuperscriptBox["d", "2"], "c"]}]}]}], ")"}], "||", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"d", "<", "0"}], "&&", 
               RowBox[{"c", "\[Equal]", 
                RowBox[{"-", "d"}]}], "&&", 
               RowBox[{"a", "\[Equal]", 
                RowBox[{"-", 
                 FractionBox[
                  SuperscriptBox["d", "2"], "c"]}]}]}], ")"}]}]},
           {"Indeterminate", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773398740481674*^9, 3.773398780603203*^9, {3.7733990332236137`*^9, 
   3.773399053087438*^9}, {3.773399106068203*^9, 3.7733991564342823`*^9}, {
   3.773399251408101*^9, 3.77339928302925*^9}, 3.77339933065641*^9, {
   3.773399367741398*^9, 3.773399426502824*^9}},
 CellLabel->
  "Out[547]=",ExpressionUUID->"9a757609-ccdf-45f9-b09e-fa771d88530c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], " ", "c"}], "-", 
           SuperscriptBox["d", "3"]}], 
          RowBox[{
           RowBox[{
            RowBox[{"c", "+", "d"}], "\[Equal]", "0"}], "&&", 
           RowBox[{
            RowBox[{"a", "+", 
             FractionBox[
              SuperscriptBox["d", "2"], "c"]}], "\[Equal]", "0"}], "&&", 
           RowBox[{"d", "\[NotEqual]", "0"}]}]},
         {
          RowBox[{"-", 
           FractionBox[
            RowBox[{"c", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"a", "-", "d"}], ")"}], "2"], " ", "d"}], 
            RowBox[{"c", "+", "d"}]]}], 
          RowBox[{
           RowBox[{"d", "\[NotEqual]", "0"}], "&&", 
           RowBox[{
            RowBox[{"c", "+", "d"}], ">", "0"}]}]},
         {"\[Infinity]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", "\[Equal]", "0"}], "&&", 
             RowBox[{"c", "<", "0"}]}], ")"}], "||", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"d", "\[NotEqual]", "0"}], "&&", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"c", "+", "d"}], "<", "0"}], "||", 
               RowBox[{
                RowBox[{"c", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"a", " ", "c"}], "+", 
                   SuperscriptBox["d", "2"]}], ")"}]}], "\[NotEqual]", 
                "0"}]}], ")"}], "&&", 
             RowBox[{
              RowBox[{"c", "+", "d"}], "\[LessEqual]", "0"}]}], ")"}]}]},
         {"0", 
          TagBox["True",
           "PiecewiseDefault",
           AutoDelete->True]}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False], ",", 
   RowBox[{"{", 
    RowBox[{"x", "\[Rule]", 
     TagBox[GridBox[{
        {"\[Piecewise]", GridBox[{
           {"a", 
            RowBox[{
             RowBox[{"d", "\[Equal]", "0"}], "&&", 
             RowBox[{"c", ">", "0"}]}]},
           {
            FractionBox[
             RowBox[{
              RowBox[{"a", " ", "c"}], "+", 
              SuperscriptBox["d", "2"]}], 
             RowBox[{"c", "+", "d"}]], 
            RowBox[{
             RowBox[{"d", "\[NotEqual]", "0"}], "&&", 
             RowBox[{
              RowBox[{"c", "+", "d"}], ">", "0"}]}]},
           {"0", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"c", "\[Equal]", "0"}], "&&", 
               RowBox[{"d", "\[Equal]", "0"}]}], ")"}], "||", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"c", "+", "d"}], "\[Equal]", "0"}], "&&", 
               RowBox[{
                RowBox[{"a", "+", 
                 FractionBox[
                  SuperscriptBox["d", "2"], "c"]}], "\[Equal]", "0"}], "&&", 
               RowBox[{"d", "\[NotEqual]", "0"}]}], ")"}]}]},
           {"Indeterminate", 
            TagBox["True",
             "PiecewiseDefault",
             AutoDelete->True]}
          },
          AllowedDimensions->{2, Automatic},
          Editable->True,
          
          GridBoxAlignment->{
           "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{1.}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.84]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}},
          Selectable->True]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}},
          "RowsIndexed" -> {}},
       GridBoxItemSize->{
        "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
         "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.35]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      "Piecewise",
      DeleteWithContents->True,
      Editable->False,
      SelectWithContents->True,
      Selectable->False]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773398740481674*^9, 3.773398780603203*^9, {3.7733990332236137`*^9, 
   3.773399053087438*^9}, {3.773399106068203*^9, 3.7733991564342823`*^9}, {
   3.773399251408101*^9, 3.77339928302925*^9}, 3.77339933065641*^9, {
   3.773399367741398*^9, 3.7733994265507107`*^9}},
 CellLabel->
  "Out[548]=",ExpressionUUID->"df76e7d9-f99e-49d3-b770-a3a6be36a2c6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"97", " ", "\[Pi]"}], "2"]}]}], ",", 
     RowBox[{"y", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "11"}], " ", "\[Pi]"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773398740481674*^9, 3.773398780603203*^9, {3.7733990332236137`*^9, 
   3.773399053087438*^9}, {3.773399106068203*^9, 3.7733991564342823`*^9}, {
   3.773399251408101*^9, 3.77339928302925*^9}, 3.77339933065641*^9, {
   3.773399367741398*^9, 3.773399426593902*^9}},
 CellLabel->
  "Out[549]=",ExpressionUUID->"a29cac69-9f35-4593-bf8c-1048ac908852"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Optimization with constraints", "Subsection",
 CellChangeTimes->{{3.77339943975879*^9, 
  3.77339946381579*^9}},ExpressionUUID->"1d899355-30e1-484f-bf38-\
d4f7352c3ce7"],

Cell["\<\
When the expression in Maximize[ expr, var ] is a list, then the first entry \
in the list is interpreted as the objective function, all further entries can \
be side-constraints (Equalitities, Inequalities)\
\>", "Text",
 CellChangeTimes->{{3.773399469993658*^9, 
  3.773399529752101*^9}},ExpressionUUID->"20ce44c9-f96f-477d-b9f2-\
53278ebff511"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Multivariate", " ", "optimization", " ", "with", " ", "an", " ", 
    "equality", " ", "constraint"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Maximize", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "+", "y"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], "\[Equal]", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y"}], "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "A", " ", "quadratic", " ", "program", " ", "of", " ", "the", " ", 
      "form", " ", 
      RowBox[{"x", ".", "Q", ".", "x"}]}], " ", "+", " ", 
     RowBox[{
      RowBox[{"p", ".", "x"}], " ", "with", " ", "side", " ", 
      "constraints"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Q", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"2", ",", 
         RowBox[{"-", "1"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "2"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"p", "=", 
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}]}], "\[IndentingNewLine]", 
   RowBox[{"Maximize", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x1", ",", "x2"}], "}"}], ".", "Q", ".", 
         RowBox[{"{", 
          RowBox[{"x1", ",", "x2"}], "}"}]}], "+", 
        RowBox[{"p", ".", 
         RowBox[{"{", 
          RowBox[{"x1", ",", "x2"}], "}"}]}]}], ",", 
       RowBox[{
        RowBox[{"x1", "+", "x2"}], "\[GreaterEqual]", "2"}], ",", 
       RowBox[{
        RowBox[{"x1", "-", 
         RowBox[{"2", "x2"}]}], "\[LessEqual]", "42"}], ",", " ", 
       RowBox[{"x1", "\[GreaterEqual]", "0"}], ",", 
       RowBox[{"x2", "\[LessEqual]", "0"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x1", ",", "x2"}], "}"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.773399532304178*^9, 3.773399769572163*^9}},
 CellLabel->
  "In[578]:=",ExpressionUUID->"f45e272d-c03e-492d-8fdb-7272afd3649a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SqrtBox["2"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      FractionBox["1", 
       SqrtBox["2"]]}], ",", 
     RowBox[{"y", "\[Rule]", 
      FractionBox["1", 
       SqrtBox["2"]]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773399553268818*^9, {3.773399694658752*^9, 3.773399770321376*^9}},
 CellLabel->
  "Out[578]=",ExpressionUUID->"3ec7458a-2971-4fb0-8c18-ec4b424a01e7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{
  3.773399553268818*^9, {3.773399694658752*^9, 3.773399770330443*^9}},
 CellLabel->
  "Out[580]=",ExpressionUUID->"d768784a-7ce1-4f5e-970f-6111a421f995"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3612", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x1", "\[Rule]", "42"}], ",", 
     RowBox[{"x2", "\[Rule]", "0"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773399553268818*^9, {3.773399694658752*^9, 3.773399770334614*^9}},
 CellLabel->
  "Out[581]=",ExpressionUUID->"5658aae8-68ca-4574-baf9-d83683597675"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Integer Programs", "Subsection",
 CellChangeTimes->{{3.773399887346662*^9, 
  3.773399899994388*^9}},ExpressionUUID->"6cdc5e46-a34d-4afb-a8c8-\
10a6a370ac49"],

Cell["\<\
The functions Maximize/Minimize take as third parameter a domain restriction, \
in particular this domain can be integers\
\>", "Text",
 CellChangeTimes->{{3.7733999090446463`*^9, 3.773399943442184*^9}, {
  3.773400028619214*^9, 
  3.773400038303226*^9}},ExpressionUUID->"2a47fda8-d949-40f6-a479-\
7b47943a892b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Maximize", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"2", "x"}], "+", 
      RowBox[{"3", "y"}], "-", "z"}], ",", 
     RowBox[{"1", "\[LessEqual]", 
      RowBox[{"x", "+", "y", "+", "z"}], "\[LessEqual]", "2"}], ",", 
     RowBox[{"1", "\[LessEqual]", 
      RowBox[{"x", "-", "y", "+", "z"}], "\[LessEqual]", "2"}], ",", 
     RowBox[{
      RowBox[{"x", "-", "y", "-", "z"}], "\[Equal]", "3"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", " ", "Integers"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7734001123317432`*^9, 3.773400136596692*^9}, {
  3.773400168145832*^9, 3.773400174756312*^9}},
 CellLabel->
  "In[586]:=",ExpressionUUID->"8f96ce4a-3e7e-45d0-951a-9b5b6ce754d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", "2"}], ",", 
     RowBox[{"y", "\[Rule]", "0"}], ",", 
     RowBox[{"z", "\[Rule]", 
      RowBox[{"-", "1"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.773400124799025*^9, 3.7734001370522213`*^9}, {
  3.773400168672727*^9, 3.773400174894125*^9}},
 CellLabel->
  "Out[586]=",ExpressionUUID->"805e4c9c-a000-4c34-b89d-96f94b65ca70"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Linear Programming", "Section",
 CellChangeTimes->{{3.773400188408909*^9, 
  3.7734002097548532`*^9}},ExpressionUUID->"4327b0ad-c7dd-40c1-b193-\
4e6f8ff07bf7"],

Cell[TextData[{
 "Mathematica provides the function LinearProgramming[ c, A , b ] to solve \
linear programs of the form \n",
 Cell[BoxData[{
  FormBox[
   RowBox[{"min", " ", 
    SuperscriptBox["c", "T"], "x"}], TraditionalForm], "\[IndentingNewLine]", 
 
  FormBox[
   RowBox[{"     ", 
    RowBox[{
     RowBox[{
      RowBox[{"s", ".", "t", ".", " ", "A"}], " ", "x"}], " ", 
     "\[GreaterEqual]", " ", "b"}]}], TraditionalForm], "\[IndentingNewLine]", 
  FormBox[
   RowBox[{"                  ", 
    RowBox[{"x", " ", "\[GreaterEqual]", " ", "0"}]}], TraditionalForm]}],
  FormatType->"TraditionalForm",ExpressionUUID->
  "1c2c198d-0832-476c-b7fb-6f9b3a44bf69"],
 "\nLinearProgramming[ ] returns the optimal solution as a vector."
}], "Text",
 CellChangeTimes->{{3.773400214855364*^9, 3.773400241660342*^9}, {
  3.773400284851413*^9, 3.773400333923142*^9}, {3.773400393941687*^9, 
  3.7734004140254583`*^9}},ExpressionUUID->"2af64346-42e5-4236-80e9-\
a4b7e0162d48"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Solves", " ", "minimize", " ", "x"}], " ", "+", " ", 
     RowBox[{"y", " ", 
      RowBox[{"s", ".", "t", ".", " ", "x"}]}], " ", "+", " ", 
     RowBox[{"2", "y"}]}], " ", "\[GreaterEqual]", " ", "3"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"x", "=", 
    RowBox[{"LinearProgramming", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}], "}"}], ",", 
      RowBox[{"{", "3", "}"}]}], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Compute", " ", "the", " ", "optmal", " ", "value"}], " ", "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], ".", "x"}], "\[IndentingNewLine]", 
   RowBox[{"Unset", "[", "x", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7734002466800117`*^9, 3.773400247078063*^9}, {
  3.773400317228786*^9, 3.773400378844078*^9}, {3.773400425605309*^9, 
  3.7734004448707047`*^9}, {3.773400530860924*^9, 3.773400532748268*^9}},
 CellLabel->
  "In[594]:=",ExpressionUUID->"bb8e1c0d-1cef-4a48-892c-5a388f21484e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox["3", "2"]}], "}"}]], "Output",
 CellChangeTimes->{
  3.773400339537842*^9, 3.773400379949844*^9, {3.773400437648798*^9, 
   3.773400445387217*^9}, 3.7734005332602253`*^9},
 CellLabel->
  "Out[594]=",ExpressionUUID->"bb16452d-ac78-44b9-810e-78925c1bd53d"],

Cell[BoxData[
 FractionBox["3", "2"]], "Output",
 CellChangeTimes->{
  3.773400339537842*^9, 3.773400379949844*^9, {3.773400437648798*^9, 
   3.773400445387217*^9}, 3.773400533273687*^9},
 CellLabel->
  "Out[595]=",ExpressionUUID->"3df0a7df-9ae8-4637-9441-046e3fa4a9f5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical Optimization", "Section",
 CellChangeTimes->{{3.773400464185741*^9, 
  3.773400477361459*^9}},ExpressionUUID->"04c72501-cbb7-4dcd-b0a9-\
d97d083e00a7"],

Cell["\<\
The functions NMaximize and NMinimize apply numerical optimization whenever \
analytical solutions is are not possible.\
\>", "Text",
 CellChangeTimes->{{3.7734005406887074`*^9, 
  3.773400571356336*^9}},ExpressionUUID->"d23d0d37-5b79-4cf4-a2c9-\
8d4aa334e4dc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NMaximize", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"E", "^", 
       RowBox[{"(", 
        RowBox[{"Sin", "[", 
         RowBox[{"50", " ", "x"}], "]"}], ")"}]}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{"60", " ", 
        RowBox[{"E", "^", "y"}]}], "]"}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{"70", " ", 
        RowBox[{"Sin", "[", "x", "]"}]}], "]"}], "+", 
      RowBox[{"Sin", "[", 
       RowBox[{"Sin", "[", 
        RowBox[{"80", " ", "y"}], "]"}], "]"}], "-", 
      RowBox[{"Sin", "[", 
       RowBox[{"10", " ", 
        RowBox[{"(", 
         RowBox[{"x", "+", "y"}], ")"}]}], "]"}], "+", 
      RowBox[{
       RowBox[{"1", "/", "4"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"x", "^", "2"}], "+", 
         RowBox[{"y", "^", "2"}]}], ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "^", "2"}], "+", 
       RowBox[{"y", "^", "2"}]}], "\[LessEqual]", "1"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.773400479095037*^9, 3.77340050829729*^9}},
 CellLabel->
  "In[598]:=",ExpressionUUID->"db870234-fd2b-4896-a2e9-02d09f4805a0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.303876970561731`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "\[Rule]", 
      RowBox[{"-", "0.15837499104982783`"}]}], ",", 
     RowBox[{"y", "\[Rule]", "0.6476622954254764`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.773400509051305*^9, 3.773400535457312*^9}, 
   3.773400574744235*^9},
 CellLabel->
  "Out[598]=",ExpressionUUID->"b84654e7-d1c9-4f93-bc91-7aeca7f2a8ae"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 857},
WindowMargins->{{Automatic, 551}, {47, Automatic}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 166, 3, 98, "Title",ExpressionUUID->"e4ed4572-67c2-4916-b3a1-16afad4708b8"],
Cell[749, 27, 348, 7, 58, "Text",ExpressionUUID->"ef0c37f0-56f9-4ad4-9455-ecb39c5cf0f1"],
Cell[CellGroupData[{
Cell[1122, 38, 324, 5, 67, "Section",ExpressionUUID->"0313d4a7-ccc4-4ff2-b0d9-51861ded2445"],
Cell[CellGroupData[{
Cell[1471, 47, 168, 3, 54, "Subsection",ExpressionUUID->"a7c69e81-28ce-4448-883b-7fad9dda4f8a"],
Cell[1642, 52, 631, 15, 104, "Text",ExpressionUUID->"d47d1d53-634d-4a3a-bc2e-f9fd014a6fe5"],
Cell[CellGroupData[{
Cell[2298, 71, 2355, 61, 241, "Input",ExpressionUUID->"2890a011-0704-49ea-ad13-aaeaa5aba636"],
Cell[4656, 134, 519, 12, 34, "Output",ExpressionUUID->"372be69c-9921-4244-9f07-81bc4051cc15"],
Cell[5178, 148, 545, 13, 51, "Output",ExpressionUUID->"1d05ad24-eba4-4bc9-8450-6125ad48b602"],
Cell[5726, 163, 8713, 242, 177, "Output",ExpressionUUID->"9a757609-ccdf-45f9-b09e-fa771d88530c"],
Cell[14442, 407, 6358, 175, 230, "Output",ExpressionUUID->"df76e7d9-f99e-49d3-b770-a3a6be36a2c6"],
Cell[20803, 584, 693, 18, 50, "Output",ExpressionUUID->"a29cac69-9f35-4593-bf8c-1048ac908852"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[21545, 608, 175, 3, 38, "Subsection",ExpressionUUID->"1d899355-30e1-484f-bf38-d4f7352c3ce7"],
Cell[21723, 613, 357, 7, 58, "Text",ExpressionUUID->"20ce44c9-f96f-477d-b9f2-53278ebff511"],
Cell[CellGroupData[{
Cell[22105, 624, 2214, 65, 157, "Input",ExpressionUUID->"f45e272d-c03e-492d-8fdb-7272afd3649a"],
Cell[24322, 691, 457, 15, 54, "Output",ExpressionUUID->"3ec7458a-2971-4fb0-8c18-ec4b424a01e7"],
Cell[24782, 708, 247, 6, 34, "Output",ExpressionUUID->"d768784a-7ce1-4f5e-970f-6111a421f995"],
Cell[25032, 716, 366, 10, 34, "Output",ExpressionUUID->"5658aae8-68ca-4574-baf9-d83683597675"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[25447, 732, 164, 3, 38, "Subsection",ExpressionUUID->"6cdc5e46-a34d-4afb-a8c8-10a6a370ac49"],
Cell[25614, 737, 322, 7, 58, "Text",ExpressionUUID->"2a47fda8-d949-40f6-a479-7b47943a892b"],
Cell[CellGroupData[{
Cell[25961, 748, 777, 20, 52, "Input",ExpressionUUID->"8f96ce4a-3e7e-45d0-951a-9b5b6ce754d6"],
Cell[26741, 770, 450, 12, 34, "Output",ExpressionUUID->"805e4c9c-a000-4c34-b89d-96f94b65ca70"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27252, 789, 165, 3, 67, "Section",ExpressionUUID->"4327b0ad-c7dd-40c1-b193-4e6f8ff07bf7"],
Cell[27420, 794, 975, 24, 126, "Text",ExpressionUUID->"2af64346-42e5-4236-80e9-a4b7e0162d48"],
Cell[CellGroupData[{
Cell[28420, 822, 1221, 31, 115, "Input",ExpressionUUID->"bb8e1c0d-1cef-4a48-892c-5a388f21484e"],
Cell[29644, 855, 319, 8, 50, "Output",ExpressionUUID->"bb16452d-ac78-44b9-810e-78925c1bd53d"],
Cell[29966, 865, 270, 6, 50, "Output",ExpressionUUID->"3df0a7df-9ae8-4637-9441-046e3fa4a9f5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30285, 877, 167, 3, 67, "Section",ExpressionUUID->"04c72501-cbb7-4dcd-b0a9-d97d083e00a7"],
Cell[30455, 882, 271, 6, 58, "Text",ExpressionUUID->"d23d0d37-5b79-4cf4-a2c9-8d4aa334e4dc"],
Cell[CellGroupData[{
Cell[30751, 892, 1223, 37, 73, "Input",ExpressionUUID->"db870234-fd2b-4896-a2e9-02d09f4805a0"],
Cell[31977, 931, 440, 12, 68, "Output",ExpressionUUID->"b84654e7-d1c9-4f93-bc91-7aeca7f2a8ae"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

