(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     36982,        873]
NotebookOptionsPosition[     34664,        828]
NotebookOutlinePosition[     35017,        844]
CellTagsIndexPosition[     34974,        841]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Computing Wardrop Equilibria via Convex Programming", "Title",
 CellChangeTimes->{{3.773299840180934*^9, 
  3.773299858802884*^9}},ExpressionUUID->"03448495-b5a7-4dc4-af71-\
28d7cd079886"],

Cell[CellGroupData[{

Cell["Input", "Section",
 CellChangeTimes->{{3.7732998967307673`*^9, 
  3.773299913619836*^9}},ExpressionUUID->"30819828-a015-46a8-8221-\
4764b5527bb5"],

Cell["\<\
Enter graph and cost function data in this section or use one of the existing \
examples\
\>", "Text",
 CellChangeTimes->{{3.773300213589114*^9, 3.773300236319919*^9}, {
  3.773300298459044*^9, 
  3.7733003126960783`*^9}},ExpressionUUID->"4e5a2b8b-89e1-4019-906b-\
dac0e1464662"],

Cell[CellGroupData[{

Cell["Braess Graph", "Subsection",
 CellChangeTimes->{{3.773300245480818*^9, 
  3.773300251969647*^9}},ExpressionUUID->"04e8b69c-0c7e-4c7c-b1f5-\
325bfd379f2c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", "Graph", " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"graph", " ", "=", " ", 
    RowBox[{"Graph", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"s", "\[Rule]", "v"}], ",", 
       RowBox[{"s", "\[Rule]", "w"}], ",", 
       RowBox[{"v", "\[Rule]", "w"}], ",", 
       RowBox[{"v", "\[Rule]", "t"}], ",", 
       RowBox[{"w", "\[Rule]", "t"}]}], "}"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Slopes", " ", "of", " ", "affine", " ", "linear", " ", "cost", " ", 
    "functions"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"a", "=", 
    RowBox[{"{", 
     RowBox[{"1", ",", "0", ",", "0", ",", "0", ",", "1"}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Offsets", " ", "of", " ", "affine", " ", "linear", " ", "cost", " ", 
    "functions"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"b", "=", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1", ",", "0", ",", "1", ",", "0"}], "}"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Specify", " ", "source", " ", "and", " ", "sink", " ", "vertices"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"source", "=", "s"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sink", "=", "t"}], ";"}]}], "Input",
 CellChangeTimes->{{3.773299879768874*^9, 3.773299888898929*^9}, {
  3.773299952811804*^9, 3.773300016500615*^9}, {3.7733007360502567`*^9, 
  3.773300745628681*^9}, {3.7733013374091167`*^9, 3.77330134138113*^9}},
 CellLabel->
  "In[176]:=",ExpressionUUID->"e6271266-35c7-4610-893f-f4d48da71d33"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Program", "Section",
 CellChangeTimes->{{3.7732999280169888`*^9, 
  3.773299937990365*^9}},ExpressionUUID->"8e0e9092-6795-46c8-a619-\
44141140bff4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Prepare", " ", 
    RowBox[{"Lists", "/", "Values"}], " ", "associated", " ", "with", " ", 
    "the", " ", "graph"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"vertices", "=", 
     RowBox[{"VertexList", "[", "graph", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"edges", "=", 
     RowBox[{"EdgeList", "[", "graph", "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"sourceIndex", "=", 
     RowBox[{
      RowBox[{"Position", "[", 
       RowBox[{"vertices", ",", "source"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"sinkIndex", "=", 
     RowBox[{
      RowBox[{"Position", "[", 
       RowBox[{"vertices", ",", "sink"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"n", "=", 
     RowBox[{"VertexCount", "[", "graph", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"m", "=", 
     RowBox[{"EdgeCount", "[", "graph", "]"}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalGamma]", "=", 
     RowBox[{"IncidenceMatrix", "[", "graph", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Create", " ", "cost", " ", "functions"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"c", "[", 
      RowBox[{"e_", ",", "x_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "[", 
        RowBox[{"[", "e", "]"}], "]"}], "*", "x"}], "+", 
      RowBox[{"b", "[", 
       RowBox[{"[", "e", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Create", " ", "itegrated", " ", "cost", " ", "functios"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"cInt", "[", 
      RowBox[{"e_", ",", "x_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Integrate", "[", 
       RowBox[{
        RowBox[{"c", "[", 
         RowBox[{"e", ",", "\[Xi]"}], "]"}], ",", "\[Xi]"}], "]"}], "/.", 
      RowBox[{"\[Xi]", "\[Rule]", "x"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Print", " ", "Graph", " ", "with", " ", "cost", " ", "functions"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Input Graph with cost functions:\>\"", "]"}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"edgelabels", "=", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"edges", "[", 
         RowBox[{"[", "e", "]"}], "]"}], "\[Rule]", 
        RowBox[{"c", "[", 
         RowBox[{"e", ",", "x"}], "]"}]}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"e", ",", "1", ",", "m"}], "}"}]}], " ", "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Graph", "[", 
    RowBox[{"graph", ",", 
     RowBox[{"VertexLabels", "\[Rule]", "Automatic"}], ",", 
     RowBox[{"EdgeLabels", "\[Rule]", "edgelabels"}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Create", " ", "list", " ", "of", " ", "flow"}], "-", 
     RowBox[{
     "variables", " ", "for", " ", "the", " ", "convex", " ", "program"}]}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"flowvars", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"f", "[", "e", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"e", ",", "1", ",", "m"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Create", " ", "the", " ", "objective", " ", "function"}], " ", 
     "\[Equal]", " ", 
     RowBox[{
     "Sum", " ", "over", " ", "all", " ", "iterated", " ", "cost", " ", 
      "functios"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"objective", "=", 
     RowBox[{"Total", "[", 
      RowBox[{"Table", "[", " ", 
       RowBox[{
        RowBox[{"cInt", "[", 
         RowBox[{"e", ",", 
          RowBox[{"flowvars", "[", 
           RowBox[{"[", "e", "]"}], "]"}]}], "]"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"e", ",", "1", ",", "m"}], "}"}]}], " ", "]"}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Create", " ", "flow", " ", "conditions"}], ",", " ", 
     RowBox[{"i", ".", "e"}], ",", " ", 
     RowBox[{"excess", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"-", "r"}], " ", "/", " ", 
          RowBox[{"+", "r"}]}], " ", "/", " ", "0"}], " ", "for", " ", "v"}], 
       " ", "=", " ", 
       RowBox[{
        RowBox[{"s", " ", "/", " ", "t"}], " ", "/", " ", "otherwise"}]}]}]}],
     " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"\[Rule]", " ", 
     RowBox[{
     "Compute", " ", "the", " ", "excess", " ", "vector", " ", "containing", 
      " ", "the", " ", "excess", " ", "of", " ", "all", " ", "vertices", " ", 
      "depending", " ", "on", " ", "the", " ", "flow", " ", "definded", " ", 
      "by", " ", "flowvars"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"excess", "=", 
     RowBox[{"\[CapitalGamma]", ".", "flowvars"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"\[Rule]", " ", 
     RowBox[{
     "Create", " ", "a", " ", "list", " ", "of", " ", "flow", " ", 
      "conservation", " ", "rules"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"flowconditions", "=", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"excess", "[", 
         RowBox[{"[", "v", "]"}], "]"}], "\[Equal]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"v", "\[Equal]", "sourceIndex"}], ",", 
          RowBox[{"-", "r"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"v", "\[Equal]", "sinkIndex"}], ",", "r", ",", "0"}], 
           "]"}]}], "]"}]}], " ", ",", 
       RowBox[{"{", 
        RowBox[{"v", ",", "1", ",", "n"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Create", " ", "non"}], "-", 
      RowBox[{"negativity", " ", "constraints", " ", 
       RowBox[{"f", "[", "e", "]"}]}]}], "\[GreaterEqual]", "0"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"nonnegconditions", "=", 
     RowBox[{"Table", "[", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"flowvars", "[", 
         RowBox[{"[", "e", "]"}], "]"}], "\[GreaterEqual]", "0"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"e", ",", "1", ",", "m"}], "}"}]}], " ", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Print", " ", "the", " ", "conxex", " ", "program"}], " ", "*)"}],
    "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Convex program:\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\< min \>\"", ",", "objective"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "n"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"praefix", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", "\[Equal]", "1"}], ",", "\"\< s.t. \>\"", ",", " ", 
          "\"\<      \>\""}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"praefix", ",", " ", 
         RowBox[{"flowconditions", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<      \>\"", ",", " ", "flowvars", ",", " ", 
      "\"\< \[GreaterEqual] 0\>\""}], "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Compute", " ", "and", " ", "print", " ", "the", " ", "solution"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "\"\<Solution:\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{
     "Create", " ", "new", " ", "flowconditions", " ", "vector", " ", "that", 
      " ", "depends", " ", "on", " ", "the", " ", "\"\<rate\>\"", " ", 
      "variable", " ", "of", " ", "the", " ", "Manipulate", " ", "function"}],
      " ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"fc", "=", 
       RowBox[{"flowconditions", "/.", 
        RowBox[{"r", "\[Rule]", "rate"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Execute", " ", "the", " ", "actual", " ", "convex", " ", 
        "optimization"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"solution", "=", 
       RowBox[{"Minimize", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", "objective", "}"}], "~", "Join", "~", "fc", "~", 
          "Join", "~", "nonnegconditions"}], ",", "flowvars"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Extract", " ", "optimal", " ", "value", " ", "and", " ", "the", " ", 
        "optimal", " ", "solution", " ", "from", " ", "the", " ", "solution", 
        " ", "variable"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"optvalue", "=", 
       RowBox[{"solution", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"optflow", "=", 
       RowBox[{"solution", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "Create", " ", "Arrays", " ", "that", " ", "describe", " ", "the", " ",
         "labels", " ", "and", " ", "the", " ", "style", " ", "of", " ", 
        "the", " ", "edges"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"edgeweights", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Table", "[", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"edges", "[", 
             RowBox[{"[", "e", "]"}], "]"}], "\[Rule]", 
            RowBox[{"f", "[", "e", "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"e", ",", "1", ",", "m"}], "}"}]}], "]"}], ")"}], "/.", 
        "optflow"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"edgestyle", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Table", "[", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"edges", "[", 
             RowBox[{"[", "e", "]"}], "]"}], "\[Rule]", " ", 
            RowBox[{"Directive", "[", 
             RowBox[{
              RowBox[{"Thickness", "[", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"1", "/", "2"}], "+", 
                  RowBox[{"f", "[", "e", "]"}]}], ")"}], "/", "50"}], "]"}], 
              ",", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"f", "[", "e", "]"}], "\[Equal]", "0"}], ",", "Gray",
                 ",", "Blue"}], "]"}]}], "]"}]}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"e", ",", "1", ",", "m"}], "}"}]}], " ", "]"}], ")"}], "/.",
         "optflow"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Create", " ", "the", " ", "actual", " ", "graph"}], ",", " ", 
        RowBox[{
        "by", " ", "copying", " ", "the", " ", "input", " ", "graph", " ", 
         "and", " ", "equipping", " ", "it", " ", "with", " ", "EdgeWeights", 
         " ", "and", " ", "Labels"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"Graph", "[", 
       RowBox[{"graph", ",", 
        RowBox[{"EdgeWeight", "\[Rule]", "edgeweights"}], ",", 
        RowBox[{"EdgeLabels", "\[Rule]", "\"\<EdgeWeight\>\""}], ",", " ", 
        RowBox[{"VertexLabels", "\[Rule]", "Automatic"}], ",", " ", 
        RowBox[{"EdgeStyle", "\[Rule]", "edgestyle"}]}], "]"}]}], 
     "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"rate", ",", "0", ",", "4", ",", 
       RowBox[{"1", "/", "1000"}]}], "}"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.773297163841174*^9, 3.773297313437759*^9}, {
  3.773297446437958*^9, 3.773297583625681*^9}, {3.773297626510837*^9, 
  3.773297737762336*^9}, {3.773297789240361*^9, 3.773298079152246*^9}, {
  3.7732981237181*^9, 3.773298376967474*^9}, {3.77329840851075*^9, 
  3.7732986294005136`*^9}, {3.773298667378293*^9, 3.773298706957796*^9}, {
  3.773298758444813*^9, 3.773299162624757*^9}, {3.773299324365149*^9, 
  3.773299465058106*^9}, {3.773299536769843*^9, 3.773299537600892*^9}, {
  3.7732995827216883`*^9, 3.773299607227841*^9}, {3.773299691171089*^9, 
  3.773299736339509*^9}, {3.773299772431077*^9, 3.773299835512567*^9}, {
  3.773300019620826*^9, 3.77330013226749*^9}, {3.773300360776925*^9, 
  3.773300698791856*^9}, {3.7733010508074713`*^9, 3.77330122743398*^9}, {
  3.7733012706700706`*^9, 3.773301281237321*^9}, {3.7734688148581057`*^9, 
  3.773468816249833*^9}},
 CellLabel->
  "In[205]:=",ExpressionUUID->"9526067e-b7b7-434f-969f-8552cabc45ff"],

Cell[BoxData["\<\"Input Graph with cost functions:\"\>"], "Print",
 CellChangeTimes->{{3.773299041354598*^9, 3.77329912385933*^9}, 
   3.7732991629390793`*^9, {3.773299382586542*^9, 3.773299465623701*^9}, {
   3.773299592723957*^9, 3.773299608774199*^9}, {3.773299693265654*^9, 
   3.7732997387918367`*^9}, 3.7733003322985497`*^9, 3.7733007006290894`*^9, 
   3.773300775621126*^9, 3.773301100020769*^9, 3.7733011928793173`*^9, {
   3.773301223340167*^9, 3.773301231840027*^9}, {3.7733012710068903`*^9, 
   3.773301281871986*^9}, 3.773307877949904*^9, 3.77346871512571*^9, 
   3.773468817041811*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"480cd305-3e54-4373-8dc4-7ea0eca1674b"],

Cell[BoxData[
 GraphicsBox[
  NamespaceBox["NetworkGraphics",
   DynamicModuleBox[{Typeset`graph = HoldComplete[
     Graph[{$CellContext`s, $CellContext`v, $CellContext`w, $CellContext`t}, \
{{{1, 2}, {1, 3}, {2, 3}, {2, 4}, {3, 4}}, Null}, {
      EdgeLabels -> {
        DirectedEdge[$CellContext`v, $CellContext`w] -> 0, 
         DirectedEdge[$CellContext`s, $CellContext`v] -> $CellContext`x, 
         DirectedEdge[$CellContext`w, $CellContext`t] -> $CellContext`x, 
         DirectedEdge[$CellContext`s, $CellContext`w] -> 1, 
         DirectedEdge[$CellContext`v, $CellContext`t] -> 1}, 
       GraphLayout -> {"Dimension" -> 2}, VertexLabels -> {Automatic}}]]}, 
    TagBox[GraphicsGroupBox[{
       {Hue[0.6, 0.7, 0.5], Opacity[0.7], Arrowheads[
        Medium], {ArrowBox[{{0., 3.}, {1., 2.}}, 0.030239520958083826`], 
         InsetBox["x", {0.5, 2.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQjQo4HGCskPM3jr6ezw7nb/KQrNhliuCL5xwUyznI
Bue3WV5cyOCM4P/dANLACufXXVKvvaSO4HPMyzvL380C588UluUyeMIM55sY
gwCCfwWkvZYJzi+UOQ5EjHC+kCAIIPgbWaM3sEYzwPkLvnjO/+L53x7Gv3cX
BP7C+bIg4wr/wPkxG0AG/IbzZ80EgZ9wPjh4zH/A+Z8PK6U+ePkNzmcHWb/h
K4IP9u8XOP9rT+yef5Wf4Xxw8NR+gvPByqd8hPMjEv1KNA58gPMh4IM9AIO9
YI0=
          "]], 0.030239520958083826`], 
         InsetBox["1", {0., 2.}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{1., 2.}, {0., 1.}}, 0.030239520958083826`], 
         InsetBox["0", {0.5, 1.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {ArrowBox[BezierCurveBox[CompressedData["
1:eJxTTMoPSmViYGCQAWIQDQEf7KEMBxh/+byN3dft/9vD+EkTjT6UZP+zZ4Ty
9W406d5o+guX5yle5MzY9gfO/5UI0vAbwV/iD0II9TZ3Z8mL/YTzDdWtRBJO
fIfz08DgG5y/GKz9C5z/2KIPiD7D3aOsBAKf4PKJ3NsSuLd9gPPtX062ezn5
HZy/ZzcIvIbzLUHGPX4B54N0J3A/g/ONweAxnA8OnvwHcP45/u4pjctvw90j
nnNQLOfgNbi8ZMUuU3udS3D+ivQ3j76ePw3nT7EDOfAwnP/g5bU/Gzx2wvn/
tM508rGugPNhMQcApt6NHA==
          "]], 0.030239520958083826`], 
         InsetBox["1", {1., 0.9999999999999998}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}, {
         ArrowBox[{{0., 1.}, {1., 0.}}, 0.030239520958083826`], 
         InsetBox["x", {0.5, 0.5}, ImageScaled[{0.5, 0.5}],
          BaseStyle->"Graphics"]}}, 
       {Hue[0.6, 0.2, 0.8], EdgeForm[{GrayLevel[0], Opacity[
        0.7]}], {DiskBox[{0., 3.}, 0.030239520958083826], 
         InsetBox["s", 
          Offset[{2, 2}, {0.030239520958083826, 3.0302395209580837}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{1., 2.}, 0.030239520958083826], 
         InsetBox["v", 
          Offset[{2, 2}, {1.030239520958084, 2.0302395209580837}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{0., 1.}, 0.030239520958083826], 
         InsetBox["w", 
          Offset[{2, 2}, {0.030239520958083826, 1.030239520958084}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}, {DiskBox[{1., 0.}, 0.030239520958083826], 
         InsetBox["t", 
          Offset[{2, 2}, {1.030239520958084, 0.030239520958083826}], 
          ImageScaled[{0, 0}],
          BaseStyle->"Graphics"]}}}],
     MouseAppearanceTag["NetworkGraphics"]],
    AllowKernelInitialization->False]],
  DefaultBaseStyle->{
   "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> Hue[0.8, 1., 0.6]},
  FormatType->TraditionalForm,
  FrameTicks->None]], "Output",
 CellChangeTimes->{
  3.7732976881878366`*^9, 3.773297738367153*^9, {3.773297833482792*^9, 
   3.773297866166225*^9}, 3.77329793093463*^9, 3.7732980794150143`*^9, 
   3.773298188459054*^9, 3.773298296461258*^9, {3.7732983615811777`*^9, 
   3.773298377211776*^9}, 3.773298416512607*^9, {3.773298547513585*^9, 
   3.773298568259864*^9}, {3.773298609562394*^9, 3.7732986300784063`*^9}, 
   3.7732987076096573`*^9, {3.773298775768705*^9, 3.773298853482463*^9}, {
   3.773298885173956*^9, 3.773298939768618*^9}, {3.773299041396473*^9, 
   3.7732991239263477`*^9}, 3.77329916299503*^9, {3.77329938264205*^9, 
   3.773299465661969*^9}, {3.773299592766193*^9, 3.7732996088152227`*^9}, {
   3.773299693313498*^9, 3.773299738842634*^9}, 3.77330033235308*^9, 
   3.773300700699239*^9, 3.773300775740025*^9, 3.773301100080578*^9, 
   3.773301192948596*^9, {3.7733012233929462`*^9, 3.7733012318872223`*^9}, {
   3.773301271059477*^9, 3.773301281924646*^9}, 3.773307878073769*^9, 
   3.773468715259149*^9, 3.77346881709702*^9},
 CellLabel->
  "Out[216]=",ExpressionUUID->"ad11c23a-c22d-4d3a-b1bc-65560f40c2d7"],

Cell[CellGroupData[{

Cell[BoxData["\<\"Convex program:\"\>"], "Print",
 CellChangeTimes->{{3.773299041354598*^9, 3.77329912385933*^9}, 
   3.7732991629390793`*^9, {3.773299382586542*^9, 3.773299465623701*^9}, {
   3.773299592723957*^9, 3.773299608774199*^9}, {3.773299693265654*^9, 
   3.7732997387918367`*^9}, 3.7733003322985497`*^9, 3.7733007006290894`*^9, 
   3.773300775621126*^9, 3.773301100020769*^9, 3.7733011928793173`*^9, {
   3.773301223340167*^9, 3.773301231840027*^9}, {3.7733012710068903`*^9, 
   3.773301281871986*^9}, 3.773307877949904*^9, 3.77346871512571*^9, 
   3.773468817102167*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"2c355d50-e4c7-4756-a6a9-9f39e94a93e7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" min \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox[
     SuperscriptBox[
      RowBox[{"f", "[", "1", "]"}], "2"], "2"], "+", 
    RowBox[{"f", "[", "2", "]"}], "+", 
    RowBox[{"f", "[", "4", "]"}], "+", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"f", "[", "5", "]"}], "2"], "2"]}]}],
  SequenceForm[
  " min ", Rational[1, 2] $CellContext`f[1]^2 + $CellContext`f[
    2] + $CellContext`f[4] + Rational[1, 2] $CellContext`f[5]^2],
  Editable->False]], "Print",
 CellChangeTimes->{{3.773299041354598*^9, 3.77329912385933*^9}, 
   3.7732991629390793`*^9, {3.773299382586542*^9, 3.773299465623701*^9}, {
   3.773299592723957*^9, 3.773299608774199*^9}, {3.773299693265654*^9, 
   3.7732997387918367`*^9}, 3.7733003322985497`*^9, 3.7733007006290894`*^9, 
   3.773300775621126*^9, 3.773301100020769*^9, 3.7733011928793173`*^9, {
   3.773301223340167*^9, 3.773301231840027*^9}, {3.7733012710068903`*^9, 
   3.773301281871986*^9}, 3.773307877949904*^9, 3.77346871512571*^9, 
   3.7734688171057577`*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"7c11fd0d-57ba-4093-ac0a-01474d25f0c7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\" s.t. \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"f", "[", "1", "]"}]}], "-", 
     RowBox[{"f", "[", "2", "]"}]}], "\[Equal]", 
    RowBox[{"-", "r"}]}]}],
  SequenceForm[
  " s.t. ", -$CellContext`f[1] - $CellContext`f[2] == -$CellContext`r],
  Editable->False]], "Print",
 CellChangeTimes->{{3.773299041354598*^9, 3.77329912385933*^9}, 
   3.7732991629390793`*^9, {3.773299382586542*^9, 3.773299465623701*^9}, {
   3.773299592723957*^9, 3.773299608774199*^9}, {3.773299693265654*^9, 
   3.7732997387918367`*^9}, 3.7733003322985497`*^9, 3.7733007006290894`*^9, 
   3.773300775621126*^9, 3.773301100020769*^9, 3.7733011928793173`*^9, {
   3.773301223340167*^9, 3.773301231840027*^9}, {3.7733012710068903`*^9, 
   3.773301281871986*^9}, 3.773307877949904*^9, 3.77346871512571*^9, 
   3.773468817111537*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"573e6455-9a8a-4ef4-983f-b572d2e97a10"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "1", "]"}], "-", 
     RowBox[{"f", "[", "3", "]"}], "-", 
     RowBox[{"f", "[", "4", "]"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "      ", $CellContext`f[1] - $CellContext`f[3] - $CellContext`f[4] == 0],
  Editable->False]], "Print",
 CellChangeTimes->{{3.773299041354598*^9, 3.77329912385933*^9}, 
   3.7732991629390793`*^9, {3.773299382586542*^9, 3.773299465623701*^9}, {
   3.773299592723957*^9, 3.773299608774199*^9}, {3.773299693265654*^9, 
   3.7732997387918367`*^9}, 3.7733003322985497`*^9, 3.7733007006290894`*^9, 
   3.773300775621126*^9, 3.773301100020769*^9, 3.7733011928793173`*^9, {
   3.773301223340167*^9, 3.773301231840027*^9}, {3.7733012710068903`*^9, 
   3.773301281871986*^9}, 3.773307877949904*^9, 3.77346871512571*^9, 
   3.7734688171147823`*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"d24dfe71-2ee8-4be3-8c4c-ff234df99348"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "2", "]"}], "+", 
     RowBox[{"f", "[", "3", "]"}], "-", 
     RowBox[{"f", "[", "5", "]"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "      ", $CellContext`f[2] + $CellContext`f[3] - $CellContext`f[5] == 0],
  Editable->False]], "Print",
 CellChangeTimes->{{3.773299041354598*^9, 3.77329912385933*^9}, 
   3.7732991629390793`*^9, {3.773299382586542*^9, 3.773299465623701*^9}, {
   3.773299592723957*^9, 3.773299608774199*^9}, {3.773299693265654*^9, 
   3.7732997387918367`*^9}, 3.7733003322985497`*^9, 3.7733007006290894`*^9, 
   3.773300775621126*^9, 3.773301100020769*^9, 3.7733011928793173`*^9, {
   3.773301223340167*^9, 3.773301231840027*^9}, {3.7733012710068903`*^9, 
   3.773301281871986*^9}, 3.773307877949904*^9, 3.77346871512571*^9, 
   3.773468817117887*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"0306aebd-62a2-4e51-ab8e-40ad8fcbed6d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "4", "]"}], "+", 
     RowBox[{"f", "[", "5", "]"}]}], "\[Equal]", "r"}]}],
  SequenceForm[
  "      ", $CellContext`f[4] + $CellContext`f[5] == $CellContext`r],
  Editable->False]], "Print",
 CellChangeTimes->{{3.773299041354598*^9, 3.77329912385933*^9}, 
   3.7732991629390793`*^9, {3.773299382586542*^9, 3.773299465623701*^9}, {
   3.773299592723957*^9, 3.773299608774199*^9}, {3.773299693265654*^9, 
   3.7732997387918367`*^9}, 3.7733003322985497`*^9, 3.7733007006290894`*^9, 
   3.773300775621126*^9, 3.773301100020769*^9, 3.7733011928793173`*^9, {
   3.773301223340167*^9, 3.773301231840027*^9}, {3.7733012710068903`*^9, 
   3.773301281871986*^9}, 3.773307877949904*^9, 3.77346871512571*^9, 
   3.7734688171210814`*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"a021a2af-df33-483c-84cd-64f2255adad4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"      \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"f", "[", "1", "]"}], ",", 
     RowBox[{"f", "[", "2", "]"}], ",", 
     RowBox[{"f", "[", "3", "]"}], ",", 
     RowBox[{"f", "[", "4", "]"}], ",", 
     RowBox[{"f", "[", "5", "]"}]}], "}"}], 
   "\[InvisibleSpace]", "\<\" \[GreaterEqual] 0\"\>"}],
  SequenceForm["      ", {
    $CellContext`f[1], 
    $CellContext`f[2], 
    $CellContext`f[3], 
    $CellContext`f[4], 
    $CellContext`f[5]}, " \[GreaterEqual] 0"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.773299041354598*^9, 3.77329912385933*^9}, 
   3.7732991629390793`*^9, {3.773299382586542*^9, 3.773299465623701*^9}, {
   3.773299592723957*^9, 3.773299608774199*^9}, {3.773299693265654*^9, 
   3.7732997387918367`*^9}, 3.7733003322985497`*^9, 3.7733007006290894`*^9, 
   3.773300775621126*^9, 3.773301100020769*^9, 3.7733011928793173`*^9, {
   3.773301223340167*^9, 3.773301231840027*^9}, {3.7733012710068903`*^9, 
   3.773301281871986*^9}, 3.773307877949904*^9, 3.77346871512571*^9, 
   3.7734688171242733`*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"4ab63fbf-47d2-4332-a249-46b0e0a79a08"],

Cell[BoxData["\<\"Solution:\"\>"], "Print",
 CellChangeTimes->{{3.773299041354598*^9, 3.77329912385933*^9}, 
   3.7732991629390793`*^9, {3.773299382586542*^9, 3.773299465623701*^9}, {
   3.773299592723957*^9, 3.773299608774199*^9}, {3.773299693265654*^9, 
   3.7732997387918367`*^9}, 3.7733003322985497`*^9, 3.7733007006290894`*^9, 
   3.773300775621126*^9, 3.773301100020769*^9, 3.7733011928793173`*^9, {
   3.773301223340167*^9, 3.773301231840027*^9}, {3.7733012710068903`*^9, 
   3.773301281871986*^9}, 3.773307877949904*^9, 3.77346871512571*^9, 
   3.773468817127358*^9},
 CellLabel->
  "During evaluation of \
In[205]:=",ExpressionUUID->"5eb7f17b-5f05-4188-aec8-d973e8af85a5"]
}, Open  ]],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`rate$$ = 4, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`rate$$], 0, 4, 
      Rational[1, 1000]}}, Typeset`size$$ = {155., {214., 218.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`rate$80888$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`rate$$ = 0}, 
      "ControllerVariables" :> {
        Hold[$CellContext`rate$$, $CellContext`rate$80888$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`fc = 
        ReplaceAll[$CellContext`flowconditions, $CellContext`r -> \
$CellContext`rate$$]; $CellContext`solution = Minimize[
          Join[
           
           Join[{$CellContext`objective}, $CellContext`fc], \
$CellContext`nonnegconditions], $CellContext`flowvars]; $CellContext`optvalue = 
        Part[$CellContext`solution, 1]; $CellContext`optflow = 
        Part[$CellContext`solution, 2]; $CellContext`edgeweights = 
        ReplaceAll[
          Table[
          Part[$CellContext`edges, $CellContext`e] -> \
$CellContext`f[$CellContext`e], {$CellContext`e, 
            1, $CellContext`m}], $CellContext`optflow]; \
$CellContext`edgestyle = ReplaceAll[
          Table[Part[$CellContext`edges, $CellContext`e] -> Directive[
             Thickness[(1/2 + $CellContext`f[$CellContext`e])/50], 
             
             If[$CellContext`f[$CellContext`e] == 0, Gray, 
              Blue]], {$CellContext`e, 
            1, $CellContext`m}], $CellContext`optflow]; 
       Graph[$CellContext`graph, EdgeWeight -> $CellContext`edgeweights, 
         EdgeLabels -> "EdgeWeight", VertexLabels -> Automatic, 
         EdgeStyle -> $CellContext`edgestyle]), 
      "Specifications" :> {{$CellContext`rate$$, 0, 4, 
         Rational[1, 1000]}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{259., {259., 265.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.7732976881878366`*^9, 3.773297738367153*^9, {3.773297833482792*^9, 
   3.773297866166225*^9}, 3.77329793093463*^9, 3.7732980794150143`*^9, 
   3.773298188459054*^9, 3.773298296461258*^9, {3.7732983615811777`*^9, 
   3.773298377211776*^9}, 3.773298416512607*^9, {3.773298547513585*^9, 
   3.773298568259864*^9}, {3.773298609562394*^9, 3.7732986300784063`*^9}, 
   3.7732987076096573`*^9, {3.773298775768705*^9, 3.773298853482463*^9}, {
   3.773298885173956*^9, 3.773298939768618*^9}, {3.773299041396473*^9, 
   3.7732991239263477`*^9}, 3.77329916299503*^9, {3.77329938264205*^9, 
   3.773299465661969*^9}, {3.773299592766193*^9, 3.7732996088152227`*^9}, {
   3.773299693313498*^9, 3.773299738842634*^9}, 3.77330033235308*^9, 
   3.773300700699239*^9, 3.773300775740025*^9, 3.773301100080578*^9, 
   3.773301192948596*^9, {3.7733012233929462`*^9, 3.7733012318872223`*^9}, {
   3.773301271059477*^9, 3.773301281924646*^9}, 3.773307878073769*^9, 
   3.773468715259149*^9, 3.7734688171639223`*^9},
 CellLabel->
  "Out[227]=",ExpressionUUID->"aee11747-c0a2-490b-9c93-4f80c65f8d8a"],

Cell[BoxData[
 TemplateBox[{
  "Table","iterb",
   "\"Iterator \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"e\\\", \\\",\\\", \
\\\"1\\\", \\\",\\\", \\\"m\\\"}], \\\"}\\\"}]\\) does not have appropriate \
bounds.\"",2,365,16,22788733561634924641,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7734753181305428`*^9},
 CellLabel->"",ExpressionUUID->"3d290354-a406-4209-b083-03bae982e263"],

Cell[BoxData[
 TemplateBox[{
  "Table","iterb",
   "\"Iterator \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"e\\\", \\\",\\\", \
\\\"1\\\", \\\",\\\", \\\"m\\\"}], \\\"}\\\"}]\\) does not have appropriate \
bounds.\"",2,365,17,22788733561634924641,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.773475318172051*^9},
 CellLabel->"",ExpressionUUID->"8e8240f6-02d4-483d-8d57-5e2834d77d65"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1680, 936},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 194, 3, 98, "Title",ExpressionUUID->"03448495-b5a7-4dc4-af71-28d7cd079886"],
Cell[CellGroupData[{
Cell[799, 29, 152, 3, 67, "Section",ExpressionUUID->"30819828-a015-46a8-8221-4764b5527bb5"],
Cell[954, 34, 289, 7, 35, "Text",ExpressionUUID->"4e5a2b8b-89e1-4019-906b-dac0e1464662"],
Cell[CellGroupData[{
Cell[1268, 45, 160, 3, 54, "Subsection",ExpressionUUID->"04e8b69c-0c7e-4c7c-b1f5-325bfd379f2c"],
Cell[1431, 50, 1791, 48, 220, "Input",ExpressionUUID->"e6271266-35c7-4610-893f-f4d48da71d33"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3271, 104, 154, 3, 67, "Section",ExpressionUUID->"8e0e9092-6795-46c8-a619-44141140bff4"],
Cell[CellGroupData[{
Cell[3450, 111, 13502, 341, 1270, "Input",ExpressionUUID->"9526067e-b7b7-434f-969f-8552cabc45ff"],
Cell[16955, 454, 704, 11, 24, "Print",ExpressionUUID->"480cd305-3e54-4373-8dc4-7ea0eca1674b"],
Cell[17662, 467, 4496, 82, 449, "Output",ExpressionUUID->"ad11c23a-c22d-4d3a-b1bc-65560f40c2d7"],
Cell[CellGroupData[{
Cell[22183, 553, 687, 11, 24, "Print",ExpressionUUID->"2c355d50-e4c7-4756-a6a9-9f39e94a93e7"],
Cell[22873, 566, 1172, 26, 43, "Print",ExpressionUUID->"7c11fd0d-57ba-4093-ac0a-01474d25f0c7"],
Cell[24048, 594, 1005, 22, 24, "Print",ExpressionUUID->"573e6455-9a8a-4ef4-983f-b572d2e97a10"],
Cell[25056, 618, 1011, 21, 24, "Print",ExpressionUUID->"d24dfe71-2ee8-4be3-8c4c-ff234df99348"],
Cell[26070, 641, 1009, 21, 24, "Print",ExpressionUUID->"0306aebd-62a2-4e51-ab8e-40ad8fcbed6d"],
Cell[27082, 664, 963, 20, 24, "Print",ExpressionUUID->"a021a2af-df33-483c-84cd-64f2255adad4"],
Cell[28048, 686, 1218, 28, 24, "Print",ExpressionUUID->"4ab63fbf-47d2-4332-a249-46b0e0a79a08"],
Cell[29269, 716, 681, 11, 24, "Print",ExpressionUUID->"5eb7f17b-5f05-4188-aec8-d973e8af85a5"]
}, Open  ]],
Cell[29965, 730, 3841, 73, 543, "Output",ExpressionUUID->"aee11747-c0a2-490b-9c93-4f80c65f8d8a"],
Cell[33809, 805, 407, 8, 24, "Message",ExpressionUUID->"3d290354-a406-4209-b083-03bae982e263"],
Cell[34219, 815, 405, 8, 24, "Message",ExpressionUUID->"8e8240f6-02d4-483d-8d57-5e2834d77d65"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

