(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    103720,       2423]
NotebookOptionsPosition[    100021,       2349]
NotebookOutlinePosition[    100374,       2365]
CellTagsIndexPosition[    100331,       2362]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Computing Equilibria, Optimal Flows, and the Price of Anarchy for Parallel \
Links\
\>", "Title",
 CellChangeTimes->{{3.7733044562990303`*^9, 
  3.773304484993902*^9}},ExpressionUUID->"7ad0e35a-2d49-4052-8118-\
55b4a5579ace"],

Cell[CellGroupData[{

Cell["Input", "Section",
 CellChangeTimes->{{3.773304488203755*^9, 
  3.773304492891471*^9}},ExpressionUUID->"c86c9a71-decb-4923-ba02-\
d184dee00887"],

Cell["Specify the cost functions of the two parallel links", "Text",
 CellChangeTimes->{{3.7733063962578487`*^9, 3.773306406580515*^9}, {
  3.7733064543257437`*^9, 3.773306464653039*^9}, {3.773306861128272*^9, 
  3.7733068612279453`*^9}},ExpressionUUID->"440fb9f9-48ad-451f-9771-\
a0872ecadd85"],

Cell[CellGroupData[{

Cell["Example 1", "Subsection",
 CellChangeTimes->{{3.773304541277858*^9, 
  3.773304556687975*^9}},ExpressionUUID->"ef3160aa-6832-477d-9a44-\
3136fa277848"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Input", " ", "of", " ", "the", " ", "cost", " ", "functions", " ", "of", 
    " ", "the", " ", "two", " ", "parallel", " ", "links"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c1", "[", "x_", "]"}], ":=", 
   RowBox[{"2", "x"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c2", "[", "x_", "]"}], ":=", 
   RowBox[{"x", "+", "2"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.773304504360647*^9, 3.773304518791724*^9}, {
  3.773304587830348*^9, 3.773304600006591*^9}},
 CellLabel->"In[82]:=",ExpressionUUID->"efb5aacf-8706-4340-9177-97fdbd9da764"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example 2", "Subsection",
 CellChangeTimes->{{3.773466831491194*^9, 
  3.7734668386858883`*^9}},ExpressionUUID->"71475cde-6ffd-405a-b630-\
38772cb0f9c4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Input", " ", "of", " ", "the", " ", "cost", " ", "functions", " ", "of", 
    " ", "the", " ", "two", " ", "parallel", " ", "links"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c1", "[", "x_", "]"}], ":=", 
   RowBox[{"x", "+", "1"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"c2", "[", "x_", "]"}], ":=", 
  RowBox[{"2", "x"}]}]}], "Input",
 CellChangeTimes->{{3.773466851409911*^9, 3.773466852310267*^9}},
 CellLabel->
  "In[362]:=",ExpressionUUID->"81ece15a-e9ac-43be-a3e4-fc42bfca42df"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Example with one parameter", "Subsection",
 CellChangeTimes->{{3.773304541277858*^9, 3.773304556687975*^9}, {
  3.773305913973899*^9, 3.7733059205503473`*^9}, {3.773307149493498*^9, 
  3.773307168913617*^9}},ExpressionUUID->"618fc1b7-340c-40ef-ae3e-\
06fd10cb9b5c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Input", " ", "of", " ", "the", " ", "cost", " ", "functions", " ", "of", 
    " ", "the", " ", "two", " ", "parallel", " ", "links"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c1", "[", "x_", "]"}], ":=", 
   RowBox[{"a1", "*", "x"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c2", "[", "x_", "]"}], ":=", "1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.773304504360647*^9, 3.773304518791724*^9}, {
   3.773304587830348*^9, 3.773304600006591*^9}, {3.773305922074456*^9, 
   3.773305931693379*^9}, {3.773306015384066*^9, 3.773306017443169*^9}, 
   3.77330608533283*^9, {3.773306475373445*^9, 3.773306482377306*^9}, {
   3.7733071783976593`*^9, 3.7733071977594843`*^9}},
 CellLabel->
  "In[142]:=",ExpressionUUID->"e7f4b819-6c09-4e6f-96b0-307dac7eddc5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fully Parametrized Example", "Subsection",
 CellChangeTimes->{{3.773304541277858*^9, 3.773304556687975*^9}, {
  3.773305913973899*^9, 3.7733059205503473`*^9}, {3.773307149493498*^9, 
  3.773307150452806*^9}},ExpressionUUID->"0c1e3d1f-2502-40ed-8a71-\
aa50c0d8af31"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Input", " ", "of", " ", "the", " ", "cost", " ", "functions", " ", "of", 
    " ", "the", " ", "two", " ", "parallel", " ", "links"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c1", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"a1", "*", "x"}], "+", "b1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c2", "[", "x_", "]"}], ":=", 
   RowBox[{
    RowBox[{"a2", "*", "x"}], "+", "b2"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.773304504360647*^9, 3.773304518791724*^9}, {
   3.773304587830348*^9, 3.773304600006591*^9}, {3.773305922074456*^9, 
   3.773305931693379*^9}, {3.773306015384066*^9, 3.773306017443169*^9}, 
   3.77330608533283*^9, {3.773306475373445*^9, 3.773306482377306*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"a801010b-de62-4c62-ba66-8b7959f76a0e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pigou Example (with worst case PoA)", "Subsection",
 CellChangeTimes->{{3.773304541277858*^9, 3.7733045738154078`*^9}, 
   3.77330712374613*^9},ExpressionUUID->"6bb3a9cc-d5af-428a-ad92-\
4877e147aaa6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Input", " ", "of", " ", "the", " ", "cost", " ", "functions", " ", "of", 
    " ", "the", " ", "two", " ", "parallel", " ", "links"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c1", "[", "x_", "]"}], ":=", "x"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c2", "[", "x_", "]"}], ":=", "1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.773304504360647*^9, 3.773304518791724*^9}, {
  3.773304575949272*^9, 3.773304604831308*^9}},
 CellLabel->"In[35]:=",ExpressionUUID->"a17ad966-89ba-4805-9e23-adfeed0b18c4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Program", "Section",
 CellChangeTimes->{{3.7733046131165743`*^9, 
  3.773304618234415*^9}},ExpressionUUID->"7a1b66f8-8565-4920-8b88-\
b752d0920b80"],

Cell[CellGroupData[{

Cell["Compute Equilibrium and Optimal Flows", "Subsubsection",
 CellChangeTimes->{{3.773304644100787*^9, 
  3.773304660971717*^9}},ExpressionUUID->"0b471432-2cbf-455a-b9f5-\
5e41eb4c312d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Define", " ", "a", " ", "functions", " ", "\"\<equilibrium\>\"", " ", 
     "depending", " ", "on", " ", "cost", " ", "functions", " ", "cf1"}], ",",
     " ", 
    RowBox[{
    "cf2", " ", "that", " ", "computes", " ", "a", " ", "Wardrop", " ", 
     "Equilibrium", " ", "for", " ", "two", " ", "parallel", " ", "links", 
     " ", "with", " ", "these", " ", "cost", " ", "functions"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"equilibrium", "[", 
      RowBox[{"cf1_", ",", "cf2_"}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
       "Define", " ", "a", " ", "Module", " ", "with", " ", "local", " ", 
        "variables", " ", "c1"}], ",", " ", 
       RowBox[{
        RowBox[{
        "c2", " ", "that", " ", "are", " ", "initialized", " ", "with", " ", 
         "the", " ", "arguments", " ", "of", " ", "the", " ", 
         "\"\<equilibrium\>\""}], "-", "function"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"c1", "=", "cf1"}], ",", 
         RowBox[{"c2", "=", "cf2"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{
        "Solve", " ", "the", " ", "equilibrium", " ", "conditions", " ", 
         "and", " ", "take", " ", "the", " ", "first", " ", "solution", " ", 
         RowBox[{"(", 
          RowBox[{
          "assuming", " ", "that", " ", "there", " ", "is", " ", "a", " ", 
           "unique", " ", "solution"}], ")"}]}], " ", "*)"}], 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"sol", "=", 
         RowBox[{
          RowBox[{"Solve", "[", " ", 
           RowBox[{
            RowBox[{
             RowBox[{"c1", "[", "f1", "]"}], " ", "\[Equal]", " ", 
             RowBox[{"c2", "[", 
              RowBox[{"r", "-", "f1"}], "]"}]}], ",", " ", "f1"}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{
          "Create", " ", "a", " ", "list", " ", "of", " ", "the", " ", "two", 
           " ", "flows", " ", "on", " ", "both", " ", "edges", " ", 
           RowBox[{"(", 
            RowBox[{"f1", ",", " ", "f2"}], ")"}], " ", "where", " ", "f2"}], 
          " ", "=", " ", 
          RowBox[{"r", " ", "-", " ", 
           RowBox[{
            RowBox[{"f1", ".", " ", "Plug"}], " ", "in", " ", "the", " ", 
            "solution", " ", "computed", " ", "above"}]}]}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"flows", "=", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"f1", ",", 
              RowBox[{"r", "-", "f1"}]}], "}"}], "/.", "sol"}], ")"}], 
          "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{
          "Cut", " ", "off", " ", "negative", " ", "flows", " ", "and", " ", 
           "flows"}], " ", ">", " ", "r"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"flows", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Max", "[", 
             RowBox[{"0", ",", 
              RowBox[{"Min", "[", 
               RowBox[{"r", ",", "#"}], "]"}]}], "]"}], ")"}], "&"}], "/@", 
          "flows"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "Return", " ", "the", " ", "resulting", " ", "flow", " ", "vector"}],
          " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"Return", "[", 
         RowBox[{"FullSimplify", "[", 
          RowBox[{"PiecewiseExpand", "/@", "flows"}], "]"}], "]"}], ";"}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Call", " ", "the", " ", "\"\<equilibrium\>\"", " ", "function", " ", 
     "with", " ", "normal", " ", "cost", " ", "functions"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"eqflows", "=", 
     RowBox[{"equilibrium", "[", 
      RowBox[{"c1", ",", "c2"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Equilbrium Flows: x1=\>\"", ",", " ", 
      RowBox[{"eqflows", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", "\"\<   x2 = \>\"", ",", 
      RowBox[{"eqflows", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Compute", " ", "the", " ", "total", " ", "cost", " ", "of", " ", "the", 
      " ", "Equilibrium", " ", "solution", " ", "as", " ", 
      SubscriptBox["x", "1"], 
      SubscriptBox["c", "1"], 
      RowBox[{"(", 
       SubscriptBox["x", "1"], ")"}]}], " ", "+", " ", 
     RowBox[{
      SubscriptBox["x", "2"], 
      SubscriptBox["c", "2"], 
      RowBox[{"(", 
       SubscriptBox["x", "2"], ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   
   RowBox[{
    RowBox[{"eqcost", " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"flows", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "*", 
        RowBox[{"c1", "[", 
         RowBox[{"flows", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"flows", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "*", 
        RowBox[{"c2", "[", 
         RowBox[{"flows", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Equilibrium Cost: \>\"", ",", " ", "eqcost"}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Compute", " ", "the", " ", "marginal", " ", "cost", " ", "as", " ", "c", 
      RowBox[{"(", "x", ")"}]}], " ", "+", " ", 
     RowBox[{"x", " ", 
      RowBox[{
       RowBox[{"c", "'"}], "[", "x", "]"}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"margc1", "[", "x_", "]"}], ":=", 
     RowBox[{
      RowBox[{"c1", "[", "x", "]"}], "+", 
      RowBox[{"x", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"c1", "[", "\[Xi]", "]"}], ",", "\[Xi]"}], "]"}], "/.", 
         RowBox[{"\[Xi]", "\[Rule]", "x"}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"margc2", "[", "x_", "]"}], ":=", 
     RowBox[{
      RowBox[{"c2", "[", "x", "]"}], "+", 
      RowBox[{"x", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"c2", "[", "\[Xi]", "]"}], ",", "\[Xi]"}], "]"}], "/.", 
         RowBox[{"\[Xi]", "\[Rule]", "x"}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Call", " ", "the", " ", "\"\<equilibrium\>\"", " ", "function", " ", 
     "with", " ", "normal", " ", "cost", " ", "functions"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"optflows", "=", 
     RowBox[{"equilibrium", "[", 
      RowBox[{"margc1", ",", "margc2"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Optimal Flows: xOpt1=\>\"", ",", " ", 
      RowBox[{"optflows", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", "\"\<   x2 = \>\"", ",", 
      RowBox[{"optflows", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Compute", " ", "the", " ", "total", " ", "cost", " ", "of", " ", "the", 
     " ", "Equilibrium", " ", "solution"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"optcost", " ", "=", " ", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"flows", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "*", 
        RowBox[{"c1", "[", 
         RowBox[{"optflows", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"flows", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "*", 
        RowBox[{"c2", "[", 
         RowBox[{"optflows", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{"\"\<Optimal Cost: \>\"", ",", " ", "optcost"}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Compute", " ", "the", " ", "price", " ", "of", " ", "Anarchy"}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Assumptions", " ", "are", " ", "only", " ", "needed", " ", "for", " ", 
     "parametrized", " ", "example"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"poa", "=", 
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"PiecewiseExpand", "[", 
        RowBox[{"Simplify", "[", 
         RowBox[{
          RowBox[{"eqcost", "/", "optcost"}], ",", " ", 
          RowBox[{"Assumptions", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"r", ">", "0"}], ",", 
             RowBox[{"a1", ">", "0"}], ",", 
             RowBox[{"a2", ">", "0"}], ",", 
             RowBox[{"b2", "\[GreaterEqual]", "b1"}], ",", 
             RowBox[{"b1", ">", "0"}]}], "}"}]}]}], "]"}], "]"}], ",", " ", 
       RowBox[{"Assumptions", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"r", ">", "0"}], ",", 
          RowBox[{"a1", ">", "0"}], ",", 
          RowBox[{"a2", ">", "0"}], ",", 
          RowBox[{"b2", "\[GreaterEqual]", "b1"}], ",", 
          RowBox[{"b1", ">", "0"}]}], "}"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Price of Anarchy: \>\"", ",", " ", "poa"}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Compute", " ", "the", " ", "maximal", " ", "price", " ", "of", " ", 
     "anarchy"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"poasol", "=", 
     RowBox[{"Maximize", "[", 
      RowBox[{"poa", ",", "r"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Maximal PoA is \>\"", ",", " ", 
      RowBox[{"poasol", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", " ", "\"\< at r=\>\"", ",", " ", 
      RowBox[{"r", "/.", 
       RowBox[{"poasol", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}]}], "]"}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.773304676477211*^9, 3.77330484499564*^9}, {
  3.773304976760281*^9, 3.773304997665237*^9}, {3.773305054173315*^9, 
  3.773305371604611*^9}, {3.773305408332458*^9, 3.773305411370348*^9}, {
  3.773305444450941*^9, 3.773305704324106*^9}, {3.773305737276524*^9, 
  3.773305870473145*^9}, {3.77330602504289*^9, 3.773306027426635*^9}, {
  3.773306124304823*^9, 3.773306158475779*^9}, {3.7733062467318087`*^9, 
  3.77330626149514*^9}, {3.773306508713476*^9, 3.773306523029635*^9}, {
  3.773306588077138*^9, 3.7733065910206823`*^9}, {3.773306660388955*^9, 
  3.77330668655933*^9}, {3.773306899124107*^9, 3.7733070465190287`*^9}},
 CellLabel->
  "In[365]:=",ExpressionUUID->"6020d670-316f-4597-b4d0-56585e396db2"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Equilbrium Flows: x1=\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{
           FractionBox["1", "3"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "r"}]}], ")"}]}], 
          RowBox[{"r", ">", 
           FractionBox["1", "2"]}]},
         {"0", 
          TagBox["True",
           "PiecewiseDefault",
           AutoDelete->True]}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False], "\[InvisibleSpace]", "\<\"   x2 = \"\>", 
   "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {"r", 
          RowBox[{"0", "<", "r", "\[LessEqual]", 
           FractionBox["1", "2"]}]},
         {
          FractionBox[
           RowBox[{"1", "+", "r"}], "3"], 
          RowBox[{"r", ">", 
           FractionBox["1", "2"]}]},
         {"0", 
          TagBox["True",
           "PiecewiseDefault",
           AutoDelete->True]}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}],
  SequenceForm["Equilbrium Flows: x1=", 
   Piecewise[{{
     Rational[1, 3] (-1 + 2 $CellContext`r), $CellContext`r > 
      Rational[1, 2]}}, 0], "   x2 = ", 
   Piecewise[{{$CellContext`r, 
      Inequality[0, Less, $CellContext`r, LessEqual, 
       Rational[1, 2]]}, {
     Rational[1, 3] (1 + $CellContext`r), $CellContext`r > Rational[1, 2]}}, 
    0]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773305307942649*^9, 3.7733055612325974`*^9, {3.773305606232235*^9, 
   3.773305617450603*^9}, 3.7733056537774687`*^9, {3.773305780070381*^9, 
   3.773305802827052*^9}, 3.773305836120926*^9, {3.773305870794581*^9, 
   3.773305876263274*^9}, 3.773305934971759*^9, {3.773306006806007*^9, 
   3.7733060280012712`*^9}, {3.773306080631977*^9, 3.7733060896891327`*^9}, {
   3.773306143932482*^9, 3.773306172933935*^9}, 3.773306487656041*^9, 
   3.773306550102831*^9, 3.773306591711768*^9, {3.7733066685138683`*^9, 
   3.7733066871128693`*^9}, 3.773306816865838*^9, 3.773307201232874*^9, 
   3.7734668587960997`*^9, 3.773467973177483*^9, 3.773475321285288*^9},
 CellLabel->
  "During evaluation of \
In[365]:=",ExpressionUUID->"c601ec1e-6db3-4006-864a-ea26fa6e0ca6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Equilibrium Cost: \"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{"2", " ", 
           SuperscriptBox["r", "2"]}], 
          RowBox[{"0", "<", "r", "\[LessEqual]", 
           FractionBox["1", "2"]}]},
         {
          RowBox[{
           FractionBox["2", "3"], " ", "r", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "r"}], ")"}]}], 
          RowBox[{
           RowBox[{"2", " ", "r"}], ">", "1"}]},
         {"0", 
          TagBox["True",
           "PiecewiseDefault",
           AutoDelete->True]}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}],
  SequenceForm["Equilibrium Cost: ", 
   Piecewise[{{2 $CellContext`r^2, 
      Inequality[0, Less, $CellContext`r, LessEqual, 
       Rational[1, 2]]}, {
     Rational[2, 3] $CellContext`r (1 + $CellContext`r), 2 $CellContext`r > 
      1}}, 0]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773305307942649*^9, 3.7733055612325974`*^9, {3.773305606232235*^9, 
   3.773305617450603*^9}, 3.7733056537774687`*^9, {3.773305780070381*^9, 
   3.773305802827052*^9}, 3.773305836120926*^9, {3.773305870794581*^9, 
   3.773305876263274*^9}, 3.773305934971759*^9, {3.773306006806007*^9, 
   3.7733060280012712`*^9}, {3.773306080631977*^9, 3.7733060896891327`*^9}, {
   3.773306143932482*^9, 3.773306172933935*^9}, 3.773306487656041*^9, 
   3.773306550102831*^9, 3.773306591711768*^9, {3.7733066685138683`*^9, 
   3.7733066871128693`*^9}, 3.773306816865838*^9, 3.773307201232874*^9, 
   3.7734668587960997`*^9, 3.773467973177483*^9, 3.77347532129837*^9},
 CellLabel->
  "During evaluation of \
In[365]:=",ExpressionUUID->"1b508244-8f70-4cb5-bdee-0186a4ea9f82"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Optimal Flows: xOpt1=\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{
           FractionBox["1", "6"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"4", " ", "r"}]}], ")"}]}], 
          RowBox[{"r", ">", 
           FractionBox["1", "4"]}]},
         {"0", 
          TagBox["True",
           "PiecewiseDefault",
           AutoDelete->True]}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False], "\[InvisibleSpace]", "\<\"   x2 = \"\>", 
   "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {"r", 
          RowBox[{"0", "<", "r", "\[LessEqual]", 
           FractionBox["1", "4"]}]},
         {
          RowBox[{
           FractionBox["1", "6"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "r"}]}], ")"}]}], 
          RowBox[{"r", ">", 
           FractionBox["1", "4"]}]},
         {"0", 
          TagBox["True",
           "PiecewiseDefault",
           AutoDelete->True]}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}],
  SequenceForm["Optimal Flows: xOpt1=", 
   Piecewise[{{
     Rational[1, 6] (-1 + 4 $CellContext`r), $CellContext`r > 
      Rational[1, 4]}}, 0], "   x2 = ", 
   Piecewise[{{$CellContext`r, 
      Inequality[0, Less, $CellContext`r, LessEqual, 
       Rational[1, 4]]}, {
     Rational[1, 6] (1 + 2 $CellContext`r), $CellContext`r > Rational[1, 4]}},
     0]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773305307942649*^9, 3.7733055612325974`*^9, {3.773305606232235*^9, 
   3.773305617450603*^9}, 3.7733056537774687`*^9, {3.773305780070381*^9, 
   3.773305802827052*^9}, 3.773305836120926*^9, {3.773305870794581*^9, 
   3.773305876263274*^9}, 3.773305934971759*^9, {3.773306006806007*^9, 
   3.7733060280012712`*^9}, {3.773306080631977*^9, 3.7733060896891327`*^9}, {
   3.773306143932482*^9, 3.773306172933935*^9}, 3.773306487656041*^9, 
   3.773306550102831*^9, 3.773306591711768*^9, {3.7733066685138683`*^9, 
   3.7733066871128693`*^9}, 3.773306816865838*^9, 3.773307201232874*^9, 
   3.7734668587960997`*^9, 3.773467973177483*^9, 3.773475321310474*^9},
 CellLabel->
  "During evaluation of \
In[365]:=",ExpressionUUID->"99b2951e-ff44-4cc9-a5d0-c51b437f6717"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Optimal Cost: \"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {
          RowBox[{"2", " ", 
           SuperscriptBox["r", "2"]}], 
          RowBox[{"0", "<", "r", "\[LessEqual]", 
           FractionBox["1", "4"]}]},
         {
          RowBox[{
           FractionBox["1", "12"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"8", " ", "r"}], "+", 
             RowBox[{"8", " ", 
              SuperscriptBox["r", "2"]}]}], ")"}]}], 
          RowBox[{
           RowBox[{"4", " ", "r"}], ">", "1"}]},
         {"0", 
          TagBox["True",
           "PiecewiseDefault",
           AutoDelete->True]}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}],
  SequenceForm["Optimal Cost: ", 
   Piecewise[{{2 $CellContext`r^2, 
      Inequality[0, Less, $CellContext`r, LessEqual, 
       Rational[1, 4]]}, {
     Rational[1, 12] (-1 + 8 $CellContext`r + 8 $CellContext`r^2), 
      4 $CellContext`r > 1}}, 0]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773305307942649*^9, 3.7733055612325974`*^9, {3.773305606232235*^9, 
   3.773305617450603*^9}, 3.7733056537774687`*^9, {3.773305780070381*^9, 
   3.773305802827052*^9}, 3.773305836120926*^9, {3.773305870794581*^9, 
   3.773305876263274*^9}, 3.773305934971759*^9, {3.773306006806007*^9, 
   3.7733060280012712`*^9}, {3.773306080631977*^9, 3.7733060896891327`*^9}, {
   3.773306143932482*^9, 3.773306172933935*^9}, 3.773306487656041*^9, 
   3.773306550102831*^9, 3.773306591711768*^9, {3.7733066685138683`*^9, 
   3.7733066871128693`*^9}, 3.773306816865838*^9, 3.773307201232874*^9, 
   3.7734668587960997`*^9, 3.773467973177483*^9, 3.77347532137084*^9},
 CellLabel->
  "During evaluation of \
In[365]:=",ExpressionUUID->"dcac66a9-080b-4b2e-a733-2982dd2b7cb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Price of Anarchy: \"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\[Piecewise]", GridBox[{
         {"1", 
          RowBox[{"r", "\[LessEqual]", 
           FractionBox["1", "4"]}]},
         {
          FractionBox[
           RowBox[{"24", " ", 
            SuperscriptBox["r", "2"]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"8", " ", "r"}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["r", "2"]}]}]], 
          RowBox[{
           FractionBox["1", "4"], "<", "r", "\[LessEqual]", 
           FractionBox["1", "2"]}]},
         {
          FractionBox[
           RowBox[{"8", " ", "r", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", "r"}], ")"}]}], 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"8", " ", "r"}], "+", 
            RowBox[{"8", " ", 
             SuperscriptBox["r", "2"]}]}]], 
          TagBox["True",
           "PiecewiseDefault",
           AutoDelete->True]}
        },
        AllowedDimensions->{2, Automatic},
        Editable->True,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
          "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}},
           "RowsIndexed" -> {}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.27999999999999997`], {
             Offset[0.84]}, 
            Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
          "Rows" -> {
            Offset[0.2], {
             Offset[0.4]}, 
            Offset[0.2]}, "RowsIndexed" -> {}},
        Selectable->True]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxItemSize->{
      "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.35]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    "Piecewise",
    DeleteWithContents->True,
    Editable->False,
    SelectWithContents->True,
    Selectable->False]}],
  SequenceForm["Price of Anarchy: ", 
   Piecewise[{{1, $CellContext`r <= Rational[1, 4]}, {
     24 $CellContext`r^2/(-1 + 8 $CellContext`r + 8 $CellContext`r^2), 
      Inequality[
       Rational[1, 4], Less, $CellContext`r, LessEqual, 
       Rational[1, 2]]}}, 8 $CellContext`r (1 + $CellContext`r)/(-1 + 
    8 $CellContext`r + 8 $CellContext`r^2)]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773305307942649*^9, 3.7733055612325974`*^9, {3.773305606232235*^9, 
   3.773305617450603*^9}, 3.7733056537774687`*^9, {3.773305780070381*^9, 
   3.773305802827052*^9}, 3.773305836120926*^9, {3.773305870794581*^9, 
   3.773305876263274*^9}, 3.773305934971759*^9, {3.773306006806007*^9, 
   3.7733060280012712`*^9}, {3.773306080631977*^9, 3.7733060896891327`*^9}, {
   3.773306143932482*^9, 3.773306172933935*^9}, 3.773306487656041*^9, 
   3.773306550102831*^9, 3.773306591711768*^9, {3.7733066685138683`*^9, 
   3.7733066871128693`*^9}, 3.773306816865838*^9, 3.773307201232874*^9, 
   3.7734668587960997`*^9, 3.773467973177483*^9, 3.773475321380948*^9},
 CellLabel->
  "During evaluation of \
In[365]:=",ExpressionUUID->"38b37f7a-ecb1-414b-bc7d-3e4b97536a6a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Maximal PoA is \"\>", "\[InvisibleSpace]", 
   FractionBox["6", "5"], "\[InvisibleSpace]", "\<\" at r=\"\>", 
   "\[InvisibleSpace]", 
   FractionBox["1", "2"]}],
  SequenceForm["Maximal PoA is ", 
   Rational[6, 5], " at r=", 
   Rational[1, 2]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.773305307942649*^9, 3.7733055612325974`*^9, {3.773305606232235*^9, 
   3.773305617450603*^9}, 3.7733056537774687`*^9, {3.773305780070381*^9, 
   3.773305802827052*^9}, 3.773305836120926*^9, {3.773305870794581*^9, 
   3.773305876263274*^9}, 3.773305934971759*^9, {3.773306006806007*^9, 
   3.7733060280012712`*^9}, {3.773306080631977*^9, 3.7733060896891327`*^9}, {
   3.773306143932482*^9, 3.773306172933935*^9}, 3.773306487656041*^9, 
   3.773306550102831*^9, 3.773306591711768*^9, {3.7733066685138683`*^9, 
   3.7733066871128693`*^9}, 3.773306816865838*^9, 3.773307201232874*^9, 
   3.7734668587960997`*^9, 3.773467973177483*^9, 3.7734753213904953`*^9},
 CellLabel->
  "During evaluation of \
In[365]:=",ExpressionUUID->"1f650198-f86c-466a-9fb3-fc9b9334161b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot functions", "Subsection",
 CellChangeTimes->{{3.7733057081595993`*^9, 
  3.773305723292856*^9}},ExpressionUUID->"123403cc-467f-4322-9854-\
5d71293ef78d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Plot", " ", "the", " ", "Equilibrium", " ", "flow", " ", "functions"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{"eqflows", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
     " ", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Wardrop Equilibrium Flow Functions\>\""}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"PlotLegends", "\[Rule]", "\"\<Expressions\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotLabels", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<x1\>\"", ",", " ", "\"\<x2\>\""}], "}"}]}]}], "]"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Plot", " ", "the", " ", "optimal", " ", "flow", " ", "functions"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{"optflows", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
     " ", 
     RowBox[{
     "PlotLabel", "\[Rule]", "\"\<Wardrop Equilibrium Flow Functions\>\""}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"PlotLegends", "\[Rule]", "\"\<Expressions\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"PlotLabels", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<xOpt1\>\"", ",", " ", "\"\<xOpt2\>\""}], "}"}]}]}], "]"}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"Plot", "[", 
    RowBox[{"poa", ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "2"}], "}"}], ",", " ", 
     RowBox[{"PlotLabel", "\[Rule]", "\"\<Price of Anarchy\>\""}], ",", " ", 
     RowBox[{"PlotLegends", "\[Rule]", "\"\<Expressions\>\""}]}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.773305728324719*^9, 3.773305775087009*^9}},
 CellLabel->
  "In[136]:=",ExpressionUUID->"405d4c02-1362-4259-997b-465ca0422a02"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGCQBmIQ7ZX64uKBl6l2DFDA4ixVcF/SxR7GN54/Y85myRA4
3/vs9U1zJVPg/PCU73snSZbA+Xf12517JVvg/AWi/m1dklPg/EaOzeqdkkvg
/IjIhes/fNwC53P/b4xxl9sP56sGvntxuPsInF9+ztJ+xpeTcL74FsF7jIzn
4fxtj5zPnLe5BOcfyporHfnmCpz/Vc2Wf23udTif6edqAWnVW3C+2f+EbcHr
7sD5Z1pMzh3Tug/nW/GfZppoiuCvmJloHu2A4Dev61vwPhRJ/Y0XRRKNSOq1
54pnXUfwxbYZ+5g8QvBbHE41/HuD4NdmrOHv/YrgAwC00mmK
          "]], 
         LineBox[CompressedData["
1:eJwVjHk0FHgAx5nIUatQWl5YrdoZVy1hyesbr4xCT2K1JUqilFbSQck5PSVU
qxSKRK4202FXWCxTbbowjmyMMQzj/OU+wm9n//i+7/u876Hn86vrYYaMjIyT
VP/7329Z56zkhXCXT75s2L4JOuY38tWXCiHDTA+01HJBfCVT0K4hzV+4WTDD
vVAtFzJtt1rKUXucXVp8ML29Ui1PT8o5lyKWBvnBr9GdHWwkRMGwqCv2fiDs
+qK5i+2kXOXcbM04g1CTD7XH2NJ/vi+5/eEsuKc0xXVO0r34vOJUaih0Foo0
0zykuXKB9TOzcMyotUevDxQikhXz8aZpNLg2lu57bkv/gjvMVHwvQ/fawEz+
sBA3GU4XI7p+Q8XBiPynY0IYrHU43bUzGV5m6r+UTQvRxN56nF2ajPRm65J3
jE7IJNjsXXb9Jr7VvnKGaHTCfZWxRcbmFKgVMMc2ohMGRirDFXdSIc87PFiZ
1AmhgcSE5mZiYKpD0LRBhNNuBfc2e+Uiu7+sViWxCysTYZU98RQq2rmku7sb
mdvO79bSKsXVo8V+mfo9qD2RWF54sAqTWwq7j0T0QuxxamngQg1CTHnPNWok
MP9xiej6/tfoeMyLr9frR94Pf4a0yr3F14DGNFbYAEZfx2dopn2Aoa3Cgl/Z
IKweKeUJZurAztLzf7JqGEoxLQLb2gac1fZe0+lJMF5/8VPz+UYYDbovaXH+
gtrT1joS/WaoL/uiyJv9AlNmZLXyaAvkKtOKvk8fQbFrBss7sxXHNpa1KjmO
4p94B8IL/ozC7T6ZFZNS1lwsm2vTjokBreU9t8Yg0r3bVNorQPFu9qLkreOw
1/KWC9onRIQDJ+N5zzjyD3hGpJl1Qq99x6cHnAlE1R/6jqMggrVlbLKm6SSy
tnODzg6J4KnzcUaWP4m68KNZDF4XJmoTREFRU7B/4R9z61E3bst5hbjqT6OW
27CthiOGuqBY2psGr4Ft8nhvD+TDo9ysTs5g8Zzsq/u2vZDJ9yoSqc3CvZMJ
E00JglOLEtSqZzH0Ptm/htGHvwzjFFVPfMVct/IfGpI+qO4INopWmYNGyZCY
UdGPNuM6fmj5HMJurHw5lTMA7j3od3vNo59ZwOFcHMT+IgtV7YV51Pc5HK93
HUIk535UW8ECZJ4aMdZZDeN3iXaaihOFjUV4qPpygri7nAOCnRTKDZ6GfHUC
X9ehtY93UfwbaNN+YxXB6vJyrrMHRVjO1y1qugRXkva9uupDUbIiTFHVhOCI
xZ0R5VAK87EzKSpOBGtiVzgoPKQw5gYVK8URLPx04ZuWPIp5Rxf/N/EErUNd
DQ8LKd71rte8nERwzePZfvsnFAG65IJiCgE1cD3FKafITwzcqvCQoK0+6d4i
PsXawAC+HI+g5NLUIX4TxYTiDg7vNUHyJm/Wg08UL7NZlrFvCRxzTJ7bCSh8
2ySpi/gEpefev4nqo8hy9PdhiAhuGZsn7RqkCO61X1EtJjgpSnfTIxS2Mete
RfURMJ2Od1SNUwhLxSzZEQI52cbsa1MU3J9ffq4aJxAWbwo4MEsROZqdEDlN
UB7wYP2GeQqXxFhsmSNI0V0yQSmFjoHvCKUE/wHMU2tt
          "]]}, 
        Annotation[#, "Charting`Private`Tag$42437#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQ7ZX64uKBl6l2MJrFWargvqSLPYw2nj9jzmbJEDjt
ffb6prmSKXA6POX73kmSJXD6rn67c69kC5xeIOrf1iU5BU43cmxW75RcAqcj
Iheu//BxC5zm/t8Y4y63H06rBr57cbj7CJwuP2dpP+PLSTgtvkXwHiPjeTi9
7ZHzmfM2l+D0oay50pFvrsDpr2q2/Gtzr8Nppp+rBaRVb8Fps/8J24LX3YHT
Pr4Hmlx3IOjk2fL+5ocQ9ATze8+lriHol/nRko/+Iug5D0JrCnzvwmnGQ15O
vW8QtITAKr76bwhaL47zdgHDPTgd9et4cYgIgt5i5LpU2gZBpy2251jVjaDP
tJicO6Z1H05b8Z9mmmiKoFfMTDSPdkDQzev6FrwPRdBWN14USTQi6BVJ9csf
dSNosbeid9ZMQ9AfGZ1dHdcg6BXac8WzriNosW3GPiaPEHSLw6mGf28QdG3G
Gv7erwgaAEnePxI=
          "]], 
         LineBox[CompressedData["
1:eJwVzXs01HkABXAzxiPKhpa1axKpw5ZHSEV1sZ1UtB2ziUqS8oitLdkmbY44
dPQQW0qlB0rrsXlPZ4qw0+y2abUMeuyi3zxoxgzfvMdrfjv7xz33n8+51zby
B04UU0dHJ1Cb//u3V46n1ulR8LnJFz1jUFi8+kqp+XwKRjH/ZumzKFxscujt
saDgfG3BtnsGFASsRLWftdb/urwkfh4F9dYmsxJbCpzn0F9rTCG6M9g/YSUF
7vBxQZsJBT9FWpW+H4Xm7W+8mNqdJOfXLfH+FESHyI3XlhSqTlj1tQVS6PvJ
cPKWlfZfU2mVH6L9L/OqdWdTmDLrSXM5ot3Xv7ciyl7r168JDr2h9Y0x1n+6
UbDJUU6VDmm969Rc1g4KjQdSSmtGKeQu6cryDqIQ7m6+u16tdabVbAWHwu03
Xvy/mGJ4jMRu2LSLwhfsCyeJhRj76t6dmQ6jYFbmMOoBMarW8mei4yjoCaNU
Tdli7PLlTiGDgnLyQ2+XqwQPOONjw08pPBiobzG5LIVYffWbPS5imLB/ITKZ
DHvq1hQXFopx6TAvusC+H+9bf+auni/BhE+5LDblI2bjLhe2pkiQ6Cass3gu
x/Jo3/U1Sgk+VAgvttsOYFx23Tk/QoqZuM58x9NKaE4Nux/skGKFr4Emul4F
k3hmGXejDP5FtjHVlkMQUDxuTo0MXPZ+O3EYQXKdzePxxX1YqQo2frv9ExLu
XDbwOt8H888+GQqnP2GBUUFV2mwfWE35lUtvD+NRZ0yLZWw/4j3q388LGMGI
nci7ursf5VsjCxonRpBwzrfZccdHjCu/XNh/fRRq/xje0JOP4H3nr5u7aQx2
WS5MvpMcKVsy7tX1jyHYtaKp9aYctj3b3t3PGEezfFWOQFcBrzXpuVZuE2i3
D+XXn1QgbPHfU4yOCcgbPYIYEgXGW7Ikx1InUdRd6xuwawA3WOGJHHs1okIV
RWLBAMx7eUVMoRqRiqWWIU5K6CWn7lx3fApMjY60rUAJndLwSonZNMqO5drk
zVch4VZllplgGhPRLbUHUlV4tiLT0PToDJIT9PYaj6lgui1hZZrJLIy6JxIY
+wfR7dTWkdQwiw0vL0hmRIOougt7WfgcflzUJfDDEPZVepqyNXOQJ9o/ji0d
wtmMwtTuMg10dlswrloTPJKz800CabDzGxvmZRJk3smI6P2Wht7himuK8wSH
OIPLKoJoDHrePfryIoF1Q0PV9hAaz0TJS85nE1zI3vvHpUgaYUYb0g3zCGI9
bw4bJdG4lVQfYPCQwC590RaDhzQsQvn/sIQEmrVnFrwtoaFZVlIr+53g/aBU
9LCcRt9o3iXhC4KckNp9m6tp8LK5G9NfEdBfc05kNNAIfuFZpNtB0N2efVe3
g8YVT95hpoSAf27yYEcXjdOsYj+JlCDXe7/j/Xc0IkW5Xwn6CAKKnev8emm4
HU1sTVUQPD3V+jJVQaO92H0VY5jgutPq7CAVjScnlhqJRwiOS27vtCU0CnzN
pc1jBA6B339oHqNxrGck96yagMXofJAzSSO0XHIkYpqA4nnHRUzT8EkSbfaZ
JWiIu+/iOkfDwV9gs0RDkGdjPE7TNBZ+XqOmaYL/ABj0fiY=
          "]]}, 
        Annotation[#, 
         "Charting`Private`Tag$42437#2"]& ], {}}, {{}, {}, {}, {}}}, {{}, \
{}}, {{{{{
          GraphicsGroupBox[{{
             Directive[
              AbsoluteThickness[4], 
              GrayLevel[1], 
              Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]], 
             CapForm["Butt"], 
             JoinForm["Round"], 
             BSplineCurveBox[{
               Offset[{0, 0}, {2.0416666666666665`, 0.9999999727891156}], 
               Offset[{0, 0}, {2.0416666666666665`, 0.9999999727891156}], 
               Offset[{0., 0.}, {2.0616666666666665`, 0.9999999727891156}], 
               Offset[{0., 0.}, {2.0616666666666665`, 0.9999999727891156}], 
               Offset[{0., 0.}, {2.0816666666666666`, 0.9999999727891156}], 
               Offset[{0, 0}, {2.186706747284535, 0.9024398531896612}], 
               
               Offset[{5., 1.1102230246251565`*^-15}, {2.186706747284535, 
                0.9024398531896612}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.186706747284535, 
                0.9024398531896612}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.186706747284535, 
                0.9024398531896612}]}]}, {
             Directive[
              RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25]], 
             BSplineCurveBox[{
               Offset[{0, 0}, {2.0416666666666665`, 0.9999999727891156}], 
               Offset[{0, 0}, {2.0416666666666665`, 0.9999999727891156}], 
               Offset[{0., 0.}, {2.0616666666666665`, 0.9999999727891156}], 
               Offset[{0., 0.}, {2.0616666666666665`, 0.9999999727891156}], 
               Offset[{0., 0.}, {2.0816666666666666`, 0.9999999727891156}], 
               Offset[{0, 0}, {2.186706747284535, 0.9024398531896612}], 
               
               Offset[{5., 1.1102230246251565`*^-15}, {2.186706747284535, 
                0.9024398531896612}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.186706747284535, 
                0.9024398531896612}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.186706747284535, 
                0.9024398531896612}]}]}, {
             FaceForm[
              Directive[
               GrayLevel[1], 
               Opacity[
                NCache[
                 Rational[2, 3], 0.6666666666666666]]]], 
             EdgeForm[], 
             PolygonBox[{
               
               Offset[{27., 7.000000000000006}, {2.186706747284535, 
                0.9024398531896612}], 
               
               Offset[{27., -6.999999999999994}, {2.186706747284535, 
                0.9024398531896612}], 
               
               Offset[{10.000000000000002`, -6.999999999999997}, {
                2.186706747284535, 0.9024398531896612}], 
               
               Offset[{9.999999999999998, 7.000000000000003}, {
                2.186706747284535, 0.9024398531896612}]}]}, {
             EdgeForm[], 
             Directive[
              RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25]]}, {}, 
            InsetBox[
             FormBox[
              StyleBox[
               RotationBox["\"x1\"", BoxRotation -> 0.], {}, StripOnInput -> 
               False], TraditionalForm], 
             
             Offset[{18.5, 4.107825191113079*^-15}, {2.186706747284535, 
              0.9024398531896612}], {0, 0}]}], 
          GraphicsGroupBox[{{
             Directive[
              AbsoluteThickness[4], 
              GrayLevel[1], 
              Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]], 
             CapForm["Butt"], 
             JoinForm["Round"], 
             BSplineCurveBox[{
               Offset[{0, 0}, {2.0416666666666665`, 0.9999999863945579}], 
               Offset[{0, 0}, {2.0416666666666665`, 0.9999999863945579}], 
               Offset[{0., 0.}, {2.0616666666666665`, 0.9999999863945579}], 
               Offset[{0., 0.}, {2.0616666666666665`, 0.9999999863945579}], 
               Offset[{0., 0.}, {2.0816666666666666`, 0.9999999863945579}], 
               Offset[{0, 0}, {2.186706747284535, 1.004468728369049}], 
               
               Offset[{5., 1.1102230246251565`*^-15}, {2.186706747284535, 
                1.004468728369049}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.186706747284535, 
                1.004468728369049}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.186706747284535, 
                1.004468728369049}]}]}, {
             Directive[
              RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25]], 
             BSplineCurveBox[{
               Offset[{0, 0}, {2.0416666666666665`, 0.9999999863945579}], 
               Offset[{0, 0}, {2.0416666666666665`, 0.9999999863945579}], 
               Offset[{0., 0.}, {2.0616666666666665`, 0.9999999863945579}], 
               Offset[{0., 0.}, {2.0616666666666665`, 0.9999999863945579}], 
               Offset[{0., 0.}, {2.0816666666666666`, 0.9999999863945579}], 
               Offset[{0, 0}, {2.186706747284535, 1.004468728369049}], 
               
               Offset[{5., 1.1102230246251565`*^-15}, {2.186706747284535, 
                1.004468728369049}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.186706747284535, 
                1.004468728369049}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.186706747284535, 
                1.004468728369049}]}]}, {
             FaceForm[
              Directive[
               GrayLevel[1], 
               Opacity[
                NCache[
                 Rational[2, 3], 0.6666666666666666]]]], 
             EdgeForm[], 
             PolygonBox[{
               
               Offset[{27., 7.000000000000006}, {2.186706747284535, 
                1.004468728369049}], 
               
               Offset[{27., -6.999999999999994}, {2.186706747284535, 
                1.004468728369049}], 
               
               Offset[{10.000000000000002`, -6.999999999999997}, {
                2.186706747284535, 1.004468728369049}], 
               
               Offset[{9.999999999999998, 7.000000000000003}, {
                2.186706747284535, 1.004468728369049}]}]}, {
             EdgeForm[], 
             Directive[
              RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25]]}, {}, 
            InsetBox[
             FormBox[
              StyleBox[
               RotationBox["\"x2\"", BoxRotation -> 0.], {}, StripOnInput -> 
               False], TraditionalForm], 
             
             Offset[{18.5, 4.107825191113079*^-15}, {2.186706747284535, 
              1.004468728369049}], {0, 0}]}]}}}}, {{{}}}}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> False, 
     ImagePadding -> {{All, 57.10721451121635}, {All, All}}, DisplayFunction -> 
     Identity, AspectRatio -> NCache[GoldenRatio^(-1), 0.6180339887498948], 
     Axes -> {True, True}, AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, 
     DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"Wardrop Equilibrium Flow Functions\"", TraditionalForm], 
     PlotRange -> {{0, 2}, {0., 0.9999999863945579}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       TagBox[
        GridBox[{{"\[Piecewise]", 
           GridBox[{{
              RowBox[{
                FractionBox["1", "3"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"2", " ", 
                    TagBox["r", HoldForm]}]}], ")"}]}], 
              RowBox[{
                TagBox["r", HoldForm], ">", 
                FractionBox["1", "2"]}]}, {"0", 
              TagBox["True", "PiecewiseDefault", AutoDelete -> True]}}, 
            ColumnAlignments -> {Left}, ColumnSpacings -> 1.2, ColumnWidths -> 
            Automatic, AllowedDimensions -> {2, Automatic}, Selectable -> 
            True, Editable -> True]}}, ColumnAlignments -> {Left}, 
         ColumnSpacings -> 0.5, ColumnWidths -> Automatic], "Piecewise", 
        SyntaxForm -> Equal, SelectWithContents -> True, Selectable -> False, 
        Editable -> False, DeleteWithContents -> True], 
       TagBox[
        GridBox[{{"\[Piecewise]", 
           GridBox[{{
              TagBox["r", HoldForm], 
              RowBox[{"0", "<", 
                TagBox["r", HoldForm], "\[LessEqual]", 
                FractionBox["1", "2"]}]}, {
              FractionBox[
               RowBox[{"1", "+", 
                 TagBox["r", HoldForm]}], "3"], 
              RowBox[{
                TagBox["r", HoldForm], ">", 
                FractionBox["1", "2"]}]}}, ColumnAlignments -> {Left}, 
            ColumnSpacings -> 1.2, ColumnWidths -> Automatic, 
            AllowedDimensions -> {2, Automatic}, Selectable -> True, Editable -> 
            True]}}, ColumnAlignments -> {Left}, ColumnSpacings -> 0.5, 
         ColumnWidths -> Automatic], "Piecewise", SyntaxForm -> Equal, 
        SelectWithContents -> True, Selectable -> False, Editable -> False, 
        DeleteWithContents -> True]}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.7733057764350557`*^9, 3.773305888201239*^9, 
  3.773306821081094*^9, 3.7734675772398977`*^9},
 CellLabel->
  "Out[136]=",ExpressionUUID->"79036711-f296-45f7-93b6-8d598277f930"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{{}, {}, 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQ7ZX64uKBl6l2DFDA4ixVcF/SxR7GN54/Y85myRA4
3/vs9U1zJVPg/PCU73snSZbA+Xf12517JVvg/AWi/m1dklPg/EaOzeqdkkvg
/IjIhes/fNwC53P/b4xxl9sP56sGvntxuPsInF9+ztJ+xpeTcL74FsF7jIzn
4fyYnt8hT8QQ/EUpT08f00HwdUR37uyOQPCdyhKmim5A8Dv8vHh+HEXwz6qZ
NN+6jeD/vhAhL/UawQcAjwFNvg==
          "]], 
         LineBox[CompressedData["
1:eJwVynk41AkAxnFnKptEB8l9REipiNa+KLGONlTWJiYqJUeGTVnShJZyPe1s
sQwVWcfmqGEVopJKcow7N5NjDGZ+uYvfzv7xPu/zeZ6vqmeA01kRISEhZ8H+
/8h7zjzq2iYIrabH6vYeAP+1n8ETeYHnOr4EqzrCKM0lm27QhLwGmc/+ZR5w
jakfjDYVWLFzapbmhbBgC8UQK0HfqnWRud0bL+116a4nm3DcvMZrd5A/7JdX
aEq/C/q4iLxN0Zdx2j37VE5fE6oNez9KJNxAlK1CSsq4oB/g+YaERCLbKKn1
1kwT2uLFvhulRIErFWrnt7YZQuO6trV7buJylYOJoVEzdmSE1kZ1xSJOZXZj
RXwz2sTj+q/fSULp0MH6xu9ZMKfqdC733kO7DY0fby2we9lz+tFkzBW82Gzv
JLCtNUP3dTKMfzM5/c6bBVu1s56uOSkokzWYq77DwnHWfS6Tmopnh7aqPBlj
gWIoJ+wrkYGKbF4Qnd4C86uim/zkMvHKh6Hgym0FxYQw67bIw6yW2frHfh3Y
X+nQotb4FCKL+dIKmp8gnlxHY6wrhxFJKXUu6AEjt50RMFaN+qi9DbU7+iFd
zJNZY1ID5aSJxdypAeS0KVm9aX6Lifn+vrZdQ6ByyG9svQ/I4pTXSSUMg7Jt
NnB7UwOkFP+eZrPZkAmLxe7dzYi7UHLuvsYIpIf4Mde7WZgzz2efjxgF4wR7
12BuK4INa5ibX4/B6mBRapBrO/oLam43q3Jw7YdVZ7fod+KrT2uqTugEshIu
hRovdEHXQmLlXDkX7BNMp9isblg/VPUu3jIFpv6NWG5wL0IUPdQG3aaRHqYT
SdPqhx73uGSHAw+mSdQz770HILuet7pmiQf/C3+W/nJkEGJVqYXqaXwUrWhw
ojSHcHFvedcaOwImqYv1/0oNI/9Hz/sv5gT27GzL+TKM2Ymt0iN3v+DwZ/Vq
w/dslDhbi9IPzSAtgOn6pugzImyiM5gjM1gpKW7lxYxAtde2MzN6Fu1az379
5DYKU+MourzhHBbSxWvrLcfgptS4KNwyB82WF/Mu8uOYrYsfukSbR5pUZeeE
MAfJYu7BThoLUFmlnSrXzYFsX8lDkZoFyGszIkWLJiAeTjtmErgIN0cXhfm7
XAjluhcOySwhz+gaPdJ/EtS/CuNlXi3BUp1TIffzFCp1Y1Zv8P8KR1OKpK/Z
NDbYUvVuSH1D6c0Hiv+s4aFHv6nlasU3jAXti88O56EoHRps92WoVEX4TY7z
cKrQaIPiyjL+UG6kyB7j43r0A1pP3gryRF/mm73l4/GYYqqUPYl3Vhe8mYYE
YhjRlL4jJIpkXc3pewmccZrULHAkkTxoIx9sRGBbRUWRgwuJ8+HaH/aYEriV
eLI2zpPEqpLRnU8tCJw3SuGvvUrCSuPcXPFRAmpRG20kskm8FPGKLvQnsLI/
bF1HDoncJif3xEsEuiaHWdn5JJLSLY0DqASSXJ6eOlxMgmKqNr7zMgFyh1NQ
dAUJMnDQviCcQE9zYrpoCwmzQY+Nj+MIlN2c92ppI6FZ+NNkXAIB+gEPncxO
EuvCUeubRMDu0U6mZR+JHjnlK3p0As+vfHxPGycRdrSvOz+VwF39fYmOXBJn
lBqYtxkEAofSjqlOk7DjVsZfzCCgbe/bXz1DYmsMA7qZBMSEW7OS5kmInIiX
k3xEYKDkgA9liQRHPZzPySZQ4ZNpsGuZBIvvW1eXQ+CesuQsSZJ4XuWWmZdH
4D+v6Kqs
          "]]}, Annotation[#, "Charting`Private`Tag$42847#1"]& ], 
       TagBox[{
         Directive[
          Opacity[1.], 
          RGBColor[0.880722, 0.611041, 0.142051], 
          AbsoluteThickness[1.6]], 
         LineBox[CompressedData["
1:eJxTTMoPSmViYGBQBWIQ7ZX64uKBl6l2MJrFWargvqSLPYw2nj9jzmbJEDjt
ffb6prmSKXA6POX73kmSJXD6rn67c69kC5xeIOrf1iU5BU43cmxW75RcAqcj
Iheu//BxC5zm/t8Y4y63H06rBr57cbj7CJwuP2dpP+PLSTjNp7f16UmOU3B6
Sa9Bz28ZBH3RR/1mnCuC1j4tUqw6DUHfP/5+2Sbz03Da/eBSvrNVZ+D0PQXF
rf/6EHRJw5xog8UIeqH95BWTTyPo33sbnKJkzsLp9buiy57vRdBuUtdlJC8h
6DuVQYe9niFoTktPgXV85+B08nazVSXxCFp8i+A9RsbzcDqm53fIEzEEvSjl
6eljOghaR3Tnzu4IBF30dpFBXh6C3n60Z3lAC4J2KkuYKroBQXf4efH8OIqg
z6qZNN+6jaB/X4iQl3qNoAHW/yLO
          "]], 
         LineBox[CompressedData["
1:eJwVjWs0lAkAhkUXtCmmo6QhpVa5lYpoOy92WtalZWhLJFGEVIaK4tjZKFvE
0WyxLl0wueQSo4smGjm2VfhmEGlchsnlc7eGCN/aH895z/PjPY+O93nmaXk5
OTmXRf7fa/dcxljKBNgmwdlXFQiMvw0yLtEgMDsYXp6oSMA07QiXY0zA7w+W
mXg1AbfYD5IYCwL01hEZm0YgItSKfvkggaZtgbzv1xEQOOhz3NwJWFb77ArR
IuAwv8DWukFAg3LVVzYkcNKTezyng0BtqJn2PjsC0XaaKSkDi/23pe3tjgS4
polNNycJmKntTLvmTGBI5Yp9kLIQWUV6Gg1HCVyqdDQ3MRUigtSg+foRiNsk
W8uPF8LIa245J5rAs+4fPzT8IEKSvWBktILAR1v2eLyNCBNVzdnRVQSmCivU
HZgiMC1ID42axc5V85Pv/ERQ2057b11H4AXNeOpN0uJ/+enHf34m8JKxYVNJ
/6ILFL32fyXA546FcDiN4Jg5Ca/vEqIqIF3TbagJd7d0ltKzhJBtO7C6IKgF
3Of+x6ThIsjP5K/R3NoGORfz4tKTjTClvJ65FIrhl3exT9OiCR+i99TX7OgE
w4DPsFZphnbi4EzuSBcCymycgyebMTjd2dG8sxvps4D5+4/IIl/VqtzuwXqb
SLESrwUq9MejUqkUShXV95OTWxHnX+b7QLcXiuNhjDdBnzBlmS89E9WHQ/qs
5DHXNoSaVPPU3/bjkU5r3UuDz+gsrL4l1CFhqX2t5Ja6GN8CmlK3XxkE02bf
a805MfStViz4vhoCS/9YLkPUDptHOn5P142gTV3AuFTegcv0E5slHqNwquAI
LO90wmDo8MoWxzHQbc1LpLu7QFs9plg9O4bnPDt3w8ddWFqZWrQlbRxHo9Qu
VqlJELjn1Scl+wmk1UX0ut+QIP9n7wcVUxPYuGsooGlGAtnghjW9d/9F5oSq
V8qpbpS52ChwGJOoN2t74t3ajSjbmPu83klQbUcDwhg90Gm3a82MkSHwjtgi
qLAHFmbRHA2TKUQ0yPv46kjhodUws6RxCkn+nd/y46SQ1cZ3X2BP49ANzyGZ
3BckL/UMZep+xRoFjmNc0BfQOsoeyVd/xSpOvWBJ6xcsi2S7mgfPoCAnP/6q
fS/kcj2LutVmcVgTtVbPe8H6qyherWoWD1Uven5n0IfX+rGKque+QY9evOxZ
Rh9U7VgGv6vMoez6Q/oTpX6IDYnGcP4c+kP2xnMj+1GcAV2p5zw2VUYFDQ/0
43iRqSp9YR5J2g1eNNcB/BbzkC3OW0CegiD/wN8DKOinp6o4UHh30N+PZ0Ii
Nj3Gq+MQhWKamyVnD4lTzOGthc4UkiW2GqGmJDby+cWORyicidR7v9uCxM0E
95o4bwrLy/qMSq1InDFNGVcOp3BQ13fqqROJzdFrbVdwKQjkfWKKzpFY2Bex
qiWHQi7B9Ey4QOLTcI+Im08hMcPa7DyLROKR0uM/PaXgZbF5wOgSCWoHMySG
T0GOJXEojCQhFiZkKDRSOCA5sbYgjsSL69M+jc0Uthb9Mhx3mwRn/4ntma0U
VkWi5mwiCftsI551B4X29dphBhwS5WF1/7AHKEQ4dXzOTyVx13BvgvMQhVNa
9bxb6SSCu9NcdUYp2A29jg+8T0LP4Wznm0kKG2LToZ9JYumSpqzEaQryv8av
X5lNoqtsf4DXLAVyS+Q4ySXBD8g03jlPQTR+trY2h8Q97ZUyiqJQXumRmZdH
4j9ek6pe
          "]]}, 
        Annotation[#, 
         "Charting`Private`Tag$42847#2"]& ], {}}, {{}, {}, {}, {}}}, {{}, \
{}}, {{{{{
          GraphicsGroupBox[{{
             Directive[
              AbsoluteThickness[4], 
              GrayLevel[1], 
              Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]], 
             CapForm["Butt"], 
             JoinForm["Round"], 
             BSplineCurveBox[{
               Offset[{0, 0}, {2.0416666666666665`, 1.1666666394557823`}], 
               Offset[{0, 0}, {2.0416666666666665`, 1.1666666394557823`}], 
               Offset[{0., 0.}, {2.0616666666666665`, 1.1666666394557823`}], 
               Offset[{0., 0.}, {2.0616666666666665`, 1.1666666394557823`}], 
               Offset[{0., 0.}, {2.0816666666666666`, 1.1666666394557823`}], 
               Offset[{0, 0}, {2.1252834582175884`, 1.1603372543892936`}], 
               
               Offset[{5., 1.1102230246251565`*^-15}, {2.1252834582175884`, 
                1.1603372543892936`}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.1252834582175884`, 
                1.1603372543892936`}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.1252834582175884`, 
                1.1603372543892936`}]}]}, {
             Directive[
              RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25]], 
             BSplineCurveBox[{
               Offset[{0, 0}, {2.0416666666666665`, 1.1666666394557823`}], 
               Offset[{0, 0}, {2.0416666666666665`, 1.1666666394557823`}], 
               Offset[{0., 0.}, {2.0616666666666665`, 1.1666666394557823`}], 
               Offset[{0., 0.}, {2.0616666666666665`, 1.1666666394557823`}], 
               Offset[{0., 0.}, {2.0816666666666666`, 1.1666666394557823`}], 
               Offset[{0, 0}, {2.1252834582175884`, 1.1603372543892936`}], 
               
               Offset[{5., 1.1102230246251565`*^-15}, {2.1252834582175884`, 
                1.1603372543892936`}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.1252834582175884`, 
                1.1603372543892936`}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.1252834582175884`, 
                1.1603372543892936`}]}]}, {
             FaceForm[
              Directive[
               GrayLevel[1], 
               Opacity[
                NCache[
                 Rational[2, 3], 0.6666666666666666]]]], 
             EdgeForm[], 
             PolygonBox[{
               
               Offset[{43., 8.000000000000009}, {2.1252834582175884`, 
                1.1603372543892936`}], 
               
               Offset[{43., -7.99999999999999}, {2.1252834582175884`, 
                1.1603372543892936`}], 
               
               Offset[{10., -7.999999999999997}, {2.1252834582175884`, 
                1.1603372543892936`}], 
               
               Offset[{10., 8.000000000000002}, {2.1252834582175884`, 
                1.1603372543892936`}]}]}, {
             EdgeForm[], 
             Directive[
              RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25]]}, {}, 
            InsetBox[
             FormBox[
              StyleBox[
               RotationBox["\"xOpt1\"", BoxRotation -> 0.], {}, StripOnInput -> 
               False], TraditionalForm], 
             
             Offset[{26.5, 5.88418203051333*^-15}, {2.1252834582175884`, 
              1.1603372543892936`}], {0, 0}]}], 
          GraphicsGroupBox[{{
             Directive[
              AbsoluteThickness[4], 
              GrayLevel[1], 
              Opacity[
               NCache[
                Rational[2, 3], 0.6666666666666666]]], 
             CapForm["Butt"], 
             JoinForm["Round"], 
             BSplineCurveBox[{
               Offset[{0, 0}, {2.0416666666666665`, 0.8333333197278912}], 
               Offset[{0, 0}, {2.0416666666666665`, 0.8333333197278912}], 
               Offset[{0., 0.}, {2.0616666666666665`, 0.8333333197278912}], 
               Offset[{0., 0.}, {2.0616666666666665`, 0.8333333197278912}], 
               Offset[{0., 0.}, {2.0816666666666666`, 0.8333333197278912}], 
               Offset[{0, 0}, {2.1252834582175884`, 0.8333007422476327}], 
               
               Offset[{5., 1.1102230246251565`*^-15}, {2.1252834582175884`, 
                0.8333007422476327}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.1252834582175884`, 
                0.8333007422476327}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.1252834582175884`, 
                0.8333007422476327}]}]}, {
             Directive[
              RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25]], 
             BSplineCurveBox[{
               Offset[{0, 0}, {2.0416666666666665`, 0.8333333197278912}], 
               Offset[{0, 0}, {2.0416666666666665`, 0.8333333197278912}], 
               Offset[{0., 0.}, {2.0616666666666665`, 0.8333333197278912}], 
               Offset[{0., 0.}, {2.0616666666666665`, 0.8333333197278912}], 
               Offset[{0., 0.}, {2.0816666666666666`, 0.8333333197278912}], 
               Offset[{0, 0}, {2.1252834582175884`, 0.8333007422476327}], 
               
               Offset[{5., 1.1102230246251565`*^-15}, {2.1252834582175884`, 
                0.8333007422476327}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.1252834582175884`, 
                0.8333007422476327}], 
               
               Offset[{10., 2.220446049250313*^-15}, {2.1252834582175884`, 
                0.8333007422476327}]}]}, {
             FaceForm[
              Directive[
               GrayLevel[1], 
               Opacity[
                NCache[
                 Rational[2, 3], 0.6666666666666666]]]], 
             EdgeForm[], 
             PolygonBox[{
               
               Offset[{43., 8.000000000000009}, {2.1252834582175884`, 
                0.8333007422476327}], 
               
               Offset[{43., -7.99999999999999}, {2.1252834582175884`, 
                0.8333007422476327}], 
               
               Offset[{10., -7.999999999999997}, {2.1252834582175884`, 
                0.8333007422476327}], 
               
               Offset[{10., 8.000000000000002}, {2.1252834582175884`, 
                0.8333007422476327}]}]}, {
             EdgeForm[], 
             Directive[
              RGBColor[
              0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
              AbsoluteThickness[1.25]]}, {}, 
            InsetBox[
             FormBox[
              StyleBox[
               RotationBox["\"xOpt2\"", BoxRotation -> 0.], {}, StripOnInput -> 
               False], TraditionalForm], 
             
             Offset[{26.5, 5.88418203051333*^-15}, {2.1252834582175884`, 
              0.8333007422476327}], {0, 0}]}]}}}}, {{{}}}}}, {
    DisplayFunction -> Identity, Ticks -> {Automatic, Automatic}, 
     AxesOrigin -> {0, 0}, FrameTicks -> {{Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
        Charting`ScaledFrameTicks[{Identity, Identity}]}}, 
     GridLines -> {None, None}, DisplayFunction -> Identity, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, PlotRangeClipping -> False, 
     ImagePadding -> {{All, 62.051022479165894`}, {All, All}}, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
       AbsolutePointSize[6], "ScalingFunctions" -> None, 
       "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotLabel -> 
     FormBox["\"Wardrop Equilibrium Flow Functions\"", TraditionalForm], 
     PlotRange -> {{0, 2}, {0., 1.1666666394557823`}}, PlotRangeClipping -> 
     True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
       TagBox[
        GridBox[{{"\[Piecewise]", 
           GridBox[{{
              RowBox[{
                FractionBox["1", "6"], " ", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"4", " ", 
                    TagBox["r", HoldForm]}]}], ")"}]}], 
              RowBox[{
                TagBox["r", HoldForm], ">", 
                FractionBox["1", "4"]}]}, {"0", 
              TagBox["True", "PiecewiseDefault", AutoDelete -> True]}}, 
            ColumnAlignments -> {Left}, ColumnSpacings -> 1.2, ColumnWidths -> 
            Automatic, AllowedDimensions -> {2, Automatic}, Selectable -> 
            True, Editable -> True]}}, ColumnAlignments -> {Left}, 
         ColumnSpacings -> 0.5, ColumnWidths -> Automatic], "Piecewise", 
        SyntaxForm -> Equal, SelectWithContents -> True, Selectable -> False, 
        Editable -> False, DeleteWithContents -> True], 
       TagBox[
        GridBox[{{"\[Piecewise]", 
           GridBox[{{
              TagBox["r", HoldForm], 
              RowBox[{"0", "<", 
                TagBox["r", HoldForm], "\[LessEqual]", 
                FractionBox["1", "4"]}]}, {
              RowBox[{
                FractionBox["1", "6"], " ", 
                RowBox[{"(", 
                  RowBox[{"1", "+", 
                    RowBox[{"2", " ", 
                    TagBox["r", HoldForm]}]}], ")"}]}], 
              RowBox[{
                TagBox["r", HoldForm], ">", 
                FractionBox["1", "4"]}]}}, ColumnAlignments -> {Left}, 
            ColumnSpacings -> 1.2, ColumnWidths -> Automatic, 
            AllowedDimensions -> {2, Automatic}, Selectable -> True, Editable -> 
            True]}}, ColumnAlignments -> {Left}, ColumnSpacings -> 0.5, 
         ColumnWidths -> Automatic], "Piecewise", SyntaxForm -> Equal, 
        SelectWithContents -> True, Selectable -> False, Editable -> False, 
        DeleteWithContents -> True]}, "LineLegend", 
      DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"LineLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
               ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, DefaultBaseStyle -> 
                    "ColorSwatchGraphics", AspectRatio -> 1, Frame -> True, 
                    FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    StyleBox[
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"0.880722`", ",", "0.611041`", ",", "0.142051`"}],
                     "]"}], NumberMarks -> False]], Appearance -> None, 
                    BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}]}],
              "}"}], ",", 
           RowBox[{"{", 
             RowBox[{
               TagBox[#, HoldForm], ",", 
               TagBox[#2, HoldForm]}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.7733057764350557`*^9, 3.773305888201239*^9, 
  3.773306821081094*^9, 3.773467577371847*^9},
 CellLabel->
  "Out[137]=",ExpressionUUID->"cd78a421-d3f5-42c6-bc79-b266a987a11b"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], 
       LineBox[{{4.081632653061224*^-8, 1.}, {0.019628681609693666`, 1.}, {
        0.0392573224030608, 1.}, {0.08181671417091729, 1.}, {
        0.11237243569579453`, 1.}, {0.12155576714030418`, 1.}, {
        0.1605152976377521, 1.}, {0.20277693831632224`, 1.}, {
        0.24221824019642277`, 1.}, {0.24488970345024919`, 1.}, {
        0.24756116670407563`, 1.}, {0.24822903251753226`, 1.}, {
        0.24889689833098885`, 1.}, {0.2493622448979592, 1.}}], 
       LineBox[CompressedData["
1:eJwV0H1Uk2UYx/FtoOFUXo7jdSWQaSnK1GS8HDg/SIeGQwz1KBAooERbCIJS
JAnIiyXMF1riEJTCEIWBTkQ9IgieJijJswGSMjcFRTCsm2dsAge1pz/uc53P
Od8/rut2j0sO38VhsVjrmff/zC3ZRFK5FGqi6wssWQRjt5MEKmcKBdUXPfiM
eRcHJJUfUVgT/jMtZCws21olF1AYNy4QfMk44sfOp/l+FBoC428cZpy5N+iD
b0UU2C+4qW2MT+9o3Ja4kYLA7ydPCzZBq9hDHhFFoX9qulPM+JlPRVdIAgVZ
wIolZxjPXGg/238Phe27FQumGC+2Oxy8LJNCV0poSTSHQPzmbc78QxT0j2bs
7GC8eyTtpk0xhcIQp68DLAiO9w5PsMqZviet4DrjB0pt8qCKwv1FyqIOS4JJ
xdqanpsUzlV/7hM9g+D9gqahP9opqAKqciYYx8ZURVfrKUTFO2SI3iPIC+Er
FCMUZsas+MfMuEp4rOfwOIV9SfZH660IRq2/X5/E1cC9sPmFF5cgvSXUd6VQ
g9wrBxzlcwkUNW17FwRpMJq+gZtpTdBU4n2RJ9bggLovSmJDwE5x//h1rAYb
Wm83RdgRFLmZeE0yDSa/6HudbU9QN0eyUXlSg+qtkdsVDgSaCX3h6UoNTk6b
U686Ejho2jk51zWot+WLLV0Ifs0pI6LnGkhc+Cf18wkaB1Z3dvlrMW37t2f+
YuY/1uWMydZq0SAVNQwvITDXNTuIw7VoV546sXEpgfd+39j2r7QorLUQLhMQ
XJsnMN8q1qIjZSTYyYvg+hoXN9WwFm6s1vLzQcw9VSRNLu/G0cjNR+KiCXRz
PBXhZ7rxyssQ6bOdYDpV2mx7oRsVeTTLLpYgAENWspZuuLdPXr67k6C5r788
/2U31PLahphvCFqs7txJD+yB2tCfxc4kaJOU8yNGe5A8L+ztVBnB5RGpNMbc
A89xa5/XpwnOJvrdiGf14mHJIXtTBUF+Ql/kbl4v5ob9cs50lmBdnF1prn8v
Wtkzz8xSEnRF5DvVFfVCemxV63c3mX3XJdlbLHuAcdknl7cYCEyLAmyUSX2I
CfZ9ErBoDJzJGlv+wkeQF4d5W3aMQfhuR+OmOh24l/bF/bmLhjj01kHRNR2k
btGjwkQa8adcw7zbdHg+nJJRIaFxzFv/wuWBDt3B8aVpyTRGkqOcB97o0KKr
f+acQaPsyZbMlNDHyOKUzkooosFuC/lMNvoY6efvhU+oaDjZXrDOMj+G/56n
3NgrNDxjZvWnsPTgKsyqjqs0IqfupG3m6XHw1lxNaRONhpWi3/n+ejzJuCL0
V9NIqITVhUI9XAcv+e5/SKMzb9V99RID4vI5g0PvaPjZ3OMc9zJgrSnpUTbH
iGpFrHdUoAF6aa/SZYYRuXVHKv7dwlhQMhTKNcLvr+FUpxwD1Ntci1U8po/L
OjdQaED1vVNR6x2NcHhlr6s9YUClw/I3g85GjLFXi4JqDWBfva3muTK9R7mj
pM+AhabOhL2Lmb7xU/GqAQN+my98NnupEXmBd7PfjhrwMsRFWOlpxA+JtTYy
kwHZHrYfXlpuxH97hldx
        "]], LineBox[CompressedData["
1:eJwVz3s01AkUB3DEUkqhlF2UqFPeQlYPX6mTQmpQ3uRR8uohW4gNpazKCCkR
NqXkXUohStPWKqr1KGX4zQw2Ib/5jccgfvvbP+6553PO9957rqbfEccDUhIS
Eq5M/d+fv1kbaSFDgGO9kDpvLIKGWVqR8nwCqedONrkZinChYU03V4XA5IGg
qRFdERqlI8TWagR8F4/4btYRQbyzQemuJgHTfdqsi2tEONi21yZcj4Di5Tv1
BqtEsB5IqPjJmsDvVkvyEjVEiDJoaQqxIdAZN2dBj5oIFcdV+97bE9DizxdZ
/MLcny1XzXYh8Idf3/LRpSJMKnETDMMI1M5eeh2lyOQ3me91vUbgacVw/Wtp
EZanDk4WfSdQnKmmHTREod73dNF9EYG31Jwo2UEK3ibKbrViAhFv3/cVDlDI
6djw+K0UDwkjGlID/RSWqSefGFHhwUlPUSuaR0Hp3hqRKXjgTAWJWzooyHAO
DDWweZDNceBuaKQwONHT3W7Eh1d1mBGRTeFRILvRdj0f1n4OFgXXKcR9tCxs
2MiHZazxpsAsCirVN8KKtvMha5OuS2VSsD7h8SPGk48WrkGachqF66MdqtpJ
fMTO3cc+k0Rhh7DZObyHj/N7AjQUT1C49a22SSFFAJn1z9pKnSgcvrpbKzhd
APnoSr8SRwrm2wSnXl4TQLXd7G4xi0LTjXn6MQUCrIO8S8luCsI9buyBxwLk
Zt4xfGRHwbJ63IkjYOYXNegPbqXQecaYG2XRCz1WSGa7KQUF9Tsjvb298K26
Upy0jMLFoIcH87X7sa9BKjhjQIhxq+LeQ6f/RUcod+Xbp0JErONUqbz4CiPJ
ABn/60L0lHEufND8Bu9lewz4kUJMB7dlr40ehH9zvbmSpxC6W2RnD9YOwe5R
X7jlNiFsbmoGVi79Dr3K5iMW+kKcVPdZyfMcwVb39JoZVSH0hvbKf9xFYgOU
2GNyQigvJOU4U4z9V9+3EpOQbsgu18oRwjlatlHtG4kQ09rOucyf+Q/UhnS6
SBTv9MuvH6eg/zz0ZNU7EmODPy/qzxTh8+UtrPkvSTx0spmTsW0U5occfMJq
SJzekZhX1T8KQr17vn0lCU2u7aeCxDFU9kWyJIuYu+ZnM1TXjSPHNrKyOJ+E
p8a7ScnWcZi8uPkkIovZ33SJfzR+AoEWQQLDNBLXpL0jHLXFOKOfcrv7Agnl
7oc3pThivDGJuad8joRMbLyzxbFJlMgdfWISR0KiyLucrzSFzy1hXYqnSIRf
L7+k1DiFHKu8419+I/FUN0lO8fA0pn2KdBcdI6FoG66XoPAD6fKLjb+EkujS
f98aVfcDu868imcfIlGRC+1e7xmUfh3ufBVAwqt8vaL67Azeq7l5bPclEZf4
Z3zXvVnUJN8sLvUimZx6toI9jUK72MY4dxJJNxL3dzvQ4D2VGgtnHOA4vKqM
RaNa8rnOAcZqdXUVu1xoaH0V5O1knMz2+OuiHw1WSWGFEuND67OE86JoPLLf
HHLbjcTKs4t3yBbSMJsu3dzsSmL215gFH+/S0Mt2b29g3Dks+KewmIaL5oqj
9xmnujzw2l5JI2xGWHaVMa3jeDyxjoZKxxWWH+OuD+zcOa00ml1/0hG7kHh8
bsK/tZ2G8HIz9Y1xxkaftQWfaHg45tZzGdvdNqiy7qaRmevq84JxTWTz3/ED
NF6RS16mMM7UN2OzhmhkDCsUxjM+xs9x1hyhkdI/NzmC8Rr70J5nozSyFKQ8
3BlLS7bdSp1g9vvM2OxiTDzcGLx/ikbZyLi5FeO64AJDoxkabh+GdUwYX10u
P0bTNGJVeCtWM/4P8lLZ/Q==
        "]]},
      Annotation[#, 
       "Charting`Private`Tag$43084#1"]& ], {}}, {{}, {}, {}}}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 1.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Price of Anarchy\"", TraditionalForm],
  PlotRange->{{0, 2}, {1., 1.199592538400041}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.7733057764350557`*^9, 3.773305888201239*^9, 
  3.773306821081094*^9, 3.773467577437603*^9},
 CellLabel->
  "Out[138]=",ExpressionUUID->"c730ae2b-c4d5-4a54-9420-c48b8e18408c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute Price of Anarchy", "Subsection",
 CellChangeTimes->{{3.773306295232239*^9, 
  3.773306304704705*^9}},ExpressionUUID->"d5a31020-bf79-4719-bf8a-\
ba8237301428"],

Cell["\<\
To use this computation, load the parametrized example first and compute the \
equilibrium and optimal functions\
\>", "Text",
 CellChangeTimes->{{3.773306311651971*^9, 
  3.773306341974915*^9}},ExpressionUUID->"3489adec-8305-4205-8a08-\
dfd9f68b2141"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Maximize", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"poa", ",", 
     RowBox[{"a1", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"a2", ">", "0"}], ",", 
     RowBox[{"b2", "\[GreaterEqual]", "b1"}], ",", 
     RowBox[{"b1", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"r", "\[GreaterEqual]", "0"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "a2", ",", "b1", ",", "b2", ",", "r"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.773306619981442*^9, 3.773306653534966*^9}},
 CellLabel->
  "In[121]:=",ExpressionUUID->"e1c10f65-a977-4e4d-be13-50250aa0645f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["4", "3"], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a1", "\[Rule]", "1"}], ",", 
     RowBox[{"a2", "\[Rule]", "1"}], ",", 
     RowBox[{"b1", "\[Rule]", "1"}], ",", 
     RowBox[{"b2", "\[Rule]", "2"}], ",", 
     RowBox[{"r", "\[Rule]", "1"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.773306345592265*^9, 3.773306566127894*^9, 
  3.773306615676654*^9, 3.773306700241143*^9, 3.773307227983737*^9},
 CellLabel->
  "Out[121]=",ExpressionUUID->"bf7c554d-f778-4b18-a4a5-713c6ed26faf"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1680, 936},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"11.3 for Mac OS X x86 (32-bit, 64-bit Kernel) (March 5, \
2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 235, 6, 98, "Title",ExpressionUUID->"7ad0e35a-2d49-4052-8118-55b4a5579ace"],
Cell[CellGroupData[{
Cell[840, 32, 150, 3, 67, "Section",ExpressionUUID->"c86c9a71-decb-4923-ba02-d184dee00887"],
Cell[993, 37, 295, 4, 35, "Text",ExpressionUUID->"440fb9f9-48ad-451f-9771-a0872ecadd85"],
Cell[CellGroupData[{
Cell[1313, 45, 157, 3, 54, "Subsection",ExpressionUUID->"ef3160aa-6832-477d-9a44-3136fa277848"],
Cell[1473, 50, 742, 18, 94, "Input",ExpressionUUID->"efb5aacf-8706-4340-9177-97fdbd9da764"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2252, 73, 159, 3, 54, "Subsection",ExpressionUUID->"71475cde-6ffd-405a-b630-38772cb0f9c4"],
Cell[2414, 78, 660, 17, 128, "Input",ExpressionUUID->"81ece15a-e9ac-43be-a3e4-fc42bfca42df"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3111, 100, 271, 4, 54, "Subsection",ExpressionUUID->"618fc1b7-340c-40ef-ae3e-06fd10cb9b5c"],
Cell[3385, 106, 950, 21, 94, "Input",ExpressionUUID->"e7f4b819-6c09-4e6f-96b0-307dac7eddc5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4372, 132, 271, 4, 54, "Subsection",ExpressionUUID->"0c1e3d1f-2502-40ed-8a71-aa50c0d8af31"],
Cell[4646, 138, 968, 22, 94, "Input",ExpressionUUID->"a801010b-de62-4c62-ba66-8b7959f76a0e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5651, 165, 207, 3, 54, "Subsection",ExpressionUUID->"6bb3a9cc-d5af-428a-ad92-4877e147aaa6"],
Cell[5861, 170, 702, 17, 94, "Input",ExpressionUUID->"a17ad966-89ba-4805-9e23-adfeed0b18c4"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[6612, 193, 154, 3, 67, "Section",ExpressionUUID->"7a1b66f8-8565-4920-8b88-b752d0920b80"],
Cell[CellGroupData[{
Cell[6791, 200, 188, 3, 45, "Subsubsection",ExpressionUUID->"0b471432-2cbf-455a-b9f5-5e41eb4c312d"],
Cell[CellGroupData[{
Cell[7004, 207, 11595, 293, 1018, "Input",ExpressionUUID->"6020d670-316f-4597-b4d0-56585e396db2"],
Cell[CellGroupData[{
Cell[18624, 504, 4888, 129, 74, "Print",ExpressionUUID->"c601ec1e-6db3-4006-864a-ea26fa6e0ca6"],
Cell[23515, 635, 3059, 77, 74, "Print",ExpressionUUID->"1b508244-8f70-4cb5-bdee-0186a4ea9f82"],
Cell[26577, 714, 4989, 132, 74, "Print",ExpressionUUID->"99b2951e-ff44-4cc9-a5d0-c51b437f6717"],
Cell[31569, 848, 3195, 81, 74, "Print",ExpressionUUID->"dcac66a9-080b-4b2e-a733-2982dd2b7cb8"],
Cell[34767, 931, 3584, 90, 88, "Print",ExpressionUUID->"38b37f7a-ecb1-414b-bc7d-3e4b97536a6a"],
Cell[38354, 1023, 1111, 22, 40, "Print",ExpressionUUID->"1f650198-f86c-466a-9fb3-fc9b9334161b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[39526, 1052, 164, 3, 54, "Subsection",ExpressionUUID->"123403cc-467f-4322-9854-5d71293ef78d"],
Cell[CellGroupData[{
Cell[39715, 1059, 1928, 48, 283, "Input",ExpressionUUID->"405d4c02-1362-4259-997b-465ca0422a02"],
Cell[41646, 1109, 25344, 529, 224, "Output",ExpressionUUID->"79036711-f296-45f7-93b6-8d598277f930"],
Cell[66993, 1640, 25653, 536, 223, "Output",ExpressionUUID->"cd78a421-d3f5-42c6-bc79-b266a987a11b"],
Cell[92649, 2178, 5651, 113, 252, "Output",ExpressionUUID->"c730ae2b-c4d5-4a54-9420-c48b8e18408c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[98349, 2297, 172, 3, 54, "Subsection",ExpressionUUID->"d5a31020-bf79-4719-bf8a-ba8237301428"],
Cell[98524, 2302, 262, 6, 35, "Text",ExpressionUUID->"3489adec-8305-4205-8a08-dfd9f68b2141"],
Cell[CellGroupData[{
Cell[98811, 2312, 601, 15, 30, "Input",ExpressionUUID->"e1c10f65-a977-4e4d-be13-50250aa0645f"],
Cell[99415, 2329, 554, 14, 51, "Output",ExpressionUUID->"bf7c554d-f778-4b18-a4a5-713c6ed26faf"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

